@@ -145,7 +145,7 @@ static void fits_rotate_pi(fits *fit) {
 	invalidate_WCS_keywords(fit);
 }
 
-static void mirrorx_gui(fits *fit) {
+void mirrorx_gui(fits *fit) {
 	if (confirm_delete_wcs_keywords(fit)) {
 		set_cursor_waiting(TRUE);
 		undo_save_state(fit, _("Mirror X"));
@@ -156,7 +156,7 @@ static void mirrorx_gui(fits *fit) {
 	}
 }
 
-static void mirrory_gui(fits *fit) {
+void mirrory_gui(fits *fit) {
 	if (confirm_delete_wcs_keywords(fit)) {
 		set_cursor_waiting(TRUE);
 		undo_save_state(fit, _("Mirror Y"));
@@ -468,51 +468,28 @@ int crop(fits *fit, rectangle *bounds) {
 /**
  *  ROTATION
  */
-void on_menuitem_rotation90_activate(GtkMenuItem *menuitem, gpointer user_data) {
+void siril_rotate90() {
 	if (confirm_delete_wcs_keywords(&gfit)) {
-		static GtkToggleButton *crop_rotation = NULL;
-		int cropped;
-
-		if (crop_rotation == NULL) {
-			crop_rotation = GTK_TOGGLE_BUTTON(
-					lookup_widget("checkbutton_rotation_crop"));
-		}
-		cropped = gtk_toggle_button_get_active(crop_rotation);
-
 		set_cursor_waiting(TRUE);
 		undo_save_state(&gfit, _("Rotation (90.0deg)"));
-		verbose_rotate_image(&gfit, 90.0, -1, cropped);	// fast rotation, no interpolation, no crop
+		verbose_rotate_image(&gfit, 90.0, -1, 0);	// fast rotation, no interpolation, no crop
 		redraw(com.cvport, REMAP_ALL);
 		redraw_previews();
 		set_cursor_waiting(FALSE);
 	}
 }
 
-void on_menuitem_rotation270_activate(GtkMenuItem *menuitem, gpointer user_data) {
+void siril_rotate270() {
 	if (confirm_delete_wcs_keywords(&gfit)) {
-		static GtkToggleButton *crop_rotation = NULL;
-		int cropped;
-
-		if (crop_rotation == NULL) {
-			crop_rotation = GTK_TOGGLE_BUTTON(
-					lookup_widget("checkbutton_rotation_crop"));
-		}
-		cropped = gtk_toggle_button_get_active(crop_rotation);
-
 		set_cursor_waiting(TRUE);
 		undo_save_state(&gfit, _("Rotation (-90.0deg)"));
-		verbose_rotate_image(&gfit, 270.0, -1, cropped);// fast rotation, no interpolation, no crop
+		verbose_rotate_image(&gfit, 270.0, -1, 0);// fast rotation, no interpolation, no crop
 		redraw(com.cvport, REMAP_ALL);
 		redraw_previews();
 		set_cursor_waiting(FALSE);
 	}
 }
 
-void on_menuitem_rotation_activate(GtkMenuItem *menuitem, gpointer user_data) {
-	if (single_image_is_loaded())
-		siril_open_dialog("rotation_dialog");
-}
-
 void on_button_rotation_close_clicked(GtkButton *button, gpointer user_data) {
 	siril_close_dialog("rotation_dialog");
 }
@@ -521,35 +498,11 @@ void on_button_rotation_ok_clicked(GtkButton *button, gpointer user_data) {
 	rotate_gui(&gfit);
 }
 
-/******
- * MIRROR
- */
-
-void on_menuitem_mirrorx_activate(GtkMenuItem *menuitem, gpointer user_data) {
-	mirrorx_gui(&gfit);
-}
-
-void on_mirrorx_button_clicked(GtkToolButton *button, gpointer user_data) {
-	mirrorx_gui(&gfit);
-}
-
-void on_menuitem_mirrory_activate(GtkMenuItem *menuitem, gpointer user_data) {
-	mirrory_gui(&gfit);
-}
-
-void on_mirrory_button_clicked(GtkToolButton *button, gpointer user_data) {
-	mirrory_gui(&gfit);
-}
-
 /*************
  * RESAMPLE
  */
 
 /* Resample */
-void on_menuitem_resample_activate(GtkMenuItem *menuitem, gpointer user_data) {
-	if (single_image_is_loaded())
-		siril_open_dialog("resample_dialog");
-}
 
 void on_button_resample_ok_clicked(GtkButton *button, gpointer user_data) {
 	if (confirm_delete_wcs_keywords(&gfit)) {
