@@ -14,6 +14,11 @@ struct crop_sequence_data {
 int verbose_resize_gaussian(fits *, int, int, int);
 int verbose_rotate_image(fits *, double, int, int);
 
+void siril_rotate90();
+void siril_rotate270();
+
+void mirrorx_gui(fits *fit);
+void mirrory_gui(fits *fit);
 void mirrorx(fits *fit, gboolean verbose);
 void mirrory(fits *fit, gboolean verbose);
 
