@@ -51,6 +51,9 @@
 #include "algos/annotate.h"
 #include "algos/siril_wcs.h"
 #include "io/image_format_fits.h"
+#include "io/single_image.h"
+#include "io/sequence.h"
+#include "opencv/opencv.h"
 #include "registration/matching/match.h"
 #include "registration/matching/apply_match.h"
 #include "registration/matching/misc.h"
@@ -59,6 +62,8 @@
 
 #include "plateSolver.h"
 
+#define DOWNSAMPLE_FACTOR 0.25
+
 enum {
 	COLUMN_RESOLVER,		// string
 	COLUMN_NAME,		// string
@@ -100,7 +105,7 @@ static struct object platedObject[RESOLVER_NUMBER];
 static GtkListStore *list_IPS = NULL;
 static image_solved is_result;
 
-static void initialize_ips_dialog() {
+void initialize_ips_dialog() {
 	GtkWidget *button_ips_ok, *button_cc_ok, *catalog_label, *catalog_box_ips,
 			*catalog_box_pcc, *catalog_auto, *frame_cc_bkg, *frame_cc_norm,
 			*catalog_label_pcc;
@@ -297,6 +302,13 @@ static gboolean flip_image_after_ps() {
 	return gtk_toggle_button_get_active(button);
 }
 
+static gboolean is_downsample_activated() {
+	GtkToggleButton *button;
+
+	button = GTK_TOGGLE_BUTTON(lookup_widget("downsample_ips_button"));
+	return gtk_toggle_button_get_active(button);
+}
+
 static gchar *get_catalog_url(SirilWorldCS *center, double mag_limit, double dfov, int type) {
 	GString *url;
 	gchar *coordinates;
@@ -305,7 +317,7 @@ static gchar *get_catalog_url(SirilWorldCS *center, double mag_limit, double dfo
 
 	coordinates = g_strdup_printf("%f+%f", siril_world_cs_get_alpha(center), siril_world_cs_get_delta(center));
 	mag = g_strdup_printf("%2.2lf", mag_limit);
-	fov = g_strdup_printf("%2.1lf", dfov / 2);
+	fov = g_strdup_printf("%2.1lf", dfov / 2.0);
 
 	url = g_string_new("http://vizier.u-strasbg.fr/viz-bin/asu-tsv?-source=");
 	switch (type) {
@@ -666,21 +678,30 @@ static gboolean has_any_keywords() {
 			gfit.pixel_size_x > 0.f ||
 			gfit.pixel_size_y > 0.f ||
 			(gfit.wcsdata.crval[0] > 0.0 && gfit.wcsdata.crval[1] != 0.0) ||
-			(gfit.wcsdata.objctra[0] != '\0' && gfit.wcsdata.objctdec[0] != '\0'));
+			(gfit.wcsdata.objctra[0] != '\0' && gfit.wcsdata.objctdec[0] != '\0') ||
+			(gfit.wcsdata.ra != 0.0 && gfit.wcsdata.dec != 0.0));
 }
 
 static void update_coords() {
 	SirilWorldCS *world_cs = NULL;
+	fits *fit = &gfit;
 
-	if (gfit.wcsdata.crval[0] != 0.0 && gfit.wcsdata.crval[1] != 0.0) {
-		// first transform coords to alpha and delta
-		world_cs = siril_world_cs_new_from_a_d(gfit.wcsdata.crval[0], gfit.wcsdata.crval[1]);
+	if (fit->wcsdata.ra != 0.0 && fit->wcsdata.dec != 0.0) {
+
+		world_cs = siril_world_cs_new_from_a_d(fit->wcsdata.ra, fit->wcsdata.dec);
 
 		update_coordinates(world_cs);
 		unselect_all_items();
-	} else if (gfit.wcsdata.objctra[0] != '\0' && gfit.wcsdata.objctdec[0] != '\0') {
+	} else if (fit->wcsdata.objctra[0] != '\0' && fit->wcsdata.objctdec[0] != '\0') {
 
-		world_cs = siril_world_cs_new_from_objct_ra_dec(gfit.wcsdata.objctra, gfit.wcsdata.objctdec);
+		world_cs = siril_world_cs_new_from_objct_ra_dec(fit->wcsdata.objctra, fit->wcsdata.objctdec);
+
+		update_coordinates(world_cs);
+		unselect_all_items();
+	} else if (fit->wcsdata.crval[0] != 0.0 && fit->wcsdata.crval[1] != 0.0) {
+
+		// first transform coords to alpha and delta
+		world_cs = siril_world_cs_new_from_a_d(fit->wcsdata.crval[0], fit->wcsdata.crval[1]);
 
 		update_coordinates(world_cs);
 		unselect_all_items();
@@ -760,11 +781,14 @@ static void update_gfit(image_solved image, double det, gboolean ask_for_flip) {
 	gfit.wcsdata.equinox = 2000.0;
 	gfit.wcsdata.cdelt[0] = image.resolution / 3600.0;
 	gfit.wcsdata.cdelt[1] = -gfit.wcsdata.cdelt[0];
-	if (det < 0&& !ask_for_flip)
+	if (det < 0 && !ask_for_flip)
 		gfit.wcsdata.cdelt[0] = -gfit.wcsdata.cdelt[0];
 	gfit.wcsdata.crota[0] = gfit.wcsdata.crota[1] = -image.crota;
 	cd_x(&gfit.wcsdata);
 
+	gfit.wcsdata.ra = siril_world_cs_get_alpha(image.image_center);
+	gfit.wcsdata.dec = siril_world_cs_get_delta(image.image_center);
+
 	gchar *ra = siril_world_cs_alpha_format(image.image_center, "%02d %02d %.3lf");
 	gchar *dec = siril_world_cs_delta_format(image.image_center, "%c%02d %02d %.3lf");
 
@@ -782,13 +806,14 @@ static void flip_astrometry_data(fits *fit) {
 	fit->wcsdata.crota[1] = fit->wcsdata.crota[0];
 }
 
-static void print_platesolving_results(Homography H, image_solved image, gboolean *flip_image) {
+static void print_platesolving_results(Homography H, image_solved image, gboolean *flip_image, gboolean downsample) {
 	double rotation, det, scaleX, scaleY;
 	double inliers;
 	gchar *alpha;
 	gchar *delta;
 	char field_x[256] = { 0 };
 	char field_y[256] = { 0 };
+	float factor = (downsample) ? DOWNSAMPLE_FACTOR : 1.0;
 
 	/* Matching information */
 	gchar *str = ngettext("%d pair match.\n", "%d pair matches.\n", H.pair_matched);
@@ -801,7 +826,7 @@ static void print_platesolving_results(Homography H, image_solved image, gboolea
 	/* Plate Solving */
 	scaleX = sqrt(H.h00 * H.h00 + H.h01 * H.h01);
 	scaleY = sqrt(H.h10 * H.h10 + H.h11 * H.h11);
-	image.resolution = (scaleX + scaleY) * 0.5; // we assume square pixels
+	image.resolution = (scaleX + scaleY) * 0.5 * factor; // we assume square pixels
 	siril_log_message(_("Resolution:%*.3lf arcsec/px\n"), 11, image.resolution);
 
 	/* rotation */
@@ -829,7 +854,6 @@ static void print_platesolving_results(Homography H, image_solved image, gboolea
 
 	image.fov.x = get_fov(image.resolution, image.px_size.x);
 	image.fov.y = get_fov(image.resolution, image.px_size.y);
-
 	siril_log_message(_("Focal:%*.2lf mm\n"), 15, image.focal);
 	siril_log_message(_("Pixel size:%*.2lf µm\n"), 10, image.pixel_size);
 	fov_in_DHMS(image.fov.x / 60.0, field_x);
@@ -1142,6 +1166,18 @@ static gboolean end_plate_solver(gpointer p) {
 	struct plate_solver_data *args = (struct plate_solver_data *) p;
 	stop_processing_thread();
 
+	if (args->downsample) {
+		/* copying size of original fits */
+		args->fit->naxes[0] = args->fit_backup->naxes[0];
+		args->fit->naxes[1] = args->fit_backup->naxes[1];
+		args->fit->rx = args->fit->naxes[0];
+		args->fit->ry = args->fit->naxes[1];
+
+		copyfits(args->fit_backup, args->fit, CP_ALLOC | CP_COPYA, -1);
+
+		clearfits(args->fit_backup);
+	}
+
 	if (!args->manual)
 		clear_stars_list();
 	set_cursor_waiting(FALSE);
@@ -1151,13 +1187,12 @@ static gboolean end_plate_solver(gpointer p) {
 				"The image could not be aligned with the reference stars.\n"), "red");
 		if (!args->message) {
 			args->message = g_strdup(_("This is usually because the initial parameters (pixel size, focal length, initial coordinates) "
-					"are too far from the real metadata of the image.\n"
-					"You could also try to look into another catalogue.\n"
+					"are too far from the real metadata of the image.\n\n"
+					"You could also try to look into another catalogue, or try to click on the \"Downsampling\" button, especially for image done with Drizzle.\n\n"
 					"Finally, keep in mind that plate solving algorithm should only be applied on linear image."));
 		}
 		siril_message_dialog(GTK_MESSAGE_ERROR, title, args->message);
 	} else {
-
 		update_image_parameters_GUI();
 		set_GUI_CAMERA();
 		update_coordinates(is_result.image_center);
@@ -1189,14 +1224,19 @@ gpointer match_catalog(gpointer p) {
 	GError *error = NULL;
 	fitted_PSF **cstars;
 	int n_fit = 0, n_cat = 0, n = 0;
-	point image_size = { args->fit->rx, args->fit->ry };
 	Homography H = { 0 };
 	int nobj = AT_MATCH_CATALOG_NBRIGHT;
 
 	args->message = NULL;
 
+	if (args->downsample) {
+		args->fit_backup = calloc(1, sizeof(fits));
+		copyfits(args->fit, args->fit_backup, CP_ALLOC | CP_COPYA | CP_FORMAT, -1);
+		cvResizeGaussian(args->fit, DOWNSAMPLE_FACTOR * args->fit->rx, DOWNSAMPLE_FACTOR * args->fit->ry, OPENCV_AREA);
+	}
+
 	if (!args->manual) {
-		com.stars = peaker(args->fit, 0, &com.starfinder_conf, &n_fit, NULL, FALSE); // TODO: use good layer
+		com.stars = peaker(args->fit, 0, &com.starfinder_conf, &n_fit, NULL, FALSE, FALSE); // TODO: use good layer
 	} else {
 		if (com.stars)
 			while (com.stars[n_fit++]);
@@ -1254,11 +1294,13 @@ gpointer match_catalog(gpointer p) {
 		attempt++;
 	}
 	if (!args->ret) {
+
 		/* we only want to compare with linear function
 		 * Maybe one day we will apply match with homography matrix
 		 */
 		TRANS trans = H_to_linear_TRANS(H);
 		if (check_affine_TRANS_sanity(trans)) {
+			point image_size = { args->fit->rx, args->fit->ry };
 
 			is_result.px_size = image_size;
 			is_result.x = image_size.x / 2.0;
@@ -1267,7 +1309,15 @@ gpointer match_catalog(gpointer p) {
 
 			apply_match(&is_result, trans);
 
-			print_platesolving_results(H, is_result, &(args->flip_image));
+			if (args->downsample) {
+				double inv = 1.0 / DOWNSAMPLE_FACTOR;
+				is_result.px_size.x *= inv;
+				is_result.px_size.y *= inv;
+				is_result.x = is_result.px_size.x / 2.0;
+				is_result.y = is_result.px_size.y / 2.0;
+			}
+
+			print_platesolving_results(H, is_result, &(args->flip_image), args->downsample);
 		} else {
 			args->ret = 1;
 		}
@@ -1315,8 +1365,14 @@ static void start_image_plate_solve() {
  * CALLBACKS FUNCTIONS
  */
 
-void on_GtkEntry_IPS_changed(GtkEditable *editable, gpointer user_data) {
+void on_GtkEntry_IPS_focal_changed(GtkEditable *editable, gpointer user_data) {
 	update_resolution_field();
+	com.pref.focal = g_ascii_strtod(gtk_editable_get_chars(editable, 0, -1), NULL);
+}
+
+void on_GtkEntry_IPS_pixels_changed(GtkEditable *editable, gpointer user_data) {
+	update_resolution_field();
+	com.pref.pitch = g_ascii_strtod(gtk_editable_get_chars(editable, 0, -1), NULL);
 }
 
 void on_GtkEntry_IPS_insert_text(GtkEntry *entry, const gchar *text, gint length,
@@ -1345,8 +1401,7 @@ void on_GtkEntry_IPS_insert_text(GtkEntry *entry, const gchar *text, gint length
 }
 
 void on_info_menu_astrometry_clicked(GtkButton *button, gpointer user_data) {
-	initialize_ips_dialog();
-	siril_open_dialog("ImagePlateSolver_Dial");
+	open_astrometry_dialog();
 }
 
 void on_buttonIPS_close_clicked(GtkButton *button, gpointer user_data) {
@@ -1430,6 +1485,13 @@ void on_GtkCheckButton_OnlineCat_toggled(GtkToggleButton *button,
  * Public functions
  */
 
+void open_astrometry_dialog() {
+	if (single_image_is_loaded() || sequence_is_loaded()) {
+		initialize_ips_dialog();
+		siril_open_dialog("ImagePlateSolver_Dial");
+	}
+}
+
 gchar *search_in_catalogs(const gchar *object) {
 	GString *string_url;
 	gchar *url, *result, *name;
@@ -1482,6 +1544,7 @@ int fill_plate_solver_structure(struct plate_solver_data *args) {
 	args->pixel_size = px_size;
 	args->manual = is_detection_manual();
 	args->flip_image = flip_image_after_ps();
+	args->downsample = is_downsample_activated();
 	args->fit = &gfit;
 
 	return 0;
@@ -1530,3 +1593,20 @@ double get_image_solved_x(image_solved *image) {
 double get_image_solved_y(image_solved *image) {
 	return image->y;
 }
+
+void set_focal_and_pixel_pitch() {
+	GtkEntry *focal, *pitch;
+	gchar *f_str, *p_str;
+
+	focal = GTK_ENTRY(lookup_widget("GtkEntry_IPS_focal"));
+	pitch = GTK_ENTRY(lookup_widget("GtkEntry_IPS_pixels"));
+
+	f_str = g_strdup_printf("%.1lf", com.pref.focal);
+	p_str = g_strdup_printf("%.2lf", com.pref.pitch);
+
+	gtk_entry_set_text(focal, f_str);
+	gtk_entry_set_text(pitch, p_str);
+
+	g_free(f_str);
+	g_free(p_str);
+}
