@@ -28,8 +28,10 @@ struct plate_solver_data {
 	online_catalog onlineCatalog;
 	gchar *catalogStars;
 	gboolean for_photometry_cc;
+	gboolean downsample;
 	double scale; // scale (resolution)
 	fits *fit;
+	fits *fit_backup;
 	gchar *message; // error message
 	int ret; // return value
 	double pixel_size; // pixel size in µm
@@ -37,7 +39,7 @@ struct plate_solver_data {
 	gboolean flip_image;
 };
 
-
+void open_astrometry_dialog();
 gchar *search_in_catalogs(const gchar *object);
 int fill_plate_solver_structure(struct plate_solver_data *args);
 gpointer match_catalog(gpointer p);
@@ -49,6 +51,7 @@ SirilWorldCS *get_image_solved_px_cat_center(image_solved *image);
 SirilWorldCS *get_image_solved_image_center(image_solved *image);
 double get_image_solved_x(image_solved *image);
 double get_image_solved_y(image_solved *image);
+void set_focal_and_pixel_pitch();
 void update_image_center_coord(image_solved *image, gdouble alpha, gdouble delta);
 
 #endif /* SRC_ALGOS_PLATESOLVER_H_ */
