@@ -56,7 +56,7 @@
  * Deactivating this will take less memory and make a faster statistics
  * computation. ngoodpix will be equal to total if deactivated.
  * Set to 0 to deactivate or 1 to activate. */
-#define ACTIVATE_NULLCHECK 0
+#define ACTIVATE_NULLCHECK 1
 
 static void stats_set_default_values(imstats *stat);
 
@@ -111,10 +111,9 @@ float siril_stats_ushort_sd_32(const WORD data[], const int N) {
  * of the absolute deviations from the data's median:
  *  MAD = median (| Xi − median(X) |)
  */
-static double siril_stats_ushort_mad(WORD* data, const size_t n, const double m,
+float siril_stats_ushort_mad(const WORD* data, const size_t n, const double m,
 		gboolean multithread) {
-	size_t i;
-	double mad;
+	float mad;
 	int median = round_to_int(m);	// we use it on integer data anyway
 	WORD *tmp = malloc(n * sizeof(WORD));
 	if (!tmp) {
@@ -123,13 +122,13 @@ static double siril_stats_ushort_mad(WORD* data, const size_t n, const double m,
 	}
 
 #ifdef _OPENMP
-#pragma omp parallel for num_threads(com.max_thread) if(n > 10000) private(i) schedule(static)
+#pragma omp parallel for num_threads(com.max_thread) if(multithread && n > 10000) schedule(static)
 #endif
-	for (i = 0; i < n; i++) {
+	for (size_t i = 0; i < n; i++) {
 		tmp[i] = (WORD)abs(data[i] - median);
 	}
 
-	mad = histogram_median(tmp, n, multithread);
+	mad = (float) histogram_median(tmp, n, multithread);
 	free(tmp);
 	return mad;
 }
@@ -213,14 +212,14 @@ static void siril_stats_ushort_minmax(WORD *min_out, WORD *max_out,
 /* this function tries to get the requested stats from the passed stats,
  * computes them and stores them in it if they have not already been */
 static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *selection,
-		int option, imstats *stats, gboolean multithread) {
+		int option, imstats *stats, int bitpix, gboolean multithread) {
 	int nx, ny;
 	WORD *data = NULL;
 	int stat_is_local = 0, free_data = 0;
 	imstats* stat = stats;
 	// median is included in STATS_BASIC but required to compute other data
 	int compute_median = (option & STATS_BASIC) || (option & STATS_AVGDEV) ||
-		(option & STATS_MAD) || (option & STATS_BWMV);
+		(option & STATS_MAD) || (option & STATS_BWMV) || (option & STATS_IKSS);
 
 	if (!stat) {
 		allocate_stats(&stat);
@@ -252,12 +251,14 @@ static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *sele
 			if (stat_is_local) free(stat);
 			return NULL;
 		}
-		/* First we want to know the normalization value!! */
-		stat->normValue = (fit->bitpix == BYTE_IMG) ? UCHAR_MAX_DOUBLE : USHRT_MAX_DOUBLE;
+	}
+
+	if (stat->normValue == NULL_STATS) {
+		stat->normValue = (bitpix == BYTE_IMG) ? UCHAR_MAX_DOUBLE : USHRT_MAX_DOUBLE;
 	}
 
 	/* Calculation of min and max */
-	if ((option & (STATS_MINMAX | STATS_BASIC)) && (stat->min < 0. || stat->max < 0.)) {
+	if ((option & (STATS_MINMAX | STATS_BASIC)) && (stat->min == NULL_STATS || stat->max == NULL_STATS)) {
 		WORD min = 0, max = 0;
 		if (!data) {
 			if (stat_is_local) free(stat);
@@ -265,14 +266,13 @@ static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *sele
 		}
 		siril_debug_print("- stats %p fit %p (%d): computing minmax\n", stat, fit, layer);
 		siril_stats_ushort_minmax(&min, &max, data, stat->total, multithread);
-
 		stat->min = (double) min;
 		stat->max = (double) max;
 	}
 
 	/* Calculation of ngoodpix, mean, sigma and background noise */
-	if ((option & (STATS_NOISE | STATS_BASIC)) && (stat->ngoodpix <= 0L || stat->mean < 0. ||
-			stat->sigma < 0. || stat->bgnoise < 0.)) {
+	if ((option & (STATS_SIGMEAN | STATS_BASIC)) && (stat->ngoodpix <= 0L || stat->mean == NULL_STATS ||
+		stat->sigma == NULL_STATS || stat->bgnoise == NULL_STATS)) {
 		int status = 0;
 		if (!data) {
 			if (stat_is_local) free(stat);
@@ -288,6 +288,7 @@ static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *sele
 			return NULL;
 		}
 	}
+
 	if (stat->ngoodpix == 0L) {
 		if (free_data) free(data);
 		if (stat_is_local) free(stat);
@@ -296,7 +297,7 @@ static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *sele
 
 	/* we exclude 0 if some computations remain to be done or copy data if
 	 * median has to be computed (this is deactivated in the ngoodpix computation) */
-	if (fit && (compute_median || (option & STATS_IKSS)) && stat->total != stat->ngoodpix) {
+	if (fit && compute_median && stat->total != stat->ngoodpix) {
 		data = reassign_to_non_null_data_ushort(data, stat->total, stat->ngoodpix, free_data);
 		if (!data) {
 			if (stat_is_local) free(stat);
@@ -306,7 +307,7 @@ static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *sele
 	}
 
 	/* Calculation of median */
-	if (compute_median && stat->median < 0.) {
+	if (compute_median && stat->median == NULL_STATS) {
 		if (!data) {
 			if (stat_is_local) free(stat);
 			return NULL;	// not in cache, don't compute
@@ -316,7 +317,7 @@ static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *sele
 	}
 
 	/* Calculation of average absolute deviation from the median */
-	if ((option & STATS_AVGDEV) && stat->avgDev < 0.) {
+	if ((option & STATS_AVGDEV) && stat->avgDev == NULL_STATS) {
 		if (!data) {
 			if (stat_is_local) free(stat);
 			return NULL;	// not in cache, don't compute
@@ -326,7 +327,7 @@ static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *sele
 	}
 
 	/* Calculation of median absolute deviation */
-	if (((option & STATS_MAD) || (option & STATS_BWMV)) && stat->mad < 0.) {
+	if (((option & STATS_MAD) || (option & STATS_BWMV) || (option & STATS_IKSS)) && stat->mad == NULL_STATS) {
 		if (!data) {
 			if (stat_is_local) free(stat);
 			return NULL;	// not in cache, don't compute
@@ -336,7 +337,7 @@ static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *sele
 	}
 
 	/* Calculation of Bidweight Midvariance */
-	if ((option & STATS_BWMV) && stat->sqrtbwmv < 0.) {
+	if ((option & STATS_BWMV) && stat->sqrtbwmv == NULL_STATS) {
 		if (!data) {
 			if (stat_is_local) free(stat);
 			return NULL;	// not in cache, don't compute
@@ -346,8 +347,9 @@ static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *sele
 		stat->sqrtbwmv = sqrt(bwmv);
 	}
 
+
 	/* Calculation of IKSS. Only used for stacking normalization */
-	if ((option & STATS_IKSS) && (stat->location < 0. || stat->scale < 0.)) {
+	if ((option & STATS_IKSS) && (stat->location == NULL_STATS || stat->scale == NULL_STATS)) {
 		if (!data) {
 			if (stat_is_local) free(stat);
 			return NULL;	// not in cache, don't compute
@@ -361,24 +363,26 @@ static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *sele
 			PRINT_ALLOC_ERR;
 			return NULL;
 		}
-
+		double normValue = (fit->bitpix == BYTE_IMG) ? UCHAR_MAX_DOUBLE : USHRT_MAX_DOUBLE;
 		/* we convert in the [0, 1] range */
-		float invertNormValue = (float)(1.0 / stat->normValue);
+		float invertNormValue = (float)(1.0 / normValue);
 #ifdef _OPENMP
 #pragma omp parallel for num_threads(com.max_thread) if (multithread) private(i) schedule(static)
 #endif
 		for (i = 0; i < stat->ngoodpix; i++) {
 			newdata[i] = (float) data[i] * invertNormValue;
 		}
-		if (IKSS(newdata, stat->ngoodpix, &stat->location, &stat->scale, multithread)) {
+		float med = (float)(stat->median) * invertNormValue;
+		float mad = (float)(stat->mad) * invertNormValue;
+		if (IKSSlite(newdata, stat->ngoodpix, med, mad, &stat->location, &stat->scale, multithread)) {
 			if (stat_is_local) free(stat);
 			if (free_data) free(data);
 			free(newdata);
 			return NULL;
 		}
 		/* go back to the original range */
-		stat->location *= stat->normValue;
-		stat->scale *= stat->normValue;
+		stat->location *= normValue;
+		stat->scale *= normValue;
 		free(newdata);
 	}
 
@@ -386,14 +390,16 @@ static imstats* statistics_internal_ushort(fits *fit, int layer, rectangle *sele
 	return stat;
 }
 
-static imstats* statistics_internal(fits *fit, int layer, rectangle *selection, int option, imstats *stats, gboolean multithread) {
+static imstats* statistics_internal(fits *fit, int layer, rectangle *selection, int option, imstats *stats, int bitpix, gboolean multithread) {
 	if (fit) {
 		if (fit->type == DATA_USHORT)
-			return statistics_internal_ushort(fit, layer, selection, option, stats, multithread);
+			return statistics_internal_ushort(fit, layer, selection, option, stats, bitpix, multithread);
 		if (fit->type == DATA_FLOAT)
-			return statistics_internal_float(fit, layer, selection, option, stats, multithread);
+			return statistics_internal_float(fit, layer, selection, option, stats, bitpix, multithread);
 	}
-	return statistics_internal_ushort(fit, layer, selection, option, stats, multithread);
+	if (bitpix == FLOAT_IMG)
+		return statistics_internal_float(fit, layer, selection, option, stats, bitpix, multithread);
+	return statistics_internal_ushort(fit, layer, selection, option, stats, bitpix, multithread);
 }
 
 /* Computes statistics on the given layer of the given opened image.
@@ -414,14 +420,14 @@ imstats* statistics(sequence *seq, int image_index, fits *fit, int layer, rectan
 	imstats *oldstat = NULL, *stat;
 	if (selection && selection->h > 0 && selection->w > 0) {
 		// we have a selection, don't store anything
-		return statistics_internal(fit, layer, selection, option, NULL, multithread);
+		return statistics_internal(fit, layer, selection, option, NULL, fit->bitpix, multithread);
 	} else if (!seq || image_index < 0) {
 		// we have a single image, store in the fits
 		if (fit->stats && fit->stats[layer]) {
 			oldstat = fit->stats[layer];
 			atomic_int_incref(oldstat->_nb_refs);
 		}
-		stat = statistics_internal(fit, layer, NULL, option, oldstat, multithread);
+		stat = statistics_internal(fit, layer, NULL, option, oldstat, fit->bitpix, multithread);
 		if (!stat) {
 			fprintf(stderr, "- stats failed for fit %p (%d)\n", fit, layer);
 			if (oldstat) {
@@ -440,7 +446,7 @@ imstats* statistics(sequence *seq, int image_index, fits *fit, int layer, rectan
 			if (oldstat)	// can be NULL here
 				atomic_int_incref(oldstat->_nb_refs);
 		}
-		stat = statistics_internal(fit, layer, NULL, option, oldstat, multithread);
+		stat = statistics_internal(fit, layer, NULL, option, oldstat, seq->bitpix, multithread);
 		if (!stat) {
 			if (fit)
 				fprintf(stderr, "- stats failed for %d in seq (%d)\n",
@@ -616,7 +622,7 @@ void full_stats_invalidation_from_fit(fits *fit) {
 static void stats_set_default_values(imstats *stat) {
 	stat->total = -1L;
 	stat->ngoodpix = -1L;
-	stat->mean = stat->avgDev = stat->median = stat->sigma = stat->bgnoise = stat->min = stat->max = stat->normValue = stat->mad = stat->sqrtbwmv = stat->location = stat->scale = -1.0;
+	stat->mean = stat->avgDev = stat->median = stat->sigma = stat->bgnoise = stat->min = stat->max = stat->normValue = stat->mad = stat->sqrtbwmv = stat->location = stat->scale = NULL_STATS;
 }
 
 /* allocates an imstat structure and initializes it with default values that
@@ -692,17 +698,17 @@ static int stat_image_hook(struct generic_seq_args *args, int o, int i, fits *fi
 		int new_index = i * s_args->seq->nb_layers;
 
 		if (fit->type == DATA_USHORT) {
-			if (s_args->option == STATS_BASIC) {
-				s_args->list[new_index + layer] = g_strdup_printf("%d\t%d\t%e\t%e\t%e\t%e\t%e\t%e\n",
-						i + 1,
-						layer,
-						stat->mean / USHRT_MAX_DOUBLE,
-						stat->median / USHRT_MAX_DOUBLE,
-						stat->sigma / USHRT_MAX_DOUBLE,
-						stat->min / USHRT_MAX_DOUBLE,
-						stat->max / USHRT_MAX_DOUBLE,
-						stat->bgnoise / USHRT_MAX_DOUBLE
-				);
+			if (s_args->option == (STATS_BASIC)) {
+			 	s_args->list[new_index + layer] = g_strdup_printf("%d\t%d\t%e\t%e\t%e\t%e\t%e\t%e\n",
+			 			i + 1,
+			 			layer,
+			 			stat->mean / USHRT_MAX_DOUBLE,
+			 			stat->median / USHRT_MAX_DOUBLE,
+			 			stat->sigma / USHRT_MAX_DOUBLE,
+			 			stat->min / USHRT_MAX_DOUBLE,
+			 			stat->max / USHRT_MAX_DOUBLE,
+			 			stat->bgnoise / USHRT_MAX_DOUBLE
+			 	);
 			} else {
 				s_args->list[new_index + layer] = g_strdup_printf("%d\t%d\t%e\t%e\t%e\t%e\t%e\t%e\t%e\t%e\t%e\n",
 						i + 1,
@@ -719,17 +725,17 @@ static int stat_image_hook(struct generic_seq_args *args, int o, int i, fits *fi
 				);
 			}
 		} else {
-			if (s_args->option == STATS_BASIC) {
-				s_args->list[new_index + layer] = g_strdup_printf("%d\t%d\t%e\t%e\t%e\t%e\t%e\t%e\n",
-						i + 1,
-						layer,
-						stat->mean,
-						stat->median,
-						stat->sigma,
-						stat->min,
-						stat->max,
-						stat->bgnoise
-				);
+			if (s_args->option == (STATS_BASIC)) {
+			 	s_args->list[new_index + layer] = g_strdup_printf("%d\t%d\t%e\t%e\t%e\t%e\t%e\t%e\n",
+			 			i + 1,
+			 			layer,
+			 			stat->mean,
+			 			stat->median,
+			 			stat->sigma,
+			 			stat->min,
+			 			stat->max,
+			 			stat->bgnoise
+			 	);
 			} else {
 				s_args->list[new_index + layer] = g_strdup_printf("%d\t%d\t%e\t%e\t%e\t%e\t%e\t%e\t%e\t%e\t%e\n",
 						i + 1,
@@ -773,7 +779,7 @@ static int stat_finalize_hook(struct generic_seq_args *args) {
 		return 1;
 	}
 	const gchar *header;
-	if (s_args->option == STATS_BASIC) {
+	if (s_args->option == (STATS_BASIC)) {
 		header = "image\tchan\tmean\tmedian\tsigma\tmin\tmax\tnoise\n";
 	} else {
 		header = "image\tchan\tmean\tmedian\tsigma\tmin\tmax\tnoise\tavgDev\tmad\tsqrtbwmv\n";
@@ -837,10 +843,3 @@ void on_menu_gray_stat_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	siril_open_dialog("StatWindow");
 	set_cursor_waiting(FALSE);
 }
-
-void on_info_menu_statistics_clicked(GtkButton *button, gpointer user_data) {
-	set_cursor_waiting(TRUE);
-	computeStat();
-	siril_open_dialog("StatWindow");
-	set_cursor_waiting(FALSE);
-}
