@@ -150,9 +150,6 @@ void on_filechooser_file_set(GtkFileChooserButton *widget, gpointer user_data);
 /********************************************************/
 
 /* the compositing menu callback */
-void on_menu_compositing_activate(GtkMenuItem *menuitem, gpointer user_data) {
-	open_compositing_window();
-}
 
 /* creates a new row with all widgets and bindings at the row index in the
  * layers grid. Indices start at 0, but row 0 holds only one label, and row 1 is
@@ -499,7 +496,7 @@ void on_filechooser_file_set(GtkFileChooserButton *widget, gpointer user_data) {
 							layers[layer]->the_fit.ry, gfit.rx, gfit.ry);
 						sprintf(buf, _("OK upscaled from %ux%u"),
 								layers[layer]->the_fit.rx, layers[layer]->the_fit.ry);
-						cvResizeGaussian(&layers[layer]->the_fit, gfit.rx, gfit.ry, OPENCV_LINEAR); // BILINEAR
+						cvResizeGaussian(&layers[layer]->the_fit, gfit.rx, gfit.ry, OPENCV_AREA);
 						gtk_label_set_text(layers[layer]->label, buf);
 						gtk_widget_set_tooltip_text(GTK_WIDGET(layers[layer]->label), _("Image loaded, and upscaled"));
 				}
@@ -562,7 +559,7 @@ void on_filechooser_file_set(GtkFileChooserButton *widget, gpointer user_data) {
 		set_cutoff_sliders_values();
 		set_display_mode();
 		redraw(com.cvport, REMAP_ALL);
-		
+
 		sequence_list_change_current();
 	}
 	else {
@@ -667,6 +664,7 @@ float get_normalized_pixel_value(int fits_index, float layer_pixel_value) {
 	double tmp = (double)layer_pixel_value;
 	if (!has_fit(0))
 		fits_index--;
+
 	tmp *= coeff->scale[fits_index];
 	tmp -= coeff->offset[fits_index];
 	return tmp;
