@@ -27,6 +27,7 @@ int	process_ddp(int nb);
 int	process_entropy(int nb);
 int	process_exit(int nb);
 int	process_extract(int nb);
+int	process_extractGreen(int nb);
 int	process_extractHa(int nb);
 int	process_extractHaOIII(int nb);
 
@@ -103,6 +104,7 @@ int	process_set_cpu(int nb);
 #endif
 int	process_set_ext(int nb);
 int	process_seq_extractHa(int nb);
+int	process_seq_extractGreen(int nb);
 int	process_seq_extractHaOIII(int nb);
 int	process_set_findstar(int nb);
 int	process_set_mag(int nb);
