@@ -95,20 +95,29 @@ static int readinitfile() {
 	/* Preprocessing settings */
 	config_setting_t *prepro_setting = config_lookup(&config, keywords[PRE]);
 	if (prepro_setting) {
-		const char *bias = NULL, *dark = NULL, *flat = NULL;
+		const char *bias = NULL, *bias_synth = NULL, *dark = NULL, *flat = NULL;
 
 		config_setting_lookup_bool(prepro_setting, "cfa", &com.pref.prepro_cfa);
 		config_setting_lookup_bool(prepro_setting, "equalize_cfa", &com.pref.prepro_equalize_cfa);
 		config_setting_lookup_bool(prepro_setting, "fix_xtrans", &com.pref.fix_xtrans);
+
 		config_setting_lookup_string(prepro_setting, "bias_lib", &bias);
 		com.pref.prepro_bias_lib = g_strdup(bias);
 		config_setting_lookup_bool(prepro_setting, "use_bias_lib", &com.pref.use_bias_lib);
+
+
+		config_setting_lookup_string(prepro_setting, "bias_synth", &bias_synth);
+		com.pref.prepro_bias_synth = g_strdup(bias_synth);
+		config_setting_lookup_bool(prepro_setting, "use_bias_synth", &com.pref.use_bias_synth);
+
 		config_setting_lookup_string(prepro_setting, "dark_lib", &dark);
 		com.pref.prepro_dark_lib = g_strdup(dark);
 		config_setting_lookup_bool(prepro_setting, "use_dark_lib", &com.pref.use_dark_lib);
+
 		config_setting_lookup_string(prepro_setting, "flat_lib", &flat);
 		com.pref.prepro_flat_lib = g_strdup(flat);
 		config_setting_lookup_bool(prepro_setting, "use_flat_lib", &com.pref.use_flat_lib);
+
 		prepro_setting = config_lookup(&config, "prepro-settings.xtrans_af");
 		if (prepro_setting != NULL) {
 			com.pref.xtrans_af.x = config_setting_get_int_elem(prepro_setting, 0);
@@ -157,10 +166,10 @@ static int readinitfile() {
 	/* FITS compression setting */
 	config_setting_t *comp_setting = config_lookup(&config, keywords[CMP]);
 	if (comp_setting) {
-		config_setting_lookup_bool(comp_setting, "fits_enabled", &com.pref.comp.fits_enabled);
-		config_setting_lookup_int(comp_setting, "fits_method", &com.pref.comp.fits_method);
-		config_setting_lookup_float(comp_setting, "fits_quantization", &com.pref.comp.fits_quantization);
-		config_setting_lookup_float(comp_setting, "fits_hcompress_scale", &com.pref.comp.fits_hcompress_scale);
+		config_setting_lookup_bool(comp_setting, "compress_enabled", &com.pref.comp.fits_enabled);
+		config_setting_lookup_int(comp_setting, "compress_method", &com.pref.comp.fits_method);
+		config_setting_lookup_float(comp_setting, "compress_quantization", &com.pref.comp.fits_quantization);
+		config_setting_lookup_float(comp_setting, "compress_hcompress_scale", &com.pref.comp.fits_hcompress_scale);
 	}
 
 	/* Astrometry setting */
@@ -225,6 +234,12 @@ static int readinitfile() {
 		if (config_setting_lookup_bool(misc_setting, "rgb_aladin", &com.pref.rgb_aladin) == CONFIG_FALSE) {
 			com.pref.rgb_aladin = FALSE;
 		}
+		if (config_setting_lookup_float(misc_setting, "focal", &com.pref.focal) == CONFIG_FALSE) {
+			com.pref.focal = 1000.0;
+		}
+		if (config_setting_lookup_float(misc_setting, "pitch", &com.pref.pitch) == CONFIG_FALSE) {
+			com.pref.pitch = 5.0;
+		}
 		config_setting_lookup_int(misc_setting, "thumbnail_size", &com.pref.thumbnail_size);
 		config_setting_lookup_int(misc_setting, "theme", &com.pref.combo_theme);
 		config_setting_lookup_string(misc_setting, "lang", &lang);
@@ -361,6 +376,11 @@ static void _save_preprocessing(config_t *config, config_setting_t *root) {
 	prepro_setting = config_setting_add(prepro_group, "use_bias_lib", CONFIG_TYPE_BOOL);
 	config_setting_set_bool(prepro_setting, com.pref.use_bias_lib);
 
+	prepro_setting = config_setting_add(prepro_group, "bias_synth", CONFIG_TYPE_STRING);
+	config_setting_set_string(prepro_setting, com.pref.prepro_bias_synth);
+	prepro_setting = config_setting_add(prepro_group, "use_bias_synth", CONFIG_TYPE_BOOL);
+	config_setting_set_bool(prepro_setting, com.pref.use_bias_synth);
+
 	prepro_setting = config_setting_add(prepro_group, "dark_lib", CONFIG_TYPE_STRING);
 	config_setting_set_string(prepro_setting, com.pref.prepro_dark_lib);
 	prepro_setting = config_setting_add(prepro_group, "use_dark_lib", CONFIG_TYPE_BOOL);
@@ -425,16 +445,16 @@ static void _save_comp(config_t *config, config_setting_t *root) {
 
 	cmp_group = config_setting_add(root, keywords[CMP], CONFIG_TYPE_GROUP);
 
-	cmp_setting = config_setting_add(cmp_group, "fits_enabled", CONFIG_TYPE_BOOL);
+	cmp_setting = config_setting_add(cmp_group, "compress_enabled", CONFIG_TYPE_BOOL);
 	config_setting_set_bool(cmp_setting, com.pref.comp.fits_enabled);
 
-	cmp_setting = config_setting_add(cmp_group, "fits_method", CONFIG_TYPE_INT);
+	cmp_setting = config_setting_add(cmp_group, "compress_method", CONFIG_TYPE_INT);
 	config_setting_set_int(cmp_setting, com.pref.comp.fits_method);
 
-	cmp_setting = config_setting_add(cmp_group, "fits_quantization", CONFIG_TYPE_FLOAT);
+	cmp_setting = config_setting_add(cmp_group, "compress_quantization", CONFIG_TYPE_FLOAT);
 	config_setting_set_float(cmp_setting, com.pref.comp.fits_quantization);
 
-	cmp_setting = config_setting_add(cmp_group, "fits_hcompress_scale", CONFIG_TYPE_FLOAT);
+	cmp_setting = config_setting_add(cmp_group, "compress_hcompress_scale", CONFIG_TYPE_FLOAT);
 	config_setting_set_float(cmp_setting, com.pref.comp.fits_hcompress_scale);
 
 }
@@ -532,6 +552,13 @@ static void _save_misc(config_t *config, config_setting_t *root) {
 	misc_setting = config_setting_add(misc_group, "remember_winpos", CONFIG_TYPE_BOOL);
 	config_setting_set_bool(misc_setting, com.pref.remember_windows);
 
+	misc_setting = config_setting_add(misc_group, "focal", CONFIG_TYPE_FLOAT);
+	config_setting_set_float(misc_setting, com.pref.focal);
+
+	misc_setting = config_setting_add(misc_group, "pitch", CONFIG_TYPE_FLOAT);
+	config_setting_set_float(misc_setting, com.pref.pitch);
+
+
 	misc_setting = config_setting_add(misc_group, "scripts_paths", CONFIG_TYPE_LIST);
 	while (list) {
 		config_setting_set_string_elem(misc_setting, -1, (char *)list->data);
