@@ -70,7 +70,8 @@ static float evaluateNoiseOfCalibratedImage(fits *fit, fits *dark,
 	}
 
 	for (chan = 0; chan < fit->naxes[2]; chan++) {
-		imstats *stat = statistics(NULL, -1, &fit_tmp, chan, &area, STATS_BASIC, FALSE);
+		/* STATS_SIGMEAN computes mean and normvalue */
+		imstats *stat = statistics(NULL, -1, &fit_tmp, chan, &area, STATS_SIGMEAN, FALSE);
 		if (!stat) {
 			siril_log_message(_("Error: statistics computation failed.\n"));
 			return -1.0;
@@ -124,7 +125,9 @@ static int preprocess(fits *raw, struct preprocessing_data *args) {
 	int ret = 0;
 
 	if (args->use_bias) {
-		ret = imoper(raw, args->bias, OPER_SUB, args->allow_32bit_output);
+		if (args->bias_level < FLT_MAX) { // an offset level has been defined
+			ret = soper(raw, args->bias_level, OPER_SUB, args->allow_32bit_output);
+		} else ret = imoper(raw, args->bias, OPER_SUB, args->allow_32bit_output);
 	}
 
 	/* if dark optimization, the master-dark has already been subtracted */
@@ -159,7 +162,7 @@ static int darkOptimization(fits *raw, struct preprocessing_data *args) {
 	fits dark_tmp = { 0 };
 
 	if (memcmp(raw->naxes, dark->naxes, sizeof raw->naxes)) {
-		siril_log_message(_("imoper: images must have same dimensions\n"));
+		siril_log_color_message(_("Images must have same dimensions\n"), "red");
 		return 1;
 	}
 
@@ -289,8 +292,8 @@ static int prepro_image_hook(struct generic_seq_args *args, int out_index, int i
 	}
 
 	if (prepro->debayer) {
-		// not for SER because it is done on-the-fly
-		if (!prepro->seq || prepro->seq->type == SEQ_REGULAR || prepro->seq->type == SEQ_FITSEQ) {
+		// debayering SER is now allowed - https://gitlab.com/free-astro/siril/-/issues/549	
+		if (!prepro->seq || prepro->seq->type == SEQ_REGULAR || prepro->seq->type == SEQ_FITSEQ || prepro->seq->type == SEQ_SER ) {
 			debayer_if_needed(TYPEFITS, fit, TRUE);
 		}
 
@@ -342,22 +345,22 @@ gpointer prepro_worker(gpointer p) {
 
 void start_sequence_preprocessing(struct preprocessing_data *prepro) {
 	struct generic_seq_args *args = create_default_seqargs(prepro->seq);
-	args->force_float = !com.pref.force_to_16bit;
+	args->force_float = !com.pref.force_to_16bit && prepro->output_seqtype != SEQ_SER;
 	args->compute_size_hook = prepro_compute_size_hook;
 	args->prepare_hook = prepro_prepare_hook;
 	args->image_hook = prepro_image_hook;
 	args->finalize_hook = prepro_finalize_hook;
 	args->description = _("Preprocessing");
 	args->has_output = TRUE;
-	// float output is always used in case of FITS sequence
-	args->output_type = (args->force_ser_output || com.pref.force_to_16bit ||
-			(args->seq->type == SEQ_SER && !args->force_fitseq_output)) ?
-		DATA_USHORT : DATA_FLOAT;
 	args->new_seq_prefix = prepro->ppprefix;
 	args->load_new_sequence = TRUE;
 	args->force_ser_output = prepro->seq->type != SEQ_SER && prepro->output_seqtype == SEQ_SER;
 	args->force_fitseq_output = prepro->seq->type != SEQ_FITSEQ && prepro->output_seqtype == SEQ_FITSEQ;
 	args->user = prepro;
+	// float output is always used in case of FITS sequence
+	args->output_type = (args->force_ser_output || com.pref.force_to_16bit ||
+			(args->seq->type == SEQ_SER && !args->force_fitseq_output)) ?
+		DATA_USHORT : DATA_FLOAT;
 
 	remove_prefixed_sequence_files(prepro->seq, prepro->ppprefix);
 
@@ -419,9 +422,42 @@ int preprocess_single_image(struct preprocessing_data *args) {
 	return ret;
 }
 
-static void test_for_master_files(struct preprocessing_data *args) {
+int evaluateoffsetlevel(const char* expression) {
+	// try to find an occurence of *
+	// If none -> the level is just an integer to evaluate
+	// If found -> Try to find $ sign to read the offset value and its multiplier
+
+	gchar *expressioncpy = g_strdup(expression);
+	gchar *mulsignpos = g_strrstr (expressioncpy, (gchar*)"*");
+	int offsetlevel, multiplier;
+	if (!mulsignpos) {
+		offsetlevel = g_ascii_strtoull(expressioncpy, NULL, 10);
+		if (!offsetlevel) goto free_on_error;
+		if (expressioncpy) g_free(expressioncpy);
+		return offsetlevel;
+	}
+	mulsignpos[0] = '\0';
+	mulsignpos += 1;
+	if (!((expressioncpy[0] == '$') || (mulsignpos[0] == '$'))) goto free_on_error; //found a * char but none of the words start with a $
+	if (expressioncpy[0] == '$') {
+		multiplier = g_ascii_strtoull(mulsignpos, NULL, 10);
+	} else {
+		multiplier = g_ascii_strtoull(expressioncpy, NULL, 10);
+	}
+	if (!multiplier) goto free_on_error; // multiplier not parsed
+	offsetlevel = (int)(multiplier * gfit.key_offset);
+	if (expressioncpy) g_free(expressioncpy);
+	return offsetlevel;
+free_on_error:
+	if (expressioncpy) g_free(expressioncpy);
+	return 0;
+}
+
+static gboolean test_for_master_files(struct preprocessing_data *args) {
 	GtkToggleButton *tbutton;
 	GtkEntry *entry;
+	gboolean has_error = FALSE;
+	args->bias_level = FLT_MAX;
 
 	tbutton = GTK_TOGGLE_BUTTON(lookup_widget("useoffset_button"));
 	if (gtk_toggle_button_get_active(tbutton)) {
@@ -432,25 +468,44 @@ static void test_for_master_files(struct preprocessing_data *args) {
 			gtk_toggle_button_set_active(tbutton, FALSE);
 		} else {
 			const char *error = NULL;
-			set_progress_bar_data(_("Opening offset image..."), PROGRESS_NONE);
-			args->bias = calloc(1, sizeof(fits));
-			if (!readfits(filename, args->bias, NULL, !com.pref.force_to_16bit)) {
-				if (args->bias->naxes[2] != gfit.naxes[2]) {
-					error = _("NOT USING OFFSET: number of channels is different");
-				} else if (args->bias->naxes[0] != gfit.naxes[0] ||
-						args->bias->naxes[1] != gfit.naxes[1]) {
-					error = _("NOT USING OFFSET: image dimensions are different");
+            if (filename[0] == '=') { // offset is specified as a level not a file
+			    set_progress_bar_data(_("Checking offset level..."), PROGRESS_NONE);
+				int offsetlevel = evaluateoffsetlevel(filename + 1);
+				if (!offsetlevel) {
+					error = _("NOT USING OFFSET: the offset value could not be parsed");
+					args->use_bias = FALSE;
 				} else {
-					args->use_bias = TRUE;
+					siril_log_message(_("Synthetic offset: Level = %d\n"),offsetlevel);
+					int maxlevel = (gfit.orig_bitpix == BYTE_IMG) ? UCHAR_MAX : USHRT_MAX;
+					if ((offsetlevel > maxlevel) || (offsetlevel < -maxlevel) ) {   // not excluding all neg values here to allow defining a pedestal
+						error = _("NOT USING OFFSET: the offset value is not consistent with image bitdepth");
+						args->use_bias = FALSE;
+					} else {
+						args->bias_level = (float)offsetlevel * INV_USHRT_MAX_SINGLE; //converting to [0 1] to use with soper
+						args->use_bias = TRUE;
+					}
 				}
-
-			} else error = _("NOT USING OFFSET: cannot open the file\n");
+            } else {
+				args->bias = calloc(1, sizeof(fits));
+				set_progress_bar_data(_("Opening offset image..."), PROGRESS_NONE);
+				if (!readfits(filename, args->bias, NULL, !com.pref.force_to_16bit)) {
+					if (args->bias->naxes[2] != gfit.naxes[2]) {
+						error = _("NOT USING OFFSET: number of channels is different");
+					} else if (args->bias->naxes[0] != gfit.naxes[0] ||
+							args->bias->naxes[1] != gfit.naxes[1]) {
+						error = _("NOT USING OFFSET: image dimensions are different");
+					} else {
+						args->use_bias = TRUE;
+					}
+				} else error = _("NOT USING OFFSET: cannot open the file");
+			}
 			if (error) {
-				siril_log_message("%s\n", error);
+				siril_log_color_message("%s\n", "red", error);
 				set_progress_bar_data(error, PROGRESS_DONE);
 				free(args->bias);
 				gtk_entry_set_text(entry, "");
 				args->use_bias = FALSE;
+				has_error = TRUE;
 			}
 		}
 	}
@@ -476,13 +531,14 @@ static void test_for_master_files(struct preprocessing_data *args) {
 					args->use_dark = TRUE;
 				}
 
-			} else error = _("NOT USING DARK: cannot open the file\n");
+			} else error = _("NOT USING DARK: cannot open the file");
 			if (error) {
-				siril_log_message("%s\n", error);
+				siril_log_color_message("%s\n", "red", error);
 				set_progress_bar_data(error, PROGRESS_DONE);
 				free(args->dark);
 				gtk_entry_set_text(entry, "");
 				args->use_dark = FALSE;
+				has_error = TRUE;
 			}
 		}
 
@@ -532,13 +588,14 @@ static void test_for_master_files(struct preprocessing_data *args) {
 					args->use_flat = TRUE;
 				}
 
-			} else error = _("NOT USING FLAT: cannot open the file\n");
+			} else error = _("NOT USING FLAT: cannot open the file");
 			if (error) {
-				siril_log_message("%s\n", error);
+				siril_log_color_message("%s\n", "red", error);
 				set_progress_bar_data(error, PROGRESS_DONE);
 				free(args->flat);
 				gtk_entry_set_text(entry, "");
 				args->use_flat = FALSE;
+				has_error = TRUE;
 			}
 
 			if (args->use_flat) {
@@ -551,6 +608,7 @@ static void test_for_master_files(struct preprocessing_data *args) {
 			}
 		}
 	}
+	return has_error;
 }
 
 void on_prepro_button_clicked(GtkButton *button, gpointer user_data) {
@@ -569,7 +627,10 @@ void on_prepro_button_clicked(GtkButton *button, gpointer user_data) {
 	GtkComboBox *output_type = GTK_COMBO_BOX(lookup_widget("prepro_output_type_combo"));
 
 	struct preprocessing_data *args = calloc(1, sizeof(struct preprocessing_data));
-	test_for_master_files(args);	// sets most properties
+	if (test_for_master_files(args)) {
+		siril_log_color_message(_("Some errors have been detected, Please check the logs.\n"), "red");
+		return;
+	}
 	if (!args->use_bias && !args->use_dark && !args->use_flat)
 		return;
 
