@@ -43,7 +43,7 @@ int readpic(const char *name, fits *fit);
 /****************** image_formats_libraries.h ******************/
 #ifdef HAVE_LIBTIFF
 int readtif(const char *name, fits *fit, gboolean force_float);
-int savetif(const char *name, fits *fit, uint16 bitspersample);
+int savetif(const char *name, fits *fit, uint16_t bitspersample);
 #endif
 
 #ifdef HAVE_LIBJPEG
@@ -89,6 +89,7 @@ WORD *float_buffer_to_ushort(float *buffer, size_t ndata);
 float *uchar_buffer_to_float(BYTE *buffer, size_t ndata);
 float *ushort_buffer_to_float(WORD *buffer, size_t ndata);
 float *ushort8_buffer_to_float(WORD *buffer, size_t ndata);
+gboolean test_double_eq(double a, double b, double epsilon);
 uint16_t change_endianness16(uint16_t x);
 uint16_t cpu_to_le16(uint16_t x);
 uint16_t cpu_to_be16(uint16_t x);
