@@ -63,8 +63,8 @@
 #define SHRT_MAX_SINGLE ((float)SHRT_MAX)
 #define UCHAR_MAX_DOUBLE ((double)UCHAR_MAX)
 #define UCHAR_MAX_SINGLE ((float)UCHAR_MAX)
-#define INV_USHRT_MAX_SINGLE .000015259022f	// 1/255
-#define INV_UCHAR_MAX_SINGLE .0039215686f	// 1/65535
+#define INV_USHRT_MAX_SINGLE .000015259022f	 // 1/65535
+#define INV_UCHAR_MAX_SINGLE .0039215686f	 // 1/255
 
 #define BYTES_IN_A_MB 1048576	// 1024
 
@@ -165,6 +165,7 @@ typedef enum {
 				// the loaded sequence
 
 #define MAX_STARS 200000		// maximum length of com.stars
+#define MAX_STARS_FITTED 2000   // maximum number of stars fitted for registration
 
 #define INDEX_MAX 100000		// maximum index for images
 
@@ -195,7 +196,7 @@ typedef struct save_config_struct save_config;
 /* global structures */
 
 typedef enum {
-	NORMAL_DISPLAY,	
+	LINEAR_DISPLAY,	
 	LOG_DISPLAY,
 	SQRT_DISPLAY,
 	SQUARED_DISPLAY,
@@ -239,8 +240,8 @@ typedef enum {
 typedef enum {
 	OPENCV_NEAREST = 0,
 	OPENCV_LINEAR = 1,
-	OPENCV_AREA = 2,
-	OPENCV_CUBIC = 3,
+	OPENCV_CUBIC = 2,
+	OPENCV_AREA = 3,
 	OPENCV_LANCZOS4 = 4,
 	OPENCV_INTER_MAX = 7
 } opencv_interpolation;
@@ -262,7 +263,7 @@ struct layer_info_struct {
 	WORD lo, hi;			// the values of the cutoff sliders
 	//WORD min, max;		// the min and max values of the sliders
 	gboolean cut_over, cut_under;	// display values over hi or under lo as negative
-	display_mode rendering_mode;	// defaults to NORMAL_DISPLAY
+	display_mode rendering_mode;	// defaults to LINEAR_DISPLAY
 };
 
 typedef enum { SEQ_REGULAR, SEQ_SER, SEQ_FITSEQ,
@@ -364,6 +365,8 @@ struct wcs_struct {
 	double crota[2];
 	char objctra[FLEN_VALUE];
 	char objctdec[FLEN_VALUE];
+	double ra;
+	double dec;
 };
 
 struct dft_struct {
@@ -414,6 +417,7 @@ struct ffit {
 	/* data obtained from FITS or RAW files */
 	double focal_length, iso_speed, exposure, aperture, ccd_temp;
 	double cvf; // Conversion factor (e-/adu)
+	int key_gain, key_offset; // Gain, Offset values read in camera headers.
 
 	/* Plate Solving data */
 	wcs_info wcsdata;	// data from the header
@@ -449,7 +453,7 @@ struct libraw_config {
 	int auto_mul, use_camera_wb, use_auto_wb;		// White Balance parameters
 	int user_qual;						// Index of the Matrix interpolation set in dcraw, 0: bilinear, 1: VNG, 2: PPG, 3: AHD
 	int user_black;						// black point correction
-	double gamm[2];						// Gamma correction
+	double gamm[3];						// Gamma correction
 };
 
 /* This structure is used for storing all parameters used in photometry module */
@@ -476,7 +480,8 @@ struct stack_config {
 	double sigma_low, sigma_high;
 	double linear_low, linear_high;
 	double percentile_low, percentile_high;
-	enum { RATIO, AMOUNT, UNLIMITED } mem_mode; // mode of memory management
+	double esdt_outliers, esdt_significance;
+	enum { RATIO, AMOUNT } mem_mode; // mode of memory management
 	double memory_ratio;			// ratio of available memory to use for stacking (and others)
 	double memory_amount;			// amount of memory in GB to use for stacking (and others)
 };
@@ -513,8 +518,13 @@ struct historic_struct {
 
 struct star_finder_struct {
 	int radius;
+	int adj_radius;
+	gboolean adjust;
 	double sigma;
 	double roundness;
+
+	/** internal variable **/
+	gboolean no_guess; // TRUE means no guess about resolution
 };
 
 struct save_config_struct {
@@ -542,6 +552,8 @@ struct pref_struct {
 	rectangle xtrans_sample; // if no xtrans model found, use these values
 	gchar *prepro_bias_lib;
 	gboolean use_bias_lib;
+	gchar *prepro_bias_synth;
+	gboolean use_bias_synth;
 	gchar *prepro_dark_lib;
 	gboolean use_dark_lib;
 	gchar *prepro_flat_lib;
@@ -563,6 +575,9 @@ struct pref_struct {
 	gchar *swap_dir;		// swap directory
 	GSList *script_path;	// script path directories
 
+	gdouble focal;			// focal length saved in config file
+	gdouble pitch;			// pixel pitch saved in config file
+
 	libraw raw_set;			// the libraw settings
 	struct debayer_config debayer;	// debayer settings
 	phot phot_set;          // photometry settings
@@ -594,7 +609,6 @@ struct cominf {
 	int surface_height[MAXVPORT];	// allocated height
 	cairo_surface_t *surface[MAXVPORT];
 	gboolean buf_is_dirty[MAXVPORT];// dirtyness of each buffer (= need to redraw)
-	GdkPixbuf *siril_pix; // Siril.svg image loaded at initialization
 
 	/* Color map */
 	color_map color;
