@@ -34,6 +34,7 @@
 #ifdef _WIN32
 #include <windows.h>
 #endif
+#include <glib.h>
 
 #include "core/siril.h"
 #include "core/proto.h"
@@ -46,6 +47,10 @@
 #include "gui/progress_and_log.h"
 #include "io/single_image.h"
 
+#if GLIB_CHECK_VERSION(2,68,0)
+#define g_memdup g_memdup2
+#endif
+
 /**
  * Round double value to an integer
  * @param x value to round
@@ -329,6 +334,17 @@ float *ushort8_buffer_to_float(WORD *buffer, size_t ndata) {
 	return buf;
 }
 
+/**
+ * Test equality between two double number
+ * @param a
+ * @param b
+ * @param epsilon
+ * @return
+ */
+gboolean test_double_eq(double a, double b, double epsilon) {
+	return (fabs(a - b) <= epsilon);
+}
+
 /**
  * change endianness of a 16 bit unsigned int
  * @param x value to convert
