@@ -33,6 +33,7 @@
 #include "core/OS_utils.h"
 #include "algos/siril_wcs.h"
 #include "algos/star_finder.h"
+#include "algos/plateSolver.h"
 #include "io/conversion.h"
 #include "io/films.h"
 #include "io/image_format_fits.h"
@@ -44,6 +45,7 @@
 #include "preferences.h"
 #include "image_display.h"
 #include "image_interactions.h"
+#include "single_image.h"
 #include "callbacks.h"
 #include "utils.h"
 #include "plot.h"
@@ -56,13 +58,14 @@
 #include "fix_xtrans_af.h"
 #include "siril_intro.h"
 #include "siril_preview.h"
+#include "siril-window.h"
 
 layer_info predefined_layers_colors[] = {
 	/* name, lambda, lo, hi, c/over, c/under, mode */
-	{ N_("Luminance"), 0.0, 0, 0, FALSE, FALSE, NORMAL_DISPLAY }, // no color, undefined value is <0
-	{ N_("Red"), 650.0, 0, 0, FALSE, FALSE, NORMAL_DISPLAY }, // approx. of the middle of the color
-	{ N_("Green"), 530.0, 0, 0, FALSE, FALSE, NORMAL_DISPLAY },	// approx. of the middle of the color
-	{ N_("Blue"), 450.0, 0, 0, FALSE, FALSE, NORMAL_DISPLAY }// approx. of the middle of the color
+	{ N_("Luminance"), 0.0, 0, 0, FALSE, FALSE, LINEAR_DISPLAY }, // no color, undefined value is <0
+	{ N_("Red"), 650.0, 0, 0, FALSE, FALSE, LINEAR_DISPLAY }, // approx. of the middle of the color
+	{ N_("Green"), 530.0, 0, 0, FALSE, FALSE, LINEAR_DISPLAY },	// approx. of the middle of the color
+	{ N_("Blue"), 450.0, 0, 0, FALSE, FALSE, LINEAR_DISPLAY }// approx. of the middle of the color
 };
 
 /*****************************************************************************
@@ -277,7 +280,7 @@ void set_display_mode() {
 	}
 
 	vport = com.cvport;
-	if (com.cvport ==  RGB_VPORT) vport = GREEN_VPORT;
+	if (com.cvport == RGB_VPORT) vport = GREEN_VPORT;
 	if (single_image_is_loaded() && vport < com.uniq->nb_layers && com.uniq->layers
 			&& com.seq.current != RESULT_IMAGE)
 		mode = com.uniq->layers[vport].rendering_mode;
@@ -345,92 +348,60 @@ void set_icon_entry(GtkEntry *entry, gchar *string) {
 }
 
 void update_MenuItem() {
+	GtkApplicationWindow *app_win = GTK_APPLICATION_WINDOW(lookup_widget("control_window"));
 	gboolean is_a_single_image_loaded;		/* An image is loaded. Not a sequence or only the result of stacking process */
 	gboolean is_a_singleRGB_image_loaded;	/* A RGB image is loaded. Not a sequence or only the result of stacking process */
 	gboolean any_image_is_loaded;			/* Something is loaded. Single image or Sequence */
-	char *str;
-
-	is_a_singleRGB_image_loaded = isrgb(&gfit) && (!sequence_is_loaded()
-			|| (sequence_is_loaded() && (com.seq.current == RESULT_IMAGE
-					|| com.seq.current == SCALED_IMAGE)));
-
-	is_a_single_image_loaded = single_image_is_loaded()	&& (!sequence_is_loaded()
-			|| (sequence_is_loaded() && (com.seq.current == RESULT_IMAGE
-					|| com.seq.current == SCALED_IMAGE)));
 
+	is_a_single_image_loaded = single_image_is_loaded()	&& (!sequence_is_loaded() || (sequence_is_loaded() && (com.seq.current == RESULT_IMAGE || com.seq.current == SCALED_IMAGE)));
+	is_a_singleRGB_image_loaded = isrgb(&gfit) && single_image_is_loaded();
 	any_image_is_loaded = single_image_is_loaded() || sequence_is_loaded();
 
-	/* toolbar button */
-	gtk_widget_set_sensitive(lookup_widget("header_precision_button"), any_image_is_loaded);
+	/* some toolbar buttons */
 	gtk_widget_set_sensitive(lookup_widget("toolbarbox"), any_image_is_loaded);
-#ifdef HAVE_WCSLIB
-	gtk_widget_set_sensitive(lookup_widget("annotate_button"), any_image_is_loaded && has_wcs(&gfit));
-#else
-	gtk_widget_set_sensitive(lookup_widget("annotate_button"), FALSE);
-#endif
-	gtk_widget_set_sensitive(lookup_widget("header_undo_button"), is_undo_available());
-	if (is_undo_available()) {
-		str = g_strdup_printf(_("Undo: \"%s\""), com.history[com.hist_display - 1].history);
-		gtk_widget_set_tooltip_text(lookup_widget("header_undo_button"), str);
-		g_free(str);
-	}
-	else gtk_widget_set_tooltip_text(lookup_widget("header_undo_button"), _("Nothing to undo"));
-	gtk_widget_set_sensitive(lookup_widget("header_redo_button"), is_redo_available());
-	if (is_redo_available()) {
-		str = g_strdup_printf(_("Redo: \"%s\""), com.history[com.hist_display].history);
-		gtk_widget_set_tooltip_text(lookup_widget("header_redo_button"), str);
-		g_free(str);
-	}
-	else gtk_widget_set_tooltip_text(lookup_widget("header_redo_button"), _("Nothing to redo"));
-	/* File Menu */
-	gtk_widget_set_sensitive(lookup_widget("header_save_as_button"), any_image_is_loaded);
-	gtk_widget_set_sensitive(lookup_widget("header_save_button"), is_a_single_image_loaded && com.uniq->fileexist);
-	gtk_widget_set_sensitive(lookup_widget("header_snapshot_button"), any_image_is_loaded);
-	gtk_widget_set_sensitive(lookup_widget("info_menu_headers"), any_image_is_loaded && gfit.header != NULL);
-	gtk_widget_set_sensitive(lookup_widget("menu_gray_header"), any_image_is_loaded && gfit.header != NULL);
-	gtk_widget_set_sensitive(lookup_widget("info_menu_informations"), any_image_is_loaded);
+
+	GAction *action_annotate = g_action_map_lookup_action(G_ACTION_MAP(app_win), "annotate-object");
+	g_simple_action_set_enabled(G_SIMPLE_ACTION (action_annotate), any_image_is_loaded && has_wcs(&gfit));
+
+	/* undo and redo */
+	GAction *action_undo = g_action_map_lookup_action(G_ACTION_MAP(app_win), "undo");
+	GAction *action_redo = g_action_map_lookup_action(G_ACTION_MAP(app_win), "redo");
+	g_simple_action_set_enabled(G_SIMPLE_ACTION (action_undo), is_undo_available());
+	g_simple_action_set_enabled(G_SIMPLE_ACTION (action_redo), is_redo_available());
+
+	set_undo_redo_tooltip();
+
+	/* save and save as */
+	GAction *action_save = g_action_map_lookup_action (G_ACTION_MAP(gtk_window_get_application(GTK_WINDOW(app_win))), "save");
+	GAction *action_save_as = g_action_map_lookup_action (G_ACTION_MAP(gtk_window_get_application(GTK_WINDOW(app_win))), "save-as");
+	g_simple_action_set_enabled(G_SIMPLE_ACTION(action_save), is_a_single_image_loaded && com.uniq->fileexist);
+	g_simple_action_set_enabled(G_SIMPLE_ACTION(action_save_as), any_image_is_loaded);
+
+	/* fits header */
+	GAction *action_fits_header = g_action_map_lookup_action (G_ACTION_MAP(app_win), "fits-header");
+	g_simple_action_set_enabled(G_SIMPLE_ACTION(action_fits_header), any_image_is_loaded && gfit.header != NULL);
 
 	/* Image processing Menu */
-	gtk_widget_set_sensitive(lookup_widget("removegreen"), is_a_singleRGB_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_satu"), is_a_singleRGB_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menu_negative"), any_image_is_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitemcalibration"), is_a_singleRGB_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitemphotometriccalibration"), is_a_singleRGB_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menu_channel_separation"), is_a_singleRGB_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menu_slpitcfa"), any_image_is_loaded && !isrgb(&gfit));
-	gtk_widget_set_sensitive(lookup_widget("menuitem_histo"), any_image_is_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_asinh"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_fixbanding"), any_image_is_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_cosmetic"), any_image_is_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_fft"), TRUE);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_deconvolution"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_resample"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_rotation"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_rotation90"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_rotation270"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_mirrorx"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_mirrory"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_background_extraction"), any_image_is_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_wavelets"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menu_wavelet_separation"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_medianfilter"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_rgradient"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menuitem_clahe"), is_a_single_image_loaded);
-	gtk_widget_set_sensitive(lookup_widget("menu_linearmatch"), is_a_single_image_loaded);
+
+	/* single RGB image is needed */
+	siril_window_enable_rgb_proc_actions(app_win, is_a_singleRGB_image_loaded);
+	/* any image is needed */
+	siril_window_enable_any_proc_actions(app_win, any_image_is_loaded);
+	/* any mono image is needed */
+	siril_window_enable_any_mono_proc_actions(app_win, any_image_is_loaded && !isrgb(&gfit));
+	/* only single image needed */
+	siril_window_enable_single_proc_actions(app_win, is_a_single_image_loaded);
+	/* no images needed */
+	siril_window_enable_none_proc_actions(app_win, TRUE);
 
 	/* Image information menu */
-	gtk_widget_set_sensitive(lookup_widget("info_menu_noise_estimation"), any_image_is_loaded);
-	gtk_widget_set_sensitive(lookup_widget("info_menu_statistics"), any_image_is_loaded);
-	gtk_widget_set_sensitive(lookup_widget("info_menu_astrometry"), any_image_is_loaded);
-	gtk_widget_set_sensitive(lookup_widget("info_menu_dynamic_psf"), any_image_is_loaded);
+	siril_window_enable_image_actions(app_win, any_image_is_loaded);
 }
 
 void sliders_mode_set_state(sliders_mode sliders) {
 	GtkToggleButton *radiobutton;	// Must not be static
-	gchar *str[] =
-	{ "radiobutton_hilo", "radiobutton_minmax", "radiobutton_user" };
-	void *func[] = { on_radiobutton_hilo_toggled, on_radiobutton_minmax_toggled,
-		on_radiobutton_user_toggled };
+	gchar *str[] = { "radiobutton_hilo", "radiobutton_minmax", "radiobutton_user" };
+	void *func[] = { on_radiobutton_hilo_toggled, on_radiobutton_minmax_toggled, on_radiobutton_user_toggled };
 
 	radiobutton = GTK_TOGGLE_BUTTON(lookup_widget(str[sliders]));
 
@@ -439,8 +410,8 @@ void sliders_mode_set_state(sliders_mode sliders) {
 	g_signal_handlers_unblock_by_func(radiobutton, func[sliders], NULL);
 }
 
-static display_mode get_display_mode_from_menu(GtkMenu *menu) {
-	GtkWidget *w = gtk_menu_get_active(menu);
+display_mode get_display_mode_from_menu() {
+	GtkWidget *w = gtk_menu_get_active(GTK_MENU(lookup_widget("menu_display")));
 	if (w == lookup_widget("log_item"))
 		return LOG_DISPLAY;
 	else if (w == lookup_widget("square_root_item"))
@@ -454,7 +425,7 @@ static display_mode get_display_mode_from_menu(GtkMenu *menu) {
 	else if (w == lookup_widget("histo_item"))
 		return HISTEQ_DISPLAY;
 	else
-		return NORMAL_DISPLAY;
+		return LINEAR_DISPLAY;
 }
 
 /* When rendering settings are chained, they need to be copied to other layers
@@ -471,7 +442,6 @@ static display_mode get_display_mode_from_menu(GtkMenu *menu) {
 int copy_rendering_settings_when_chained(gboolean from_GUI) {
 	static GtkToggleButton *chainedbutton = NULL;
 	static GtkRange *range_lo = NULL, *range_hi = NULL;
-	static GtkMenu *display_menu = NULL;
 	static GtkToggleButton *cutmax = NULL;
 
 	gboolean is_chained;
@@ -483,7 +453,6 @@ int copy_rendering_settings_when_chained(gboolean from_GUI) {
 
 	if (!chainedbutton) {	// init widgets
 		chainedbutton = GTK_TOGGLE_BUTTON(lookup_widget("checkbutton_chain"));
-		display_menu = GTK_MENU(lookup_widget("menu_display"));
 		range_lo = GTK_RANGE(gtk_builder_get_object(builder, "scalemin"));
 		range_hi = GTK_RANGE(gtk_builder_get_object(builder, "scalemax"));
 		cutmax = GTK_TOGGLE_BUTTON(
@@ -507,10 +476,10 @@ int copy_rendering_settings_when_chained(gboolean from_GUI) {
 		return 0;
 
 	if (from_GUI) {
-		int raw_mode = get_display_mode_from_menu(display_menu);//gtk_combo_box_get_active(modecombo);
+		int raw_mode = get_display_mode_from_menu();
 		/* update values in the layer_info for cvport */
 		layers[cvport].rendering_mode =
-			raw_mode >= 0 ? raw_mode : NORMAL_DISPLAY;
+			raw_mode >= 0 ? raw_mode : LINEAR_DISPLAY;
 		layers[cvport].lo = round_to_WORD(gtk_range_get_value(range_lo));
 		layers[cvport].hi = round_to_WORD(gtk_range_get_value(range_hi));
 		layers[cvport].cut_over = gtk_toggle_button_get_active(cutmax);
@@ -661,8 +630,8 @@ void update_display_fwhm() {
 	if (com.selection.w && com.selection.h) {// Now we don't care about the size of the sample. Minimization checks that
 		if (com.selection.w < 300 && com.selection.h < 300) {
 			double roundness;
-			double fwhm_val = psf_get_fwhm(&gfit, com.cvport, &roundness);
-			g_sprintf(fwhm_buffer, _("fwhm: %.2f, r: %.2f"), fwhm_val, roundness);
+			double fwhm_val = psf_get_fwhm(&gfit, com.cvport, &com.selection, &roundness);
+			g_sprintf(fwhm_buffer, _("fwhm: %.2f px, r: %.2f"), fwhm_val, roundness);
 		} else
 			g_sprintf(fwhm_buffer, _("fwhm: N/A"));
 	} else {
@@ -812,22 +781,28 @@ void set_layers_for_registration() {
 		gtk_combo_box_set_active(GTK_COMBO_BOX(cbbt_layers), reminder);
 }
 
-void show_data_dialog(char *text, char *title, gchar *url) {
+void show_data_dialog(char *text, char *title, gchar *parent, gchar *url) {
 	GtkTextView *tv = GTK_TEXT_VIEW(lookup_widget("data_txt"));
 	GtkTextBuffer *tbuf = gtk_text_view_get_buffer(tv);
 	GtkTextIter itDebut;
 	GtkTextIter itFin;
+	GtkWindow *win = GTK_WINDOW(lookup_widget("data_dialog"));
 
 	gtk_text_buffer_get_bounds(tbuf, &itDebut, &itFin);
 	gtk_text_buffer_delete(tbuf, &itDebut, &itFin);
 	gtk_text_buffer_set_text(tbuf, text, strlen(text));
-	gtk_window_set_title(GTK_WINDOW(lookup_widget("data_dialog")), title);
+	gtk_window_set_title(win, title);
 
 	gtk_widget_show(lookup_widget("data_dialog"));
 	gtk_widget_set_visible(lookup_widget("data_extra_button"), url != NULL);
 	if (url) {
 		gtk_link_button_set_uri((GtkLinkButton *)lookup_widget("data_extra_button"), url);
 	}
+	if (parent) {
+		gtk_window_set_transient_for(win, GTK_WINDOW(lookup_widget(parent)));
+	} else {
+		gtk_window_set_transient_for(win, GTK_WINDOW(lookup_widget("control_window")));
+	}
 }
 
 /**
@@ -863,6 +838,12 @@ void initialize_FITS_name_entries() {
 		}
 	}
 
+	if (com.pref.prepro_bias_synth) {
+		if (com.pref.use_bias_synth) {
+			str[0] = g_strdup_printf("%s", com.pref.prepro_bias_synth);
+		}
+	}
+
 	if (com.pref.prepro_dark_lib && (g_file_test(com.pref.prepro_dark_lib, G_FILE_TEST_EXISTS))) {
 		if (com.pref.use_dark_lib) {
 			str[1] = g_strdup_printf("%s", com.pref.prepro_dark_lib);
@@ -975,85 +956,76 @@ void update_spinCPU(int max) {
  *             I N I T I A L I S A T I O N      F U N C T I O N S            *
  ****************************************************************************/
 
-#define MAX_ACCELS 5
-static void add_accelerator_va(GtkApplication *app, const gchar *action_name,
-		const gchar *first_accel, va_list *args) {
-	const gchar *vaccels[MAX_ACCELS];
-
-	const gchar *next_element = first_accel;
-	int i = 0;
-	while (next_element && i < MAX_ACCELS - 1) {
-		vaccels[i++] = next_element;
-		next_element = va_arg(*args, gchar*);
-	}
-	vaccels[i] = NULL;
-	gtk_application_set_accels_for_action(app, action_name, vaccels);
-}
-
-static void add_accelerator(GtkApplication *app, const gchar *action_name,
-		const gchar *first_accel, ...) {
-	va_list args;
-
-	va_start(args, first_accel);
-	add_accelerator_va(app, action_name, first_accel, &args);
-	va_end(args);
-}
-
 static void load_accels() {
+	static const gchar * const accelmap[] = {
+		"app.quit",                   "<Primary>q", NULL,
+		"app.preferences",            "<Primary>p", NULL,
+		"app.open",                   "<Primary>o", NULL,
+		"app.save",                   "<Primary>s", NULL,
+		"app.save-as",                "<Primary><Shift>s", NULL,
+
+		"win.undo",                   "<Primary>z", NULL,
+		"win.redo",                   "<Primary><Shift>z", NULL,
+		"win.close",                  "<Primary>w", NULL,
+		"win.cwd",                    "<Primary>d", NULL,
+		"win.full-screen",            "<Primary>f", NULL,
+
+		"win.conversion",             "F1", NULL,
+		"win.sequence",               "F2", NULL,
+		"win.prepro",                 "F3", NULL,
+		"win.registration",           "F4", NULL,
+		"win.plot",                   "F5", NULL,
+		"win.stacking",               "F6", NULL,
+		"win.logs",                   "F7", NULL,
+
+		"win.hide-show-toolbar",      "<Primary>T", NULL,
+
+		"win.zoom-out",               "<Primary>minus", "<Primary>KP_Subtract", NULL,
+		"win.zoom-in",                "<Primary>plus", "<Primary>KP_Add", NULL,
+		"win.zoom-fit",               "<Primary>0", NULL,
+
+		"win.search-object",          "<Primary>slash", NULL,
+		"win.astrometry",             "<Primary><Shift>a", NULL,
+		"win.pickstar",               "<Primary>space", NULL,
+
+		"win.negative-processing",    "<Primary>i", NULL,
+		"win.rotation90-processing",  "<Primary>Right", NULL,
+		"win.rotation270-processing", "<Primary>Left", NULL,
+		"win.mirrorx-processing",     "<Primary>Up", NULL,
+		"win.mirrory-processing",     "<Primary>Down", NULL,
+
+		NULL /* Terminating NULL */
+	};
+
+	set_accel_map(accelmap);
+}
+
+void set_accel_map(const gchar * const *accelmap) {
 	GApplication *application = g_application_get_default();
 
-	add_accelerator(GTK_APPLICATION(application), "app.quit", "<Primary>Q", (const char *)NULL );
-	add_accelerator(GTK_APPLICATION(application), "app.preferences", "<Primary>P", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.open", "<Primary>O", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.undo", "<Primary>Z", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.redo", "<Primary><Shift>Z", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.save", "<Primary>S", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.save_as", "<Primary><Shift>S", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.close", "<Primary>W", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.cwd", "<Primary>D", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.full_screen", "<Primary>F", (const char *)NULL);
-
-	add_accelerator(GTK_APPLICATION(application), "app.conversion", "F1", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.sequence", "F2", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.prepro", "F3", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.registration", "F4", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.plot", "F5", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.stacking", "F6", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.logs", "F7", (const char *)NULL);
-
-	add_accelerator(GTK_APPLICATION(application), "app.hide_show_toolbar", "<Primary>T", (const char *)NULL);
-
-	add_accelerator(GTK_APPLICATION(application), "app.zoom_out", "<Primary>minus", "<Primary>KP_Subtract", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.zoom_in", "<Primary>plus", "<Primary>KP_Add", (const char *)NULL);
-	add_accelerator(GTK_APPLICATION(application), "app.zoom_fit", "<Primary>0", (const char *)NULL);
-
-	add_accelerator(GTK_APPLICATION(application), "app.search_object", "<Primary>slash", (const char *)NULL);
+	for (const gchar *const *it = accelmap; it[0]; it += g_strv_length((gchar**) it) + 1) {
+		gtk_application_set_accels_for_action(GTK_APPLICATION(application), it[0], &it[1]);
+	}
 }
 
 /* Initialize the combobox when loading new single_image */
 void initialize_display_mode() {
-	static GtkMenu *display_menu = NULL;
 	static GtkToggleButton *chainedbutton = NULL;
 	display_mode mode;
 	int i;
 
-	if (!display_menu) {
-		display_menu = GTK_MENU(lookup_widget("menu_display"));
-	}
-	int raw_mode = get_display_mode_from_menu(display_menu);
-
+	int raw_mode = get_display_mode_from_menu();
 
 	/* Check if never initialized. In this case the mode is set to linear */
 	if (raw_mode == -1)
-		mode = NORMAL_DISPLAY;
+		mode = LINEAR_DISPLAY;
 	else
 		mode = raw_mode;
 	/* The mode is applyed for each layer */
-	if (single_image_is_loaded() && com.cvport < com.uniq->nb_layers
-			&& com.seq.current != RESULT_IMAGE) {
+	if (single_image_is_loaded() && com.seq.current != RESULT_IMAGE) {
 		for (i = 0; i < com.uniq->nb_layers; i++)
 			com.uniq->layers[i].rendering_mode = mode;
-	} else if (sequence_is_loaded() && com.cvport < com.seq.nb_layers) {
+	} else if (sequence_is_loaded()) {
 		for (i = 0; i < com.seq.nb_layers; i++)
 			com.seq.layers[i].rendering_mode = mode;
 	}
@@ -1112,9 +1084,8 @@ void set_GUI_misc() {
 	memory_amount = GTK_SPIN_BUTTON(lookup_widget("spinbutton_mem_amount"));
 	gtk_spin_button_set_value(memory_amount, com.pref.stack.memory_amount);
 
-	GtkToggleButton *modes[3] = { GTK_TOGGLE_BUTTON(lookup_widget("memfreeratio_radio")),
-		GTK_TOGGLE_BUTTON(lookup_widget("memfixed_radio")),
-		GTK_TOGGLE_BUTTON(lookup_widget("memunlimited_radio")) };
+	GtkToggleButton *modes[2] = { GTK_TOGGLE_BUTTON(lookup_widget("memfreeratio_radio")),
+		GTK_TOGGLE_BUTTON(lookup_widget("memfixed_radio"))};
 	gtk_toggle_button_set_active(modes[com.pref.stack.mem_mode], TRUE);
 
 	/* initialization of default FITS extension and type */
@@ -1244,12 +1215,15 @@ void initialize_all_GUI(gchar *supported_files) {
 	/* initialize theme */
 	initialize_theme_GUI();
 
+	/* map all actions for main window */
+	siril_window_map_actions(GTK_APPLICATION_WINDOW(lookup_widget("control_window")));
+
 	/* initialize menu gui */
 	update_MenuItem();
 	initialize_script_menu();
 
-	/* initialize command completion */
-	init_completion_command();
+	/* initialize command processor */
+	init_command();
 
 	/* initialize preprocessing */
 	initialize_preprocessing();
@@ -1263,6 +1237,9 @@ void initialize_all_GUI(gchar *supported_files) {
 	/* set all preferences button in the dialog */
 	set_preferences_dialog_from_global();
 
+	/* set focal and pixel pitch */
+	set_focal_and_pixel_pitch();
+
 	initialize_FITS_name_entries();
 
 	initialize_log_tags();
@@ -1277,6 +1254,8 @@ void initialize_all_GUI(gchar *supported_files) {
 			GTK_DEST_DEFAULT_MOTION, drop_types, G_N_ELEMENTS(drop_types),
 			GDK_ACTION_COPY);
 
+	siril_drag_single_image_set_dest();
+
 	set_GUI_CWD();
 	siril_log_message(_("Default FITS extension is set to %s\n"), com.pref.ext);
 
@@ -1431,14 +1410,6 @@ void on_cosmEnabledCheck_toggled(GtkToggleButton *button, gpointer user_data) {
 	gtk_widget_set_sensitive(evaluateButton, is_active);
 }
 
-void on_info_menu_headers_clicked(GtkButton *button, gpointer user_data) {
-	show_FITS_header(&gfit);
-}
-
-void on_menu_gray_header_activate(GtkMenuItem *menuitem, gpointer user_data) {
-	show_FITS_header(&gfit);
-}
-
 void on_focal_entry_changed(GtkEditable *editable, gpointer user_data) {
 	const gchar* focal_entry = gtk_entry_get_text(GTK_ENTRY(editable));
 	gfit.focal_length = g_ascii_strtod(focal_entry, NULL);
@@ -1481,10 +1452,6 @@ void on_combobinning_changed(GtkComboBox *box, gpointer user_data) {
 	drawPlot();
 }
 
-void on_info_menu_informations_clicked(GtkButton *button, gpointer user_data) {
-	siril_open_dialog("file_information");
-}
-
 void on_file_information_close_clicked(GtkButton *button, gpointer user_data) {
 	gtk_widget_hide(lookup_widget("file_information"));
 }
@@ -1521,17 +1488,16 @@ void save_main_window_state() {
 	if (!com.script && com.pref.remember_windows) {
 		if (!main_w)
 			main_w = lookup_widget("control_window");
-		com.pref.main_w_pos = get_window_position(GTK_WINDOW(main_w));
-		com.pref.is_maximized = gtk_window_is_maximized(GTK_WINDOW(main_w));
+		com.pref.main_w_pos = get_window_position(GTK_WINDOW(GTK_APPLICATION_WINDOW(main_w)));
+		com.pref.is_maximized = gtk_window_is_maximized(GTK_WINDOW(GTK_APPLICATION_WINDOW(main_w)));
 	}
 }
 
 void load_main_window_state() {
 	GtkWidget *win = lookup_widget("control_window");
-	GdkRectangle workarea = {0};
-	gdk_monitor_get_workarea(
-	    gdk_display_get_primary_monitor(gdk_display_get_default()),
-	    &workarea);
+	GdkRectangle workarea = { 0 };
+
+	gdk_monitor_get_workarea(gdk_display_get_primary_monitor(gdk_display_get_default()), &workarea);
 
 	int w = com.pref.main_w_pos.w;
 	int h = com.pref.main_w_pos.h;
@@ -1541,10 +1507,10 @@ void load_main_window_state() {
 
 	if (com.pref.remember_windows && w > 0 && h > 0) {
 		if (com.pref.is_maximized) {
-			gtk_window_maximize(GTK_WINDOW(win));
+			gtk_window_maximize(GTK_WINDOW(GTK_APPLICATION_WINDOW(win)));
 		} else {
-			gtk_window_move(GTK_WINDOW(win), x, y);
-			gtk_window_resize(GTK_WINDOW(win), w, h);
+			gtk_window_move(GTK_WINDOW(GTK_APPLICATION_WINDOW(win)), x, y);
+			gtk_window_resize(GTK_WINDOW(GTK_APPLICATION_WINDOW(win)), w, h);
 		}
 	}
 }
@@ -1608,22 +1574,6 @@ void on_radiobutton_user_toggled(GtkToggleButton *togglebutton,
 	}
 }
 
-void on_neg_button_toggled(GtkToggleToolButton *togglebutton,
-		gpointer user_data) {
-	set_cursor_waiting(TRUE);
-	redraw(com.cvport, REMAP_ALL);
-	redraw_previews();
-	set_cursor_waiting(FALSE);
-}
-
-void on_colormap_button_toggled(GtkToggleToolButton *togglebutton,
-		gpointer user_data) {
-	set_cursor_waiting(TRUE);
-	redraw(com.cvport, REMAP_ALL);
-	redraw_previews();
-	set_cursor_waiting(FALSE);
-}
-
 void on_checkchain_toggled(GtkToggleButton *togglebutton, gpointer user_data) {
 	if (copy_rendering_settings_when_chained(FALSE))
 		redraw(com.cvport, REMAP_ALL);
