@@ -283,8 +283,10 @@ static void adjust_histogram_vport_size() {
 }
 
 size_t get_histo_size(fits *fit) {
-	if (fit->type == DATA_USHORT)
-		return (size_t)get_normalized_value(fit);
+	if (fit->type == DATA_USHORT) {
+		if (fit->orig_bitpix == BYTE_IMG)
+			return UCHAR_MAX;
+	}
 	return (size_t)USHRT_MAX;
 }
 
@@ -943,28 +945,20 @@ void on_histoToolAutoStretch_clicked(GtkToolButton *button, gpointer user_data)
 	set_cursor_waiting(FALSE);
 }
 
-void on_menuitem_histo_activate(GtkMenuItem *menuitem, gpointer user_data) {
-	set_cursor_waiting(TRUE);
-
-	siril_open_dialog("histogram_dialog");
-	set_cursor_waiting(FALSE);
-}
-
-void toggle_histogram_window_visibility(GtkToolButton *button, gpointer user_data) {
-	if (gtk_widget_get_visible((GtkWidget *)user_data)) {
+void toggle_histogram_window_visibility() {
+	if (gtk_widget_get_visible(lookup_widget("histogram_dialog"))) {
 		set_cursor_waiting(TRUE);
 		reset_cursors_and_values();
 		histo_close(TRUE);
 		set_cursor_waiting(FALSE);
 		siril_close_dialog("histogram_dialog");
 	} else {
-		on_menuitem_histo_activate(NULL, NULL);
+		siril_open_dialog("histogram_dialog");
 	}
 }
 
 gboolean on_drawingarea_histograms_motion_notify_event(GtkWidget *widget, GdkEventMotion *event,
 		gpointer user_data) {
-
 	int width = get_width_of_histo();
 	int height = get_height_of_histo();
 
