@@ -192,8 +192,7 @@ static void remap(int vport) {
 			return;
 		}
 	}
-	inverted = gtk_toggle_tool_button_get_active(
-			GTK_TOGGLE_TOOL_BUTTON(lookup_widget("neg_button")));
+	inverted = gtk_toggle_tool_button_get_active(GTK_TOGGLE_TOOL_BUTTON(lookup_widget("neg_button")));
 
 	if (single_image_is_loaded() && com.seq.current != RESULT_IMAGE) {
 		mode = com.uniq->layers[vport].rendering_mode;
@@ -279,8 +278,7 @@ static void remap(int vport) {
 	fsrc = gfit.fpdata[vport];
 	dst = com.graybuf[vport];
 
-	color = gtk_toggle_tool_button_get_active(
-			GTK_TOGGLE_TOOL_BUTTON(lookup_widget("colormap_button")));
+	color = gtk_toggle_tool_button_get_active(GTK_TOGGLE_TOOL_BUTTON(lookup_widget("colormap_button")));
 
 	if (color == RAINBOW_COLOR)
 		make_index_for_rainbow(rainbow_index);
@@ -348,7 +346,7 @@ static int make_index_for_current_display(display_mode mode, WORD lo, WORD hi,
 
 	/* initialization of data required to build the remap_index */
 	switch (mode) {
-		case NORMAL_DISPLAY:
+		case LINEAR_DISPLAY:
 			slope = UCHAR_MAX_SINGLE / (float) (hi - lo);
 			break;
 		case LOG_DISPLAY:
@@ -407,7 +405,7 @@ static int make_index_for_current_display(display_mode mode, WORD lo, WORD hi,
 				// asinh(2.78*10^110) = 255
 				index[i] = round_to_BYTE(asinhf((float) i / 1000.f) * slope); //1000.f is arbitrary: good matching with ds9, could be asinhf(a*Q*i)/Q
 				break;
-			case NORMAL_DISPLAY:
+			case LINEAR_DISPLAY:
 				index[i] = round_to_BYTE((float) i * slope);
 				break;
 			case STF_DISPLAY:
@@ -454,20 +452,36 @@ static int make_index_for_rainbow(BYTE index[][3]) {
 }
 
 static void draw_empty_image(const draw_data_t* dd) {
+	static GdkPixbuf *siril_pix = NULL;
 	cairo_t *cr = dd->cr;
 	guint width = dd->window_width;
 	guint height = dd->window_height;
+	guint pix_size = height / 3;
+	guint offset;
+#ifdef SIRIL_UNSTABLE
+	offset = 32;
+#else
+	offset = 2;
+#endif
 
 	cairo_rectangle(cr, 0, 0, width, height);
 	cairo_fill(cr);
 
-	int pix_w = gdk_pixbuf_get_width(com.siril_pix);
-	int pix_h = gdk_pixbuf_get_height(com.siril_pix);
+	/* Create pixbuf from siril.svg file */
+	if (siril_pix == NULL) {
+		gchar *image = g_build_filename(siril_get_system_data_dir(), "pixmaps", "siril.svg", NULL);
+		siril_pix = gdk_pixbuf_new_from_file_at_size(image, 256, 256, NULL);
+		g_free(image);
+	}
 
-	gdk_cairo_set_source_pixbuf(cr, com.siril_pix, (width - pix_w) / 2, (height - pix_h) / 2);
+	GdkPixbuf *pixbuf = gdk_pixbuf_scale_simple(siril_pix, pix_size, pix_size, GDK_INTERP_BILINEAR);
+
+	gdk_cairo_set_source_pixbuf(cr, pixbuf, (width - pix_size) / 2, (height - pix_size) / offset);
 	cairo_paint(cr);
 	cairo_fill(cr);
 
+	g_object_unref(pixbuf);
+
 #ifdef SIRIL_UNSTABLE
 	{
 		GtkWidget *widget = lookup_widget("drawingareargb");
@@ -483,7 +497,7 @@ static void draw_empty_image(const draw_data_t* dd) {
 		layout = gtk_widget_create_pango_layout(widget, NULL);
 
 		msg = g_strdup_printf(_("<big>Unstable Development Version</big>\n\n"
-				"<small>commit <tt>%s</tt></small>\n\n"
+				"<small>commit <tt>%s</tt></small>\n"
 				"<small>Please test bugs against "
 				"latest git master branch\n"
 				"before reporting them.</small>"),
@@ -502,7 +516,7 @@ static void draw_empty_image(const draw_data_t* dd) {
 		gdk_cairo_set_source_rgba(cr, &color);
 
 		cairo_move_to(cr, (allocation.width - (w * scale)) / 2,
-				(allocation.height - (h * scale)) / 2 - pix_h);
+				(allocation.height - (h * scale)) / 2);
 
 		cairo_scale(cr, scale, scale);
 
@@ -511,6 +525,7 @@ static void draw_empty_image(const draw_data_t* dd) {
 		g_object_unref(layout);
 	}
 #endif /* SIRIL_UNSTABLE */
+
 }
 
 static void draw_vport(const draw_data_t* dd) {
@@ -582,12 +597,7 @@ static void draw_stars(const draw_data_t* dd) {
 		cairo_set_line_width(cr, 1.5 / dd->zoom);
 
 		while (com.stars[i]) {
-			double size = com.stars[i]->fwhmx;
-			if (com.stars[i]->units[0] == '\"') {
-				size = convert_single_fwhm_to_pixels(com.stars[i]->fwhmx, com.stars[i]->sx);
-			}
-			size *= 2; // in order to be sure to contain stars
-
+			double size = com.stars[i]->fwhmx * 2.0;
 			if (i == com.selected_star) {
 				// We draw horizontal and vertical lines to show the star
 				cairo_set_line_width(cr, 2.0 / dd->zoom);
@@ -619,11 +629,7 @@ static void draw_stars(const draw_data_t* dd) {
 			cairo_set_line_width(cr, 2.0 / dd->zoom);
 			fitted_PSF *the_psf = com.seq.photometry[i][com.seq.current];
 			if (the_psf) {
-				double size = the_psf->fwhmx;
-				if (the_psf->units[0] == '\"') {
-					size = convert_single_fwhm_to_pixels(the_psf->fwhmx, the_psf->sx);
-				}
-				size *= 2; // in order to be sure to contain stars
+				double size = the_psf->fwhmx * 2.0;
 				cairo_arc(cr, the_psf->xpos, the_psf->ypos, size, 0., 2. * M_PI);
 				cairo_stroke(cr);
 				cairo_arc(cr, the_psf->xpos, the_psf->ypos, com.pref.phot_set.inner, 0.,
@@ -721,9 +727,14 @@ static gdouble y_circle(gdouble y, gdouble radius) {
 
 static void draw_annotates(const draw_data_t* dd) {
 	if (!com.found_object) return;
+	gboolean inverted = gtk_toggle_tool_button_get_active(GTK_TOGGLE_TOOL_BUTTON(lookup_widget("neg_button")));
 	cairo_t *cr = dd->cr;
 	cairo_set_dash(cr, NULL, 0, 0);
-	cairo_set_source_rgba(cr, 0.5, 1.0, 0.3, 0.9);
+	if (inverted) {
+		cairo_set_source_rgba(cr, 0.5, 0.0, 0.7, 0.9);
+	} else {
+		cairo_set_source_rgba(cr, 0.5, 1.0, 0.3, 0.9);
+	}
 	cairo_set_line_width(cr, 1.5 / dd->zoom);
 	GSList *list;
 	for (list = com.found_object; list; list = list->next) {
@@ -793,11 +804,6 @@ void initialize_image_display() {
 		// only HISTEQ mode always computes the index, it's a good initializer here
 	}
 
-	/* Create pixbuf from siril.svg file */
-	gchar *image = g_build_filename(siril_get_system_data_dir(), "pixmaps", "siril.svg", NULL);
-	com.siril_pix = gdk_pixbuf_new_from_file_at_size(image, 256, 256, NULL);
-	g_free(image);
-
 	cairo_matrix_init_identity(&com.display_matrix);
 }
 
