@@ -162,6 +162,7 @@ static void build_photometry_dataset(sequence *seq, int dataset, int size,
 		int ref_image, pldata *plot) {
 	int i, j;
 	double offset = -1001.0;
+	double fwhm;
 	fitted_PSF **psfs = seq->photometry[dataset], *ref_psf;
 	if (seq->reference_star >= 0 && !seq->photometry[seq->reference_star])
 		seq->reference_star = -1;
@@ -195,11 +196,14 @@ static void build_photometry_dataset(sequence *seq, int dataset, int size,
 				plot->data[j].y = psfs[i]->fwhmy / psfs[i]->fwhmx;
 				break;
 			case FWHM:
-				if (is_arcsec)
+				if (is_arcsec) {
 					fwhm_to_arcsec_if_needed(&gfit, psfs[i]);
-				else
+					fwhm = psfs[i]->fwhmx_arcsec < 0 ? psfs[i]->fwhmx : psfs[i]->fwhmx_arcsec;
+				} else {
 					fwhm_to_pixels(psfs[i]);
-				plot->data[j].y = psfs[i]->fwhmx;
+					fwhm = psfs[i]->fwhmx;
+				}
+				plot->data[j].y = fwhm;
 				break;
 			case AMPLITUDE:
 				plot->data[j].y = psfs[i]->A;
@@ -243,8 +247,10 @@ static void build_photometry_dataset(sequence *seq, int dataset, int size,
 }
 
 #ifdef _WIN32
+static const gchar *possible_path[] = { "C:\\PROGRA~1\\gnuplot\\bin\\gnuplot.exe", "C:\\msys64\\mingw64\\bin\\gnuplot.exe" };
+static const gchar *gnuplot_path = NULL;
+
 /* returns true if the gnuplot.exe exists in the wanted folder */
-static gchar *possible_path[] = { "C:\\Program Files\\gnuplot\\bin\\gnuplot.exe" };
 static gboolean gnuplot_is_available() {
 	size_t size, i = 0;
 	gboolean found = FALSE;
@@ -255,18 +261,33 @@ static gboolean gnuplot_is_available() {
 		i++;
 	} while (i < size && !found);
 
+	if (found)
+		gnuplot_path = possible_path[i - 1];
+
 	return found;
 }
 #else
 /* returns true if the command gnuplot is available */
 static gboolean gnuplot_is_available() {
-	int retval = system(GNUPLOT_NAME" -e > /dev/null 2>&1");
+	gchar *str = g_strdup_printf("%s -e > /dev/null 2>&1", siril_win_get_gnuplot_path());
+
+	int retval = system(str);
+	g_free(str);
 	if (WIFEXITED(retval))
 		return 0 == WEXITSTATUS(retval);
 	return FALSE;
 }
 #endif
 
+gchar *siril_win_get_gnuplot_path() {
+#ifdef _WIN32
+	gchar *str = g_strdup_printf("\"%s -persist\"", gnuplot_path);
+	return str;
+#else
+	return "gnuplot";
+#endif
+}
+
 static int lightCurve(pldata *plot, sequence *seq, gchar *filename) {
 	int i, j, k, nbImages = 0, ret = 0;
 	pldata *tmp_plot = plot;
@@ -617,7 +638,7 @@ static void set_filter(GtkFileChooser *dialog, const gchar *format) {
 }
 
 static void save_dialog(const gchar *format, int (export_function)(pldata *, sequence *, gchar *)) {
-	GtkWindow *control_window = GTK_WINDOW(lookup_widget("control_window"));
+	GtkWindow *control_window = GTK_WINDOW(GTK_APPLICATION_WINDOW(lookup_widget("control_window")));
 	SirilWidget *widgetdialog = siril_file_chooser_save(control_window, GTK_FILE_CHOOSER_ACTION_SAVE);
 	GtkFileChooser *dialog = GTK_FILE_CHOOSER(widgetdialog);
 
