@@ -69,6 +69,8 @@ static preferences pref_init = {
 		},
 		.prepro_bias_lib = NULL,
 		.use_bias_lib = FALSE,
+		.prepro_bias_synth = NULL,
+		.use_bias_synth = FALSE,
 		.prepro_dark_lib = NULL,
 		.use_dark_lib = FALSE,
 		.prepro_flat_lib = NULL,
@@ -88,6 +90,8 @@ static preferences pref_init = {
 		.ext = NULL,
 		.swap_dir = NULL,
 		.script_path = NULL,
+		.focal = 1000,
+		.pitch = 5,
 		{ // raw_set
 				.mul[0] = 1.0,
 				.mul[1] = 1.0,
@@ -216,6 +220,17 @@ static void update_prepro_preferences() {
 		com.pref.prepro_bias_lib = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(lookup_widget("filechooser_bias_lib")));
 	}
 	com.pref.use_bias_lib = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget("check_button_pref_bias")));
+
+	if (com.pref.prepro_bias_synth) {
+		g_free(com.pref.prepro_bias_synth);
+	}
+	const gchar *entry = gtk_entry_get_text(GTK_ENTRY(lookup_widget("bias_synth_entry")));
+
+	if (entry) {
+		com.pref.prepro_bias_synth = g_strdup(entry);
+		com.pref.use_bias_synth = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget("check_button_pref_bias_bis")));
+	}
+
 	if (com.pref.prepro_dark_lib) {
 		g_free(com.pref.prepro_dark_lib);
 		com.pref.prepro_dark_lib = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(lookup_widget("filechooser_dark_lib")));
@@ -278,10 +293,9 @@ static void update_FITS_options_preferences() {
 
 static void update_performances_preferences() {
 	GSList *tmp_list = gtk_radio_button_get_group (GTK_RADIO_BUTTON(lookup_widget("memfreeratio_radio")));
-	GtkWidget *ratio, *amount;
+	GtkWidget *amount;
 	GtkToggleButton *tmp_button = NULL;//Create a temp toggle button.
 
-	ratio = lookup_widget("memfreeratio_radio");
 	amount = lookup_widget("memfixed_radio");
 	while (tmp_list) {
 		tmp_button = tmp_list->data;
@@ -293,12 +307,10 @@ static void update_performances_preferences() {
 		tmp_button = NULL; //We've enumerated all of them, and none of them is active.
 	}
 	if (tmp_button) {
-		if (GTK_WIDGET(tmp_button) == ratio) {
-			com.pref.stack.mem_mode = RATIO;
-		} else if (GTK_WIDGET(tmp_button) == amount) {
+		if (GTK_WIDGET(tmp_button) == amount) {
 			com.pref.stack.mem_mode = AMOUNT;
 		} else {
-			com.pref.stack.mem_mode = UNLIMITED;
+			com.pref.stack.mem_mode = RATIO;
 		}
 	}
 
@@ -324,9 +336,8 @@ static void update_misc_preferences() {
 	com.pref.check_update = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget("miscAskUpdateStartup")));
 }
 
-void on_checkbutton_cam_toggled(GtkButton *button, gpointer user_data) {
+void on_checkbutton_cam_toggled(GtkToggleButton *cam_button, gpointer user_data) {
 	GtkToggleButton *auto_button = GTK_TOGGLE_BUTTON(lookup_widget("checkbutton_auto"));
-	GtkToggleButton *cam_button = GTK_TOGGLE_BUTTON(lookup_widget("checkbutton_cam"));
 
 	if (gtk_toggle_button_get_active(auto_button)) {
 		g_signal_handlers_block_by_func(auto_button, on_checkbutton_auto_toggled, NULL);
@@ -336,8 +347,7 @@ void on_checkbutton_cam_toggled(GtkButton *button, gpointer user_data) {
 	}
 }
 
-void on_checkbutton_auto_toggled(GtkButton *button, gpointer user_data) {
-	GtkToggleButton *auto_button = GTK_TOGGLE_BUTTON(lookup_widget("checkbutton_auto"));
+void on_checkbutton_auto_toggled(GtkToggleButton *auto_button, gpointer user_data) {
 	GtkToggleButton *cam_button = GTK_TOGGLE_BUTTON(lookup_widget("checkbutton_cam"));
 
 	if (gtk_toggle_button_get_active(cam_button)) {
@@ -432,7 +442,7 @@ void on_combobox_comp_fits_method_changed(GtkComboBox *box, gpointer user_data)
 
 void set_GUI_compression() {
 	GtkToggleButton *enabled = GTK_TOGGLE_BUTTON(lookup_widget("comp_fits_enabled_radio"));
-	GtkToggleButton *disabled = GTK_TOGGLE_BUTTON(lookup_widget("comp_fits_disbled_radio"));
+	GtkToggleButton *disabled = GTK_TOGGLE_BUTTON(lookup_widget("comp_fits_disabled_radio"));
 
 	gtk_toggle_button_set_active(enabled, com.pref.comp.fits_enabled);
 	gtk_toggle_button_set_active(disabled, !com.pref.comp.fits_enabled);
@@ -507,6 +517,21 @@ void on_show_preview_button_toggled(GtkToggleButton *togglebutton, gpointer user
 	gtk_widget_set_sensitive(box, gtk_toggle_button_get_active(togglebutton));
 }
 
+void bias_text_insert(GtkEntry *entry, const gchar *text, gint length,
+		gint *position, gpointer data) {
+	GtkEditable *editable = GTK_EDITABLE(entry);
+
+	if (*position == 0 && text[0] != '=') {
+		g_signal_handlers_block_by_func(G_OBJECT (editable), G_CALLBACK (bias_text_insert), data);
+		gchar *new_str = g_strdup_printf("=%s", text);
+		gtk_editable_insert_text(editable, new_str, length + 1, position);
+		g_free(new_str);
+		g_signal_handlers_unblock_by_func(G_OBJECT (editable), G_CALLBACK (bias_text_insert), data);
+		g_signal_stop_emission_by_name(G_OBJECT(editable), "insert_text");
+	}
+
+}
+
 void on_clear_bias_entry_clicked(GtkButton *button, gpointer user_data) {
 	gtk_file_chooser_unselect_all((GtkFileChooser *)user_data);
 }
@@ -533,6 +558,28 @@ void on_reload_script_button_clicked(GtkButton *button, gpointer user_data) {
 	}
 }
 
+void on_check_button_pref_bias_bis_toggled(GtkToggleButton *togglebutton, gpointer user_data) {
+	GtkToggleButton *bias_button = GTK_TOGGLE_BUTTON(lookup_widget("check_button_pref_bias"));
+
+	if (gtk_toggle_button_get_active(bias_button)) {
+		g_signal_handlers_block_by_func(bias_button, on_check_button_pref_bias_toggled, NULL);
+		gtk_toggle_button_set_active(bias_button, FALSE);
+		g_signal_handlers_unblock_by_func(bias_button, on_check_button_pref_bias_toggled, NULL);
+		gtk_toggle_button_set_active(togglebutton, TRUE);
+	}
+}
+
+void on_check_button_pref_bias_toggled(GtkToggleButton *togglebutton, gpointer user_data) {
+	GtkToggleButton *bias_button_bis = GTK_TOGGLE_BUTTON(lookup_widget("check_button_pref_bias_bis"));
+
+	if (gtk_toggle_button_get_active(bias_button_bis)) {
+		g_signal_handlers_block_by_func(bias_button_bis, on_check_button_pref_bias_bis_toggled, NULL);
+		gtk_toggle_button_set_active(bias_button_bis, FALSE);
+		g_signal_handlers_unblock_by_func(bias_button_bis, on_check_button_pref_bias_bis_toggled, NULL);
+		gtk_toggle_button_set_active(togglebutton, TRUE);
+	}
+}
+
 void on_spinInner_value_changed(GtkSpinButton *inner, gpointer user_data) {
 	GtkSpinButton *outer;
 	double in, out;
@@ -585,6 +632,8 @@ static void set_preferences_ui(preferences *pref) {
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(lookup_widget("Brightness_spinbutton")), pref->raw_set.bright);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget("checkbutton_blackpoint")), pref->raw_set.user_black);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget("radiobutton_gamm0")), pref->raw_set.gamm[0]);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget("radiobutton_gamm1")), pref->raw_set.gamm[1]);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget("radiobutton_gamm2")), pref->raw_set.gamm[2]);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(lookup_widget("combo_dcraw_inter")), pref->raw_set.user_qual);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget("checkbutton_cam")), pref->raw_set.use_camera_wb);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget("checkbutton_auto")), pref->raw_set.use_auto_wb);
@@ -606,6 +655,14 @@ static void set_preferences_ui(preferences *pref) {
 		gtk_toggle_button_set_active(toggle, pref->use_bias_lib);
 	}
 
+	if (pref->prepro_bias_synth) {
+		GtkEntry *entry = GTK_ENTRY(lookup_widget("bias_synth_entry"));
+		GtkToggleButton *toggle = GTK_TOGGLE_BUTTON(lookup_widget("check_button_pref_bias_bis"));
+
+		gtk_entry_set_text(entry, pref->prepro_bias_synth);
+		gtk_toggle_button_set_active(toggle, pref->use_bias_synth);
+	}
+
 	if (pref->prepro_dark_lib && (g_file_test(pref->prepro_dark_lib, G_FILE_TEST_EXISTS))) {
 		GtkFileChooser *button = GTK_FILE_CHOOSER(lookup_widget("filechooser_dark_lib"));
 		GtkToggleButton *toggle = GTK_TOGGLE_BUTTON(lookup_widget("check_button_pref_dark"));
@@ -665,7 +722,6 @@ static void set_preferences_ui(preferences *pref) {
 	/* tab 9 */
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget("memfreeratio_radio")), pref->stack.mem_mode == RATIO);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget("memfixed_radio")), pref->stack.mem_mode == AMOUNT);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget("memunlimited_radio")), pref->stack.mem_mode == UNLIMITED);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(lookup_widget("spinbutton_mem_ratio")), pref->stack.memory_ratio);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(lookup_widget("spinbutton_mem_amount")), pref->stack.memory_amount);
 
