@@ -214,7 +214,7 @@ static void prepare_savepopup() {
 	}
 	GtkWindow *parent = siril_get_active_window();
 	if (!GTK_IS_WINDOW(parent)) {
-		parent = GTK_WINDOW(lookup_widget("control_window"));
+		parent = GTK_WINDOW(GTK_APPLICATION_WINDOW(lookup_widget("control_window")));
 	}
 	gtk_window_set_transient_for(GTK_WINDOW(savepopup),	parent);
 
@@ -346,12 +346,13 @@ static int save_dialog() {
 	init_dialog();
 
 	GtkFileChooser *chooser = GTK_FILE_CHOOSER(saveDialog);
+	fileChooserPreview *preview = NULL;
 	gchar *fname = get_filename_and_replace_ext();
 
 	gtk_file_chooser_set_current_name(chooser, fname);
 	gtk_file_chooser_set_do_overwrite_confirmation(chooser, TRUE);
 	set_filters_save_dialog(chooser);
-	siril_file_chooser_add_preview(chooser);
+	siril_file_chooser_add_preview(chooser, preview);
 	gtk_file_chooser_unselect_all(chooser);
 	g_signal_connect(chooser, "notify::filter", G_CALLBACK(filter_changed), (gpointer) chooser);
 	g_free(fname);
@@ -370,6 +371,7 @@ static int save_dialog() {
 		return res;
 	}
 	close_dialog();
+	siril_preview_free(preview);
 
 	return res;
 }
@@ -393,7 +395,17 @@ gboolean end_save(gpointer p) {
 	return FALSE;
 }
 
-static void initialize_data(gpointer p) {
+static gboolean test_for_viewer_mode() {
+	gboolean confirm = TRUE;
+	if (get_display_mode_from_menu() != LINEAR_DISPLAY) {
+		confirm = siril_confirm_dialog(_("Viewer mode is not linear"),
+				_("You are saving an image that is displayed in a non linear mode. "
+						"What you see is not what you will get. Switch the viewer mode to linear to save what you see."), _("Save Anyway"));
+	}
+	return confirm;
+}
+
+static gboolean initialize_data(gpointer p) {
 	struct savedial_data *args = (struct savedial_data *) p;
 
 	GtkToggleButton *fits_8 = GTK_TOGGLE_BUTTON(lookup_widget("radiobutton_save_fit8"));
@@ -422,6 +434,8 @@ static void initialize_data(gpointer p) {
 		args->bitpix = FLOAT_IMG;
 
 	args->update_hilo = gtk_toggle_button_get_active(update_hilo);
+
+	return test_for_viewer_mode();
 }
 
 static gpointer mini_save_dialog(gpointer p) {
@@ -652,16 +666,22 @@ void on_button_savepopup_clicked(GtkButton *button, gpointer user_data) {
 	struct savedial_data *args = malloc(sizeof(struct savedial_data));
 
 	set_cursor_waiting(TRUE);
-	initialize_data(args);
-	start_in_new_thread(mini_save_dialog, args);
+	if (initialize_data(args)) {
+		start_in_new_thread(mini_save_dialog, args);
+	} else {
+		siril_add_idle(end_generic, NULL);
+	}
 }
 
 void on_savetxt_activate(GtkEntry *entry, gpointer user_data) {
 	struct savedial_data *args = malloc(sizeof(struct savedial_data));
 
 	set_cursor_waiting(TRUE);
-	initialize_data(args);
-	start_in_new_thread(mini_save_dialog, args);
+	if (initialize_data(args)) {
+		start_in_new_thread(mini_save_dialog, args);
+	} else {
+		siril_add_idle(end_generic, NULL);
+	}
 }
 
 void on_button_cancelpopup_clicked(GtkButton *button, gpointer user_data) {
@@ -678,13 +698,16 @@ void on_header_save_as_button_clicked() {
 				struct savedial_data *args = malloc(sizeof(struct savedial_data));
 
 				set_cursor_waiting(TRUE);
-				initialize_data(args);
-				start_in_new_thread(mini_save_dialog, args);
+				if (initialize_data(args)) {
+					start_in_new_thread(mini_save_dialog, args);
+				} else {
+					siril_add_idle(end_generic, NULL);
+				}
 			} else {
 				close_dialog();
 				GtkWindow *parent = siril_get_active_window();
 				if (!GTK_IS_WINDOW(parent)) {
-					parent = GTK_WINDOW(lookup_widget("control_window"));
+					parent = GTK_WINDOW(GTK_APPLICATION_WINDOW(lookup_widget("control_window")));
 				}
 				gtk_window_set_transient_for(GTK_WINDOW(savepopup), parent);
 				gtk_widget_show(savepopup);
