@@ -257,9 +257,14 @@ static void unselect_select_frame_from_list(GtkTreeView *tree_view) {
 
 static void display_status() {
 	GtkStatusbar *statusbar = GTK_STATUSBAR(lookup_widget("seqlist_statusbar"));
-	gchar *text = g_strdup_printf("%d/%d", com.seq.current + 1, com.seq.number);
-	gtk_statusbar_push(statusbar, COUNT_STATE, text);
-	g_free(text);
+	gchar *text;
+	if (sequence_is_loaded()) {
+		text = g_strdup_printf("%d/%d", com.seq.current + 1, com.seq.number);
+		gtk_statusbar_push(statusbar, COUNT_STATE, text);
+		g_free(text);
+	} else {
+		gtk_statusbar_push(statusbar, COUNT_STATE, "");
+	}
 }
 
 /* method handling all include or all exclude from a sequence */
@@ -376,15 +381,6 @@ static gboolean fill_sequence_list_idle(gpointer p) {
 	return FALSE;
 }
 
-void on_seqlist_button_clicked(GtkToolButton *button, gpointer user_data) {
-	if (gtk_widget_get_visible(lookup_widget("seqlist_dialog"))) {
-		siril_close_dialog("seqlist_dialog");
-	} else {
-		update_seqlist();
-		siril_open_dialog("seqlist_dialog");
-	}
-}
-
 void exclude_single_frame(int index) {
 	siril_log_message(_("%s image %d in sequence %s\n"),
 			com.seq.imgparam[index].incl ? _("Excluding") : _("Including"),
@@ -505,8 +501,10 @@ void on_ref_frame_toggled(GtkToggleButton *togglebutton, gpointer user_data) {
 
 void sequence_list_change_selection_index(int index_in_list, int real_index) {
 	GtkTreePath *path = gtk_tree_path_new_from_indices(index_in_list, -1);
-	sequence_list_change_selection(gtk_tree_path_to_string(path), com.seq.imgparam[real_index].incl);
-	gtk_tree_path_free(path);
+	if (path) {
+		sequence_list_change_selection(gtk_tree_path_to_string(path), com.seq.imgparam[real_index].incl);
+		gtk_tree_path_free(path);
+	}
 }
 
 void sequence_list_change_current() {
