@@ -871,7 +871,7 @@ static fits *read_fit(struct reader_data *reader, seqread_status *retval) {	// r
 	fits *fit = NULL;
 	if (reader->ser) {
 		fit = calloc(1, sizeof(fits));
-		if (ser_read_frame(reader->ser, reader->index, fit, FALSE))
+		if (ser_read_frame(reader->ser, reader->index, fit, FALSE, com.pref.debayer.open_debayer))
 			*retval = READ_FAILED;
 		else *retval = READ_OK;
 		finish_read_seq(reader);
@@ -879,7 +879,11 @@ static fits *read_fit(struct reader_data *reader, seqread_status *retval) {	// r
 		fit = calloc(1, sizeof(fits));
 		if (fitseq_read_frame(reader->fitseq, reader->index, fit, FALSE, get_thread_id(reader)))
 			*retval = READ_FAILED;
-		else *retval = READ_OK;
+		else {
+			debayer_if_needed(TYPEFITS, fit, FALSE);
+			*retval = READ_OK;
+		}
+
 		finish_read_seq(reader);
 	}
 #ifdef HAVE_FFMS2
@@ -1208,6 +1212,9 @@ static void create_sequence_filename(sequence_type output_type, const char *dest
 static seqwrite_status write_image(fits *fit, struct writer_data *writer) {
 	seqwrite_status retval = WRITE_FAILED;
 	if (writer->ser) {
+		if (!strcmp(fit->row_order,"TOP-DOWN")) {  // need to flip the fit before writing to ser to preserve the bayer matrix
+			fits_flip_top_to_bottom(fit);
+		}
 		if (ser_write_frame_from_fit(writer->ser, fit, writer->index)) {
 			siril_log_color_message(_("Error while converting to SER (no space left?)\n"), "red");
 		}
@@ -1244,10 +1251,6 @@ static seqwrite_status write_image(fits *fit, struct writer_data *writer) {
 // similar to compute_nb_images_fit_memory from sequence.c, but uses a FITS as input, not a sequence */
 static int compute_nb_images_fit_mem(fits *fit) {
 	int max_memory_MB = get_max_memory_in_MB();
-	if (max_memory_MB < 0) {
-		// unlimited
-		return -1;
-	}
 	uint64_t memory_per_image = fit->naxes[0] * fit->naxes[1] * fit->naxes[2];
 	if (fit->type == DATA_FLOAT)
 		memory_per_image *= sizeof(float);
