@@ -60,6 +60,8 @@ static char *BinY[] = { "YBINNING", "BINY", NULL };
 static char *Focal[] = { "FOCAL", "FOCALLEN", NULL };
 static char *CCD_TEMP[] = { "CCD-TEMP", "CCD_TEMP", "CCDTEMP", "TEMPERAT", NULL };
 static char *Exposure[] = { "EXPTIME", "EXPOSURE", NULL };
+static char *Cvf[] = { "CVF", "EGAIN", NULL };
+static char *OffsetLevel[] = { "OFFSET", "BLKLEVEL", NULL };  //Used for synthetic offset
 static int CompressionMethods[] = { RICE_1, GZIP_1, GZIP_2, HCOMPRESS_1};
 
 #define __tryToFindKeywords(fptr, type, keywords, value) \
@@ -268,7 +270,7 @@ void read_fits_header(fits *fit) {
 	fits_read_key(fit->fptr, TSTRING, "PROGRAM", &str, NULL, &status);
 	gboolean not_from_siril = g_ascii_strncasecmp(str, PACKAGE, strlen(PACKAGE));
 
-	if (fit->bitpix == FLOAT_IMG && not_from_siril) {
+	if ((fit->bitpix == FLOAT_IMG && not_from_siril) || (fit->bitpix == DOUBLE_IMG)) {
 		status = 0;
 		fits_read_key(fit->fptr, TDOUBLE, "DATAMAX", &(fit->data_max), NULL, &status);
 		if (status == KEY_NO_EXIST) {
@@ -344,9 +346,12 @@ void read_fits_header(fits *fit) {
 	status = 0;
 	fits_read_key(fit->fptr, TDOUBLE, "ISOSPEED", &(fit->iso_speed), NULL, &status);	// Non-standard keywords used in MaxIm DL
 
-	status = 0;
-	fits_read_key(fit->fptr, TDOUBLE, "CVF", &(fit->cvf), NULL, &status);
+	__tryToFindKeywords(fit->fptr, TDOUBLE, Cvf, &fit->cvf); // conversion gain in e-/ADU
 
+	status = 0;
+	fits_read_key(fit->fptr, TUSHORT, "GAIN", &(fit->key_gain), NULL, &status);  // Gain setting from camera
+
+    __tryToFindKeywords(fit->fptr, TUSHORT, OffsetLevel, &fit->key_offset); // Offset setting from camera
 	/*******************************************************************
 	 * ******************* PLATE SOLVING KEYWORDS **********************
 	 * ****************************************************************/
@@ -356,9 +361,15 @@ void read_fits_header(fits *fit) {
 	status = 0;
 	fits_read_key(fit->fptr, TSTRING, "OBJCTRA", &(fit->wcsdata.objctra), NULL, &status);
 
+	status = 0;
+	fits_read_key(fit->fptr, TDOUBLE, "RA", &(fit->wcsdata.ra), NULL, &status);
+
 	status = 0;
 	fits_read_key(fit->fptr, TSTRING, "OBJCTDEC", &(fit->wcsdata.objctdec), NULL, &status);
 
+	status = 0;
+	fits_read_key(fit->fptr, TDOUBLE, "DEC", &(fit->wcsdata.dec), NULL, &status);
+
 	status = 0;
 	fits_read_key(fit->fptr, TDOUBLE, "CRPIX1", &(fit->wcsdata.crpix[0]), NULL, &status);
 
@@ -496,6 +507,15 @@ char *copy_header(fits *fit) {
 	if (!header)
 		return NULL;
 
+	/* we need to test if text is ut8
+	 * indeed some header are not */
+	if (!g_utf8_validate(header, -1, NULL)) {
+		gchar *str = g_utf8_make_valid(header, -1);
+		free(header);
+		header = strdup(str);
+		g_free(str);
+	}
+
 	return header;
 }
 
@@ -919,46 +939,52 @@ static void save_wcs_keywords(fits *fit) {
 		fits_update_key(fit->fptr, TSTRING, "CTYPE2", "DEC--TAN", "Coordinate type for the second axis", &status);
 		status = 0;
 		fits_update_key(fit->fptr, TDOUBLE, "EQUINOX", &(fit->wcsdata.equinox),	"Equatorial equinox", &status);
+	}
+	status = 0;
+
+	/* Needed for Aladin compatibility */
+	if (fit->naxes[2] == 3 && com.pref.rgb_aladin) {
 		status = 0;
+		fits_update_key(fit->fptr, TSTRING, "CTYPE3", "RGB", "RGB image", &status);
+	}
 
-		/* Needed for Aladin compatibility */
-		if (fit->naxes[2] == 3 && com.pref.rgb_aladin) {
-			status = 0;
-			fits_update_key(fit->fptr, TSTRING, "CTYPE3", "RGB", "RGB image", &status);
-		}
-
-		if (fit->wcsdata.objctra[0] != '\0') {
-			status = 0;
-			fits_update_key(fit->fptr, TSTRING, "OBJCTRA", &(fit->wcsdata.objctra),	"Image center R.A. (hms)", &status);
-			status = 0;
-			fits_update_key(fit->fptr, TSTRING, "OBJCTDEC", &(fit->wcsdata.objctdec), "Image center declination (dms)", &status);
-		}
-		if (fit->wcsdata.crpix[0] != '\0') {
-			status = 0;
-			fits_update_key(fit->fptr, TDOUBLE, "CRPIX1", &(fit->wcsdata.crpix[0]), "Axis1 reference pixel", &status);
-			status = 0;
-			fits_update_key(fit->fptr, TDOUBLE, "CRPIX2", &(fit->wcsdata.crpix[1]), "Axis2 reference pixel", &status);
-		}
-		if (fit->wcsdata.crval[0] != '\0') {
-			status = 0;
-			fits_update_key(fit->fptr, TDOUBLE, "CRVAL1", &(fit->wcsdata.crval[0]), "Axis1 reference value", &status);
-			status = 0;
-			fits_update_key(fit->fptr, TDOUBLE, "CRVAL2", &(fit->wcsdata.crval[1]), "Axis2 reference value", &status);
-		}
-		if ((fit->wcsdata.cd[0][0] != 0.0) && (fit->wcsdata.cd[0][1] != 0.0) && (fit->wcsdata.cd[1][0] != 0.0) && (fit->wcsdata.cd[1][1] != 0.0)) {
-			status = 0;
-			fits_update_key(fit->fptr, TDOUBLE, "CD1_1", &(fit->wcsdata.cd[0][0]), "Scale matrix (1, 1)", &status);
-			status = 0;
-			fits_update_key(fit->fptr, TDOUBLE, "CD1_2", &(fit->wcsdata.cd[0][1]), "Scale matrix (1, 2)", &status);
-			status = 0;
-			fits_update_key(fit->fptr, TDOUBLE, "CD2_1", &(fit->wcsdata.cd[1][0]), "Scale matrix (2, 1)", &status);
-			status = 0;
-			fits_update_key(fit->fptr, TDOUBLE, "CD2_2", &(fit->wcsdata.cd[1][1]), "Scale matrix (2, 2)", &status);
-			status = 0;
-			fits_update_key(fit->fptr, TINT, "IMAGEW", &(fit->rx), "Image width, in pixels.", &status);
-			status = 0;
-			fits_update_key(fit->fptr, TINT, "IMAGEH", &(fit->ry), "Image height, in pixels.", &status);
-		}
+	if (fit->wcsdata.objctra[0] != '\0') {
+		status = 0;
+		fits_update_key(fit->fptr, TSTRING, "OBJCTRA", &(fit->wcsdata.objctra),	"Image center R.A. (hms)", &status);
+		status = 0;
+		fits_update_key(fit->fptr, TSTRING, "OBJCTDEC", &(fit->wcsdata.objctdec), "Image center declination (dms)", &status);
+	}
+	if (fit->wcsdata.ra > 0) {
+		status = 0;
+		fits_update_key(fit->fptr, TDOUBLE, "RA", &(fit->wcsdata.ra),	"Image center Right Ascension in degrees", &status);
+		status = 0;
+		fits_update_key(fit->fptr, TDOUBLE, "DEC", &(fit->wcsdata.dec), "Image center Declination in degrees", &status);
+	}
+	if (fit->wcsdata.crpix[0] != '\0') {
+		status = 0;
+		fits_update_key(fit->fptr, TDOUBLE, "CRPIX1", &(fit->wcsdata.crpix[0]), "Axis1 reference pixel", &status);
+		status = 0;
+		fits_update_key(fit->fptr, TDOUBLE, "CRPIX2", &(fit->wcsdata.crpix[1]), "Axis2 reference pixel", &status);
+	}
+	if (fit->wcsdata.crval[0] != '\0') {
+		status = 0;
+		fits_update_key(fit->fptr, TDOUBLE, "CRVAL1", &(fit->wcsdata.crval[0]), "Axis1 reference value", &status);
+		status = 0;
+		fits_update_key(fit->fptr, TDOUBLE, "CRVAL2", &(fit->wcsdata.crval[1]), "Axis2 reference value", &status);
+	}
+	if ((fit->wcsdata.cd[0][0] != 0.0) && (fit->wcsdata.cd[0][1] != 0.0) && (fit->wcsdata.cd[1][0] != 0.0) && (fit->wcsdata.cd[1][1] != 0.0)) {
+		status = 0;
+		fits_update_key(fit->fptr, TDOUBLE, "CD1_1", &(fit->wcsdata.cd[0][0]), "Scale matrix (1, 1)", &status);
+		status = 0;
+		fits_update_key(fit->fptr, TDOUBLE, "CD1_2", &(fit->wcsdata.cd[0][1]), "Scale matrix (1, 2)", &status);
+		status = 0;
+		fits_update_key(fit->fptr, TDOUBLE, "CD2_1", &(fit->wcsdata.cd[1][0]), "Scale matrix (2, 1)", &status);
+		status = 0;
+		fits_update_key(fit->fptr, TDOUBLE, "CD2_2", &(fit->wcsdata.cd[1][1]), "Scale matrix (2, 2)", &status);
+		status = 0;
+		fits_update_key(fit->fptr, TINT, "IMAGEW", &(fit->rx), "Image width, in pixels.", &status);
+		status = 0;
+		fits_update_key(fit->fptr, TINT, "IMAGEH", &(fit->ry), "Image height, in pixels.", &status);
 	}
 }
 
@@ -1115,6 +1141,16 @@ void save_fits_header(fits *fit) {
 
 	}
 
+	status = 0;
+	if (fit->key_gain > 0.)
+		fits_update_key(fit->fptr, TUSHORT, "GAIN", &(fit->key_gain),
+				"Camera gain", &status);
+
+	status = 0;
+	if (fit->key_offset > 0.)
+		fits_update_key(fit->fptr, TUSHORT, "OFFSET", &(fit->key_offset),
+				"Camera offset", &status);
+
 	status = 0;
 	if (fit->cvf > 0.)
 		fits_update_key(fit->fptr, TDOUBLE, "CVF", &(fit->cvf),
@@ -1614,6 +1650,21 @@ int siril_fits_compress(fits *f) {
 		siril_log_message(_("Unknown FITS compression method in internal conversion\n"));
 		return 1;
 	}
+
+	/** In the doc: The default algorithm is called ``SUBTRACTIVE_DITHER_1''.
+	 * A second variation called ``SUBTRACTIVE_DITHER_2'' is also available,
+	 * which does the same thing except that any pixels with a value of 0.0 are not
+	 * dithered and instead the zero values are exactly preserved in the compressed image
+	 *
+	 * Here we need to use SUBTRACTIVE_DITHER in order to not have border artifacts at the
+	 * end of sracking with compressed images.
+	 */
+	if (fits_set_quantize_dither(f->fptr, SUBTRACTIVE_DITHER_2, &status)) {
+		report_fits_error(status);
+		return 1;
+	}
+	status = 0;
+
 	if (fits_set_compression_type(f->fptr, comp_type, &status)) {
 		report_fits_error(status);
 		return 1;
@@ -2016,10 +2067,14 @@ int copy_fits_metadata(fits *from, fits *to) {
 	to->aperture = from->aperture;
 	to->ccd_temp = from->ccd_temp;
 	to->cvf = from->cvf;
+	to->key_gain = from->key_gain;
+	to->key_offset = from->key_offset;	
 	to->dft.norm[0] = from->dft.norm[0];
 	to->dft.norm[1] = from->dft.norm[1];
 	to->dft.norm[2] = from->dft.norm[2];
 
+	memcpy(&to->wcsdata, &from->wcsdata, sizeof(wcs_info));
+
 	return 0;
 }
 
