@@ -148,7 +148,9 @@ sequence * readseqfile(const char *name){
 					if (nbl_backup > 0 && ser_is_cfa(seq->ser_file)) {
 						if (com.pref.debayer.open_debayer)
 							seq->nb_layers = nbl_backup;
-						else seq->nb_layers = 1;
+						else {
+							seq->nb_layers = 1;
+						}
 					}
 					// else if nbl_backup is 3 but opening debayer is not
 					// enabled, we keep 1 in the nb_layers, which will be set in
@@ -678,7 +680,7 @@ int buildseqfile(sequence *seq, int force_recompute) {
 
 	if (seq->end <= 0 || !seq->seqname || seq->seqname[0] == '\0') return 1;
 	if (existseq(seq->seqname) && !force_recompute) {
-		fprintf(stderr, "seqfile '%s.seq' already exists, not overwriting\n", seq->seqname);
+		fprintf(stdout, "seqfile '%s.seq' already exists, not overwriting\n", seq->seqname);
 		return 0;
 	}
 
