@@ -113,6 +113,18 @@ static void fillSeqAviExport() {
 static sequence *check_seq_one_file(const char* name);
 static int seq_read_frame_metadata(sequence *seq, int index, fits *dest);
 
+void populate_seqcombo(const gchar *realname) {
+	control_window_switch_to_tab(IMAGE_SEQ);
+	GtkComboBoxText *combo_box_text = GTK_COMBO_BOX_TEXT(lookup_widget("sequence_list_combobox"));
+	gtk_combo_box_text_remove_all(combo_box_text);
+	gchar *rname = g_path_get_basename(realname);
+	gtk_combo_box_text_append(combo_box_text, 0, rname);
+	g_signal_handlers_block_by_func(GTK_COMBO_BOX(combo_box_text), on_seqproc_entry_changed, NULL);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo_box_text), 0);
+	g_signal_handlers_unblock_by_func(GTK_COMBO_BOX(combo_box_text), on_seqproc_entry_changed, NULL);
+	g_free(rname);
+}
+
 /* when opening a file outside the main sequence loading system and that file
  * is a sequence (SER/AVI), this function is called to load this sequence. */
 int read_single_sequence(char *realname, image_type imagetype) {
@@ -160,15 +172,7 @@ int read_single_sequence(char *realname, image_type imagetype) {
 	gchar *fname = g_path_get_basename(name);
 	if (!set_seq(fname)) {
 		/* if it loads, make it selected and only element in the list of sequences */
-		control_window_switch_to_tab(IMAGE_SEQ);
-		GtkComboBoxText *combo_box_text = GTK_COMBO_BOX_TEXT(lookup_widget("sequence_list_combobox"));
-		gtk_combo_box_text_remove_all(combo_box_text);
-		gchar *rname = g_path_get_basename(realname);
-		gtk_combo_box_text_append(combo_box_text, 0, rname);
-		g_signal_handlers_block_by_func(GTK_COMBO_BOX(combo_box_text), on_seqproc_entry_changed, NULL);
-		gtk_combo_box_set_active(GTK_COMBO_BOX(combo_box_text), 0);
-		g_signal_handlers_unblock_by_func(GTK_COMBO_BOX(combo_box_text), on_seqproc_entry_changed, NULL);
-		g_free(rname);
+		populate_seqcombo(realname);
 	}
 	else retval = 1;
 	g_free(fname);
@@ -694,7 +698,7 @@ int seq_read_frame(sequence *seq, int index, fits *dest, gboolean force_float, i
 			break;
 		case SEQ_SER:
 			assert(seq->ser_file);
-			if (ser_read_frame(seq->ser_file, index, dest, force_float)) {
+			if (ser_read_frame(seq->ser_file, index, dest, force_float, com.pref.debayer.open_debayer)) {
 				siril_log_message(_("Could not load frame %d from SER sequence %s\n"),
 						index, seq->seqname);
 				return 1;
@@ -1460,20 +1464,6 @@ void enforce_area_in_image(rectangle *area, sequence *seq) {
  *                               |_|_|                              *
  ********************************************************************/
 
-struct seqpsf_args {
-	gboolean for_registration;
-	framing_mode framing;
-
-	/* The seqpsf result for each image, list of seqpsf_data */
-	GSList *list;
-};
-
-struct seqpsf_data {
-	int image_index;
-	fitted_PSF *psf;
-	double exposure;
-};
-
 /* Computes FWHM for a sequence image.
  * area is the area from which fit was extracted from the full frame.
  * when the framing is set to follow star, args->area is centered on the found star
@@ -1700,32 +1690,36 @@ void free_reference_image() {
 }
 
 /* returns the number of images of the sequence that can fit into memory based
- * on the configured memory ratio. It can return -1 if there is no memory limit enforced. */
-int compute_nb_images_fit_memory(sequence *seq, double factor, gboolean force_float, unsigned int *MB_per_image, int *max_mem_MB) {
+ * on the configured memory ratio */
+int compute_nb_images_fit_memory(sequence *seq, double factor, gboolean force_float, unsigned int *MB_per_orig_image, unsigned int *MB_per_scaled_image, unsigned int *max_mem_MB) {
 	int max_memory_MB = get_max_memory_in_MB();
-	if (max_memory_MB < 0) {
-		// unlimited
-		return -1;
-	}
 	if (factor < 1.0 || factor > 2.0) {
 		fprintf(stderr, "############ FACTOR UNINIT (set to 1) ############\n");
 		factor = 1.0;
 	}
 	uint64_t newx = round_to_int((double)seq->rx * factor);
 	uint64_t newy = round_to_int((double)seq->ry * factor);
-	uint64_t memory_per_image = newx * newy * seq->nb_layers;
-	if (force_float || get_data_type(seq->bitpix) == DATA_FLOAT)
-		memory_per_image *= sizeof(float);
-	else memory_per_image *= sizeof(WORD);
-	unsigned int memory_per_image_MB = memory_per_image / BYTES_IN_A_MB;
-	if (memory_per_image_MB == 0)
-		memory_per_image_MB = 1;
-	fprintf(stdout, "Memory per image: %u MB. Max memory: %d MB\n", memory_per_image_MB, max_memory_MB);
-	if (MB_per_image)
-		*MB_per_image = memory_per_image_MB;
+	uint64_t memory_per_orig_image = seq->rx * seq->ry * seq->nb_layers;
+	uint64_t memory_per_scaled_image = newx * newy * seq->nb_layers;
+	if (force_float || get_data_type(seq->bitpix) == DATA_FLOAT) {
+		memory_per_orig_image *= sizeof(float);
+		memory_per_scaled_image *= sizeof(float);
+	} else {
+		memory_per_orig_image *= sizeof(WORD);
+		memory_per_scaled_image *= sizeof(WORD);
+	}
+	unsigned int memory_per_orig_image_MB = memory_per_orig_image / BYTES_IN_A_MB;
+	unsigned int memory_per_scaled_image_MB = memory_per_scaled_image / BYTES_IN_A_MB;
+	if (memory_per_scaled_image_MB == 0)
+		memory_per_scaled_image_MB = 1;
+	fprintf(stdout, "Memory per image: %u MB. Max memory: %d MB\n", memory_per_scaled_image_MB, max_memory_MB);
+	if (MB_per_orig_image)
+		*MB_per_orig_image = memory_per_orig_image_MB;
+	if (MB_per_scaled_image)
+		*MB_per_scaled_image = memory_per_scaled_image_MB;
 	if (max_mem_MB)
 		*max_mem_MB = max_memory_MB;
-	return max_memory_MB / memory_per_image_MB;
+	return max_memory_MB / memory_per_scaled_image_MB;
 }
 
 void fix_selnum(sequence *seq, gboolean warn) {
