@@ -40,16 +40,14 @@
 #endif
 #include "algos/geometry.h"
 
-/* same order as in the combo box 'comboExport' */
+/* same order as in the combo box 'combo_export_preset' */
 typedef enum {
-	EXPORT_FITS,
-	EXPORT_FITSEQ,
-	EXPORT_TIFF,
-	EXPORT_SER,
-	EXPORT_AVI,
-	EXPORT_MP4,
-	EXPORT_WEBM
-} export_format;
+	PRESET_RATIO,
+	PRESET_FREE,
+	PRESET_FULLHD,
+	PRESET_4K,
+	PRESET_8K
+} export_presets;
 
 struct exportseq_args {
 	sequence *seq;
@@ -107,6 +105,7 @@ static gpointer export_sequence(gpointer ptr) {
 	fitseq *fitseq_file = NULL;
 	GSList *timestamp = NULL;
 	char *filter_descr;
+	int nb_frames = 0;
 	GDateTime *strTime;
 #ifdef HAVE_FFMPEG
 	struct mp4_struct *mp4_file = NULL;
@@ -197,7 +196,8 @@ static gpointer export_sequence(gpointer ptr) {
 			break;
 
 		case EXPORT_MP4:
-		case EXPORT_WEBM:
+		case EXPORT_MP4_H265:
+		case EXPORT_WEBM_VP9:
 #ifndef HAVE_FFMPEG
 			siril_log_message(_("MP4 output is not supported because siril was not compiled with ffmpeg support.\n"));
 			retval = -1;
@@ -205,7 +205,7 @@ static gpointer export_sequence(gpointer ptr) {
 #else
 			/* resampling is managed by libswscale */
 			snprintf(dest, 256, "%s.%s", args->basename,
-					args->output == EXPORT_MP4 ? "mp4" : "webm");
+					args->output == EXPORT_WEBM_VP9 ? "webm" : "mp4");
 
 			if (in_width % 32 || out_height % 2 || out_width % 2) {
 				siril_log_message(_("Film output needs to have a width that is a multiple of 32 and an even height, resizing selection.\n"));
@@ -237,7 +237,7 @@ static gpointer export_sequence(gpointer ptr) {
 				}
 			}
 
-			mp4_file = mp4_create(dest, out_width, out_height, args->film_fps, args->seq->nb_layers, args->film_quality, in_width, in_height);
+			mp4_file = mp4_create(dest, out_width, out_height, args->film_fps, args->seq->nb_layers, args->film_quality, in_width, in_height, args->output);
 			if (!mp4_file) {
 				retval = -1;
 				goto free_and_reset_progress_bar;
@@ -250,7 +250,7 @@ static gpointer export_sequence(gpointer ptr) {
 	if (output_bitpix == FLOAT_IMG)
 		output_bitpix = com.pref.force_to_16bit ? USHORT_IMG : FLOAT_IMG;
 
-	int nb_frames = compute_nb_filtered_images(args->seq,
+	nb_frames = compute_nb_filtered_images(args->seq,
 			args->filtering_criterion, args->filtering_parameter);
 	filter_descr = describe_filter(args->seq, args->filtering_criterion,
 			args->filtering_parameter);
@@ -263,9 +263,10 @@ static gpointer export_sequence(gpointer ptr) {
 		stackargs.seq = args->seq;
 		stackargs.filtering_criterion = args->filtering_criterion;
 		stackargs.filtering_parameter = args->filtering_parameter;
-		stackargs.nb_images_to_stack = nb_frames; 
+		stackargs.nb_images_to_stack = nb_frames;
 		stackargs.normalize = ADDITIVE_SCALING;
 		stackargs.reglayer = reglayer;
+		stackargs.use_32bit_output = (output_bitpix == FLOAT_IMG);
 
 		// build image indices used by normalization
 		if (stack_fill_list_of_unfiltered_images(&stackargs))
@@ -274,6 +275,14 @@ static gpointer export_sequence(gpointer ptr) {
 		do_normalization(&stackargs);
 		coeff.offset = stackargs.coeff.offset;
 		coeff.scale = stackargs.coeff.scale;
+		for (int layer = 0; layer < args->seq->nb_layers; ++layer) {
+			coeff.poffset[layer] = stackargs.coeff.poffset[layer];
+			coeff.pscale[layer] = stackargs.coeff.pscale[layer];
+		    for (int i = 0; i < nb_frames; ++i) {
+				coeff.poffset[layer][i] = stackargs.coeff.poffset[layer][i];
+				coeff.pscale[layer][i] = stackargs.coeff.pscale[layer][i];
+			}
+		}
 		free(stackargs.coeff.mul);
 
 		// and dispose them, because we don't need them anymore
@@ -401,17 +410,21 @@ static gpointer export_sequence(gpointer ptr) {
 							WORD pixel = fit.pdata[layer][x + y * fit.rx];
 							if (args->normalize) {
 								double tmp = (double) pixel;
-								tmp *= coeff.scale[i];
-								tmp -= coeff.offset[i];
-								pixel = round_to_WORD(tmp);
+								if (pixel > 0) { // do not offset null pixels
+									tmp *= coeff.pscale[layer][i];
+									tmp -= (coeff.poffset[layer][i]);
+									pixel = round_to_WORD(tmp);
+								}
 							}
 							destfit->pdata[layer][nx + ny * fit.rx] = pixel;
 						}
 						else if (fit.type == DATA_FLOAT) {
 							float pixel = fit.fpdata[layer][x + y * fit.rx];
 							if (args->normalize) {
-								pixel *= (float) coeff.scale[i];
-								pixel -= (float) coeff.offset[i];
+								if (pixel != 0.f) { // do not offset null pixels
+									pixel *= (float) coeff.pscale[layer][i];
+									pixel -= (float) coeff.poffset[layer][i];
+								}
 							}
 							if (destfit->type == DATA_FLOAT) {
 								destfit->fpdata[layer][nx + ny * fit.rx] = pixel;
@@ -462,7 +475,8 @@ static gpointer export_sequence(gpointer ptr) {
 				break;
 #ifdef HAVE_FFMPEG
 			case EXPORT_MP4:
-			case EXPORT_WEBM:
+			case EXPORT_MP4_H265:
+			case EXPORT_WEBM_VP9:
 				// an equivalent to fits_to_uint8 is called in there (fill_rgb_image)...
 				retval = mp4_add_frame(mp4_file, destfit);
 				break;
@@ -503,7 +517,8 @@ free_and_reset_progress_bar:
 			avi_file_close(0);
 			break;
 		case EXPORT_MP4:
-		case EXPORT_WEBM:
+		case EXPORT_MP4_H265:
+		case EXPORT_WEBM_VP9:
 #ifdef HAVE_FFMPEG
 			if (mp4_file) {
 				mp4_close(mp4_file);
@@ -551,12 +566,12 @@ void on_buttonExportSeq_clicked(GtkButton *button, gpointer user_data) {
 	if (args->crop)
 		memcpy(&args->crop_area, &com.selection, sizeof(rectangle));
 
-	if (args->output == EXPORT_AVI || args->output == EXPORT_MP4 || args->output == EXPORT_WEBM) {
+	if (args->output == EXPORT_AVI || args->output == EXPORT_MP4 || args->output == EXPORT_MP4_H265 || args->output == EXPORT_WEBM_VP9) {
 		GtkEntry *fpsEntry = GTK_ENTRY(lookup_widget("entryAviFps"));
 		args->film_fps = round_to_int(g_ascii_strtod(gtk_entry_get_text(fpsEntry), NULL));
 		if (args->film_fps <= 0) args->film_fps = 1;
 	}
-	if (args->output == EXPORT_MP4 || args->output == EXPORT_WEBM) {
+	if (args->output == EXPORT_MP4 || args->output == EXPORT_MP4_H265 || args->output == EXPORT_WEBM_VP9) {
 		GtkAdjustment *adjQual = GTK_ADJUSTMENT(gtk_builder_get_object(builder,"adjustment3"));
 		GtkToggleButton *checkResize = GTK_TOGGLE_BUTTON(lookup_widget("checkAviResize"));
 		args->film_quality = (int)gtk_adjustment_get_value(adjQual);
@@ -605,13 +620,15 @@ void on_comboExport_changed(GtkComboBox *box, gpointer user_data) {
 void on_checkAviResize_toggled(GtkToggleButton *togglebutton, gpointer user_data) {
 	GtkWidget *heightEntry = lookup_widget("entryAviHeight");
 	GtkWidget *widthEntry = lookup_widget("entryAviWidth");
+	GtkWidget *combo_export_preset = lookup_widget("combo_export_preset");
 	gtk_widget_set_sensitive(heightEntry, gtk_toggle_button_get_active(togglebutton));
 	gtk_widget_set_sensitive(widthEntry, gtk_toggle_button_get_active(togglebutton));
+	gtk_widget_set_sensitive(combo_export_preset, gtk_toggle_button_get_active(togglebutton));
 }
 
 void update_export_crop_label() {
 	static GtkLabel *label = NULL;
-	if (!label) 
+	if (!label)
 		label = GTK_LABEL(lookup_widget("exportLabel"));
 	if (com.selection.w && com.selection.h)
 		gtk_label_set_text(label, _("Cropping to selection"));
@@ -666,3 +683,64 @@ void on_entryAviHeight_changed(GtkEditable *editable, gpointer user_data) {
 	g_signal_handlers_unblock_by_func(widthEntry, on_entryAviWidth_changed, NULL);
 	g_free(c_width);
 }
+
+static gboolean g_signal_handlers_is_blocked_by_func(gpointer instance, GFunc func, gpointer data) {
+	return g_signal_handler_find(instance,
+			G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA
+					| G_SIGNAL_MATCH_UNBLOCKED, 0, 0, NULL, func, data) == 0;
+}
+
+void on_combo_export_preset_changed(GtkComboBox *box, gpointer user_data) {
+	int preset = gtk_combo_box_get_active(box);
+	GtkWidget *widthEntry = lookup_widget("entryAviWidth");
+	GtkWidget *heightEntry = lookup_widget("entryAviHeight");
+
+	switch(preset) {
+	default:
+	case PRESET_RATIO:
+		if (g_signal_handlers_is_blocked_by_func(GTK_ENTRY(widthEntry), (GFunc) on_entryAviWidth_changed, NULL)) {
+			g_signal_handlers_unblock_by_func(GTK_ENTRY(widthEntry), on_entryAviWidth_changed, NULL);
+			g_signal_handlers_unblock_by_func(GTK_ENTRY(heightEntry), on_entryAviHeight_changed, NULL);
+		}
+		gtk_widget_set_sensitive(widthEntry, TRUE);
+		gtk_widget_set_sensitive(heightEntry, TRUE);
+		break;
+	case PRESET_FREE:
+		if (!g_signal_handlers_is_blocked_by_func(GTK_ENTRY(widthEntry), (GFunc) on_entryAviWidth_changed, NULL)) {
+			g_signal_handlers_block_by_func(GTK_ENTRY(widthEntry), on_entryAviWidth_changed, NULL);
+			g_signal_handlers_block_by_func(GTK_ENTRY(heightEntry), on_entryAviHeight_changed, NULL);
+		}
+		gtk_widget_set_sensitive(widthEntry, TRUE);
+		gtk_widget_set_sensitive(heightEntry, TRUE);
+		break;
+	case PRESET_FULLHD:
+		g_signal_handlers_block_by_func(GTK_ENTRY(widthEntry), on_entryAviWidth_changed, NULL);
+		g_signal_handlers_block_by_func(GTK_ENTRY(heightEntry), on_entryAviHeight_changed, NULL);
+		gtk_entry_set_text(GTK_ENTRY(widthEntry), "1920");
+		gtk_entry_set_text(GTK_ENTRY(heightEntry), "1080");
+		gtk_widget_set_sensitive(widthEntry, FALSE);
+		gtk_widget_set_sensitive(heightEntry, FALSE);
+		g_signal_handlers_unblock_by_func(GTK_ENTRY(widthEntry), on_entryAviWidth_changed, NULL);
+		g_signal_handlers_unblock_by_func(GTK_ENTRY(heightEntry), on_entryAviHeight_changed, NULL);
+		break;
+	case PRESET_4K:
+		g_signal_handlers_block_by_func(GTK_ENTRY(widthEntry), on_entryAviWidth_changed, NULL);
+		g_signal_handlers_block_by_func(GTK_ENTRY(heightEntry), on_entryAviHeight_changed, NULL);
+		gtk_entry_set_text(GTK_ENTRY(widthEntry), "3840");
+		gtk_entry_set_text(GTK_ENTRY(heightEntry), "2160");
+		gtk_widget_set_sensitive(widthEntry, FALSE);
+		gtk_widget_set_sensitive(heightEntry, FALSE);
+		g_signal_handlers_unblock_by_func(GTK_ENTRY(widthEntry), on_entryAviWidth_changed, NULL);
+		g_signal_handlers_unblock_by_func(GTK_ENTRY(heightEntry), on_entryAviHeight_changed, NULL);
+		break;
+	case PRESET_8K:
+		g_signal_handlers_block_by_func(GTK_ENTRY(widthEntry), on_entryAviWidth_changed, NULL);
+		g_signal_handlers_block_by_func(GTK_ENTRY(heightEntry), on_entryAviHeight_changed, NULL);
+		gtk_entry_set_text(GTK_ENTRY(widthEntry), "7680");
+		gtk_entry_set_text(GTK_ENTRY(heightEntry), "4320");
+		gtk_widget_set_sensitive(widthEntry, FALSE);
+		gtk_widget_set_sensitive(heightEntry, FALSE);
+		g_signal_handlers_unblock_by_func(GTK_ENTRY(widthEntry), on_entryAviWidth_changed, NULL);
+		g_signal_handlers_unblock_by_func(GTK_ENTRY(heightEntry), on_entryAviHeight_changed, NULL);
+	}
+}
