@@ -104,34 +104,15 @@ static GOptionEntry main_option[] = {
 
 static GActionEntry app_entries[] = {
 	{ "quit", quit_action_activate },
+	{ "full-screen", full_screen_activated},
 	{ "preferences", preferences_action_activate },
 	{ "open",  open_action_activate },
 	{ "save", save_action_activate },
-	{ "save_as", save_as_action_activate },
-	{ "snapshot", snapshot_action_activate },
-	{ "close", close_action_activate },
-	{ "undo", undo_action_activate },
-	{ "redo", redo_action_activate },
-	{ "scripts", scripts_action_activate },
-	{ "updates", updates_action_activate },
-	{ "full_screen", full_screen_activated},
-	{ "shortcuts", keyboard_shortcuts_activated},
-	{ "about", about_action_activate },
-	{ "cwd", cwd_action_activate },
-	{ "conversion", tab_conversion_activate },
-	{ "sequence", tab_sequence_activate },
-	{ "registration", tab_registration_activate },
-	{ "prepro", tab_prepro_activate },
-	{ "plot", tab_plot_activate },
-	{ "stacking", tab_stacking_activate },
-	{ "logs", tab_logs_activate },
-	{ "zoom_out", zoom_out_activate },
-	{ "zoom_in", zoom_in_activate },
-	{ "zoom_fit", zoom_fit_activate, NULL, "true", change_zoom_fit_state },
-	{ "hide_show_toolbar", toolbar_activate },
-	{ "search_object", search_object_activate }
+	{ "save-as", save_as_action_activate },
+	{ "about", about_action_activate }
 };
 
+
 void load_glade_file() {
 	GError *err = NULL;
 	gchar* gladefile;
@@ -167,7 +148,11 @@ static void global_initialization() {
 	com.sliders = MINMAX;
 	com.zoom_value = ZOOM_DEFAULT;
 	com.ratio = 0.0;
-	com.siril_pix = NULL;
+	com.pref.font_scale = 100.0;
+	/* first initialization of compression settings */
+	com.pref.comp.fits_enabled = FALSE;
+	com.pref.comp.fits_method = 0;
+	com.pref.comp.fits_quantization = 16;
 }
 
 static void init_num_procs() {
@@ -231,6 +216,10 @@ static void siril_app_activate(GApplication *application) {
 	gchar *supported_files = initialize_converters();
 	startup_cwd = g_get_current_dir();
 
+	if (main_option_initfile) {
+		com.initfile = g_strdup(main_option_initfile);
+	}
+
 	if (checkinitfile()) {
 		fprintf(stderr,	_("Could not load or create settings file, exiting.\n"));
 		exit(EXIT_FAILURE);
@@ -240,10 +229,6 @@ static void siril_app_activate(GApplication *application) {
 	if (com.pref.combo_lang)
 		language_init(com.pref.combo_lang);
 
-	if (main_option_initfile) {
-		com.initfile = g_strdup(main_option_initfile);
-	}
-
 	if (main_option_directory) {
 		if (!g_path_is_absolute(main_option_directory)) {
 			cwd_forced = g_build_filename(g_get_current_dir(), main_option_directory, NULL);
@@ -262,19 +247,19 @@ static void siril_app_activate(GApplication *application) {
 
 	if (com.headless) {
 		if (main_option_script) {
-			GInputStream *input_stream;
+			GInputStream *input_stream = NULL;
 
 			if (g_strcmp0(main_option_script, "-") == 0) {
 				input_stream = siril_input_stream_from_stdin();
 			} else {
 				GError *error;
 				GFile *file = g_file_new_for_path(main_option_script);
-				input_stream = (GInputStream *)g_file_read(file, NULL, &error);
-
-				if (input_stream == NULL) {
+				if (file)
+					input_stream = (GInputStream *)g_file_read(file, NULL, &error);
+				if (!input_stream) {
 					if (error != NULL) {
 						g_clear_error(&error);
-						siril_log_message(_("File [%s] does not exist\n"), main_option_script);
+						siril_log_message(_("File [%s] does not exist (from CWD, use absolute path?)\n"), main_option_script);
 					}
 					g_object_unref(file);
 					exit(EXIT_FAILURE);
@@ -300,7 +285,7 @@ static void siril_app_activate(GApplication *application) {
 		/* Load glade file */
 		load_glade_file();
 		/* Passing GApplication to the control center */
-		gtk_window_set_application(GTK_WINDOW(lookup_widget("control_window")),	GTK_APPLICATION(application));
+		gtk_window_set_application(GTK_WINDOW(GTK_APPLICATION_WINDOW(lookup_widget("control_window"))), GTK_APPLICATION(application));
 		/* Load state of the main windows (position and maximized) */
 		load_main_window_state();
 		/* Check for update */
@@ -344,7 +329,7 @@ static void siril_app_open(GApplication *application, GFile **files, gint n_file
 	g_application_activate(application);
 
 	if (n_files > 0) {
-		gchar *path = g_file_get_path (files[0]);
+		gchar *path = g_file_get_path(files[0]);
 		const char *ext = get_filename_ext(path);
 		if (ext && !strncmp(ext, "seq", 4)) {
 			gchar *sequence_dir = g_path_get_dirname(path);
@@ -353,8 +338,10 @@ static void siril_app_open(GApplication *application, GFile **files, gint n_file
 					siril_log_message(_("No sequence `%s' found.\n"), path);
 				} else {
 					set_seq(path);
-					if (!com.script)
+					if (!com.script) {
+						populate_seqcombo(path);
 						set_GUI_CWD();
+					}
 				}
 				g_free(sequence_dir);
 			}
