@@ -14,18 +14,23 @@ extern "C" {
 #include "registration/matching/atpmatch.h"
 #include "gui/progress_and_log.h"
 
-
 int cvResizeGaussian(fits *, int, int, int);
-int cvResizeGaussian_uchar(uint8_t *dataIn, int rx, int ry, uint8_t *dataOut,
-		int toX, int toY, int chan, int interpolation);
+
 int cvRotateImage(fits *, point, double, int, int);
+
+int cvAffineTransformation(fits *image, pointf *refpoints, pointf *curpoints, int nb_points,
+		gboolean upscale2x, int interpolation);
+
 unsigned char *cvCalculH(s_star *star_array_img,
 		struct s_star *star_array_ref, int n, Homography *H);
-int cvApplyScaleToH(Homography *H1, double scale);
-int cvTransformImage(fits *image, long width, long height, Homography Hom, int interpolation);
+
+
+int cvTransformImage(fits *image, Homography Hom, gboolean upscale2x, int interpolation);
+
 int cvUnsharpFilter(fits*, double, double);
-int cvLucyRichardson(fits *image, double sigma, int iterations);
+
 int cvClahe(fits *image, double clip_limit, int size);
+
 #ifdef __cplusplus
 }
 #endif
