@@ -43,7 +43,6 @@
 #include "registration/matching/misc.h"
 #include "opencv/opencv.h"
 
-#define MAX_STARS_FITTED 2000
 
 /* TODO:
  * check usage of openmp in functions called by these ones (to be disabled)
@@ -53,14 +52,82 @@
 static void create_output_sequence_for_global_star(struct registration_args *args);
 static void print_alignment_results(Homography H, int filenum, float FWHMx, float FWHMy, char *units);
 
-struct star_align_data {
-	struct registration_args *regargs;
+regdata *star_align_get_current_regdata(struct registration_args *regargs) {
 	regdata *current_regdata;
-	fitted_PSF **refstars;
-	int fitted_stars;
-	BYTE *success;
-	point ref;
-};
+	if (regargs->seq->regparam[regargs->layer]) {
+		siril_log_message(
+				_("Recomputing already existing registration for this layer\n"));
+		current_regdata = regargs->seq->regparam[regargs->layer];
+		/* we reset all values as we may register different images */
+		memset(current_regdata, 0, regargs->seq->number * sizeof(regdata));
+	} else {
+		current_regdata = calloc(regargs->seq->number, sizeof(regdata));
+		if (current_regdata == NULL) {
+			PRINT_ALLOC_ERR;
+			return NULL;
+		}
+		regargs->seq->regparam[regargs->layer] = current_regdata;
+	}
+	return current_regdata;
+}
+
+int star_align_prepare_results(struct generic_seq_args *args) {
+	struct star_align_data *sadata = args->user;
+	struct registration_args *regargs = sadata->regargs;
+
+	if (!regargs->translation_only) {
+		// allocate destination sequence data
+		regargs->imgparam = calloc(args->nb_filtered_images, sizeof(imgdata));
+		regargs->regparam = calloc(args->nb_filtered_images, sizeof(regdata));
+		if (!regargs->imgparam  || !regargs->regparam) {
+			PRINT_ALLOC_ERR;
+			return 1;
+		}
+
+		if (args->seq->type == SEQ_SER) {
+			/* copied from seq_prepare_hook with one variation */
+			args->new_ser = malloc(sizeof(struct ser_struct));
+			if (!args->new_ser) {
+				PRINT_ALLOC_ERR;
+				return 1;
+			}
+
+			char dest[256];
+			const char *ptr = strrchr(args->seq->seqname, G_DIR_SEPARATOR);
+			if (ptr)
+				snprintf(dest, 255, "%s%s.ser", regargs->prefix, ptr + 1);
+			else
+				snprintf(dest, 255, "%s%s.ser", regargs->prefix, args->seq->seqname);
+
+			/* Here the last argument is NULL because we do not want copy SER file
+			 * from the original. Indeed in the demosaicing case this would lead to
+			 * a wrong file (B&W and not in RAW data). Moreover, header informations
+			 * (like fps, local and UTC time, ...) have no sense now since some frames
+			 * could be removed from the sequence.
+			 */
+			if (ser_create_file(dest, args->new_ser, TRUE, NULL)) {
+				free(args->new_ser);
+				args->new_ser = NULL;
+				return 1;
+			}
+
+			if (seq_prepare_writer(args))
+				return 1;
+		}
+		else if (args->seq->type == SEQ_FITSEQ) {
+			if (seq_prepare_hook(args))
+				return 1;
+		}
+	}
+
+	sadata->success = calloc(args->nb_filtered_images, sizeof(BYTE));
+	if (!sadata->success) {
+		PRINT_ALLOC_ERR;
+		return 1;
+	}
+	return 0;
+}
+
 
 static int star_align_prepare_hook(struct generic_seq_args *args) {
 	struct star_align_data *sadata = args->user;
@@ -70,21 +137,9 @@ static int star_align_prepare_hook(struct generic_seq_args *args) {
 	fits fit = { 0 };
 	int i, nb_stars = 0;
 
-	if (args->seq->regparam[regargs->layer]) {
-		siril_log_message(
-				_("Recomputing already existing registration for this layer\n"));
-		sadata->current_regdata = args->seq->regparam[regargs->layer];
-		/* we reset all values as we may register different images */
-		memset(sadata->current_regdata, 0, args->seq->number * sizeof(regdata));
-	} else {
-		sadata->current_regdata = calloc(args->seq->number, sizeof(regdata));
-		if (sadata->current_regdata == NULL) {
-			PRINT_ALLOC_ERR;
-			return -2;
-		}
-		args->seq->regparam[regargs->layer] = sadata->current_regdata;
-	}
-
+	sadata->current_regdata = star_align_get_current_regdata(regargs);
+	if (!sadata->current_regdata) return -2;
+	
 	/* first we're looking for stars in reference image */
 	if (seq_read_frame(args->seq, regargs->reference_image, &fit, FALSE, -1)) {
 		siril_log_message(_("Could not load reference image\n"));
@@ -96,10 +151,10 @@ static int star_align_prepare_hook(struct generic_seq_args *args) {
 	siril_log_color_message(_("Reference Image:\n"), "green");
 
 	if (regargs->matchSelection && regargs->selection.w > 0 && regargs->selection.h > 0) {
-		com.stars = peaker(&fit, regargs->layer, &com.starfinder_conf, &nb_stars, &regargs->selection, FALSE);
+		com.stars = peaker(&fit, regargs->layer, &com.starfinder_conf, &nb_stars, &regargs->selection, FALSE, TRUE);
 	}
 	else {
-		com.stars = peaker(&fit, regargs->layer, &com.starfinder_conf, &nb_stars, NULL, FALSE);
+		com.stars = peaker(&fit, regargs->layer, &com.starfinder_conf, &nb_stars, NULL, FALSE, TRUE);
 	}
 
 	siril_log_message(_("Found %d stars in reference, channel #%d\n"), nb_stars, regargs->layer);
@@ -157,7 +212,7 @@ static int star_align_prepare_hook(struct generic_seq_args *args) {
 		i++;
 	}
 
-	if (nb_stars > MAX_STARS_FITTED) {
+	if (nb_stars >= MAX_STARS_FITTED) {
 		sadata->fitted_stars = MAX_STARS_FITTED;
 		siril_log_color_message(_("Reference Image: Limiting to %d brightest stars\n"), "green", MAX_STARS_FITTED);
 	} else {
@@ -169,58 +224,8 @@ static int star_align_prepare_hook(struct generic_seq_args *args) {
 	sadata->current_regdata[regargs->reference_image].roundness = FWHMy/FWHMx;
 	sadata->current_regdata[regargs->reference_image].fwhm = FWHMx;
 	sadata->current_regdata[regargs->reference_image].weighted_fwhm = FWHMx;
-	
-	if (!regargs->translation_only) {
-		// allocate destination sequence data
-		regargs->imgparam = calloc(args->nb_filtered_images, sizeof(imgdata));
-		regargs->regparam = calloc(args->nb_filtered_images, sizeof(regdata));
-		if (!regargs->imgparam  || !regargs->regparam) {
-			PRINT_ALLOC_ERR;
-			return 1;
-		}
 
-		if (args->seq->type == SEQ_SER) {
-			/* copied from seq_prepare_hook with one variation */
-			args->new_ser = malloc(sizeof(struct ser_struct));
-			if (!args->new_ser) {
-				PRINT_ALLOC_ERR;
-				return 1;
-			}
-
-			char dest[256];
-			const char *ptr = strrchr(args->seq->seqname, G_DIR_SEPARATOR);
-			if (ptr)
-				snprintf(dest, 255, "%s%s.ser", regargs->prefix, ptr + 1);
-			else
-				snprintf(dest, 255, "%s%s.ser", regargs->prefix, args->seq->seqname);
-
-			/* Here the last argument is NULL because we do not want copy SER file
-			 * from the original. Indeed in the demosaicing case this would lead to
-			 * a wrong file (B&W and not in RAW data). Moreover, header informations
-			 * (like fps, local and UTC time, ...) have no sense now since some frames
-			 * could be removed from the sequence.
-			 */
-			if (ser_create_file(dest, args->new_ser, TRUE, NULL)) {
-				free(args->new_ser);
-				args->new_ser = NULL;
-				return 1;
-			}
-
-			if (seq_prepare_writer(args))
-				return 1;
-		}
-		else if (args->seq->type == SEQ_FITSEQ) {
-			if (seq_prepare_hook(args))
-				return 1;
-		}
-}
-
-	sadata->success = calloc(args->nb_filtered_images, sizeof(BYTE));
-	if (!sadata->success) {
-		PRINT_ALLOC_ERR;
-		return 1;
-	}
-	return 0;
+	return star_align_prepare_results(args);
 }
 
 /* reads the image, searches for stars in it, tries to match them with
@@ -252,10 +257,10 @@ static int star_align_image_hook(struct generic_seq_args *args, int out_index, i
 		}
 
 		if (regargs->matchSelection && regargs->selection.w > 0 && regargs->selection.h > 0) {
-			stars = peaker(fit, regargs->layer, &com.starfinder_conf, &nb_stars, &regargs->selection, FALSE);
+			stars = peaker(fit, regargs->layer, &com.starfinder_conf, &nb_stars, &regargs->selection, FALSE, TRUE);
 		}
 		else {
-			stars = peaker(fit, regargs->layer, &com.starfinder_conf, &nb_stars, NULL, FALSE);
+			stars = peaker(fit, regargs->layer, &com.starfinder_conf, &nb_stars, NULL, FALSE, TRUE);
 		}
 
 		siril_log_message(_("Found %d stars in image %d, channel #%d\n"), nb_stars, filenum, regargs->layer);
@@ -267,8 +272,8 @@ static int star_align_image_hook(struct generic_seq_args *args, int out_index, i
 			return 1;
 		}
 
-		if (nb_stars > sadata->fitted_stars) {
-			if (nb_stars > MAX_STARS_FITTED) {
+		if (nb_stars >= sadata->fitted_stars) {
+			if (nb_stars >= MAX_STARS_FITTED) {
 				siril_log_color_message(_("Target Image: Limiting to %d brightest stars\n"), "green", MAX_STARS_FITTED);
 			}
 			nbpoints = sadata->fitted_stars;
@@ -317,19 +322,10 @@ static int star_align_image_hook(struct generic_seq_args *args, int out_index, i
 				/ (double) sadata->fitted_stars + FWHMx;
 
 		if (!regargs->translation_only) {
-			if (regargs->x2upscale) {
-				if (cvResizeGaussian(fit, fit->rx * 2, fit->ry * 2, OPENCV_NEAREST)) {
-					free_fitted_stars(stars);
-					return 1;
-				}
-				cvApplyScaleToH(&H, 2.0);
-			}
-			fits_flip_top_to_bottom(fit);
-			if (cvTransformImage(fit, (long) sadata->ref.x, (long) sadata->ref.y, H, regargs->interpolation)) {
+			if (cvTransformImage(fit, H, regargs->x2upscale, regargs->interpolation)) {
 				free_fitted_stars(stars);
 				return 1;
 			}
-			fits_flip_top_to_bottom(fit);
 		}
 
 		free_fitted_stars(stars);
@@ -347,7 +343,13 @@ static int star_align_image_hook(struct generic_seq_args *args, int out_index, i
 		regargs->regparam[out_index].fwhm = sadata->current_regdata[in_index].fwhm;	// not FWHMx because of the ref frame
 		regargs->regparam[out_index].weighted_fwhm = sadata->current_regdata[in_index].weighted_fwhm;
 		regargs->regparam[out_index].roundness = sadata->current_regdata[in_index].roundness;
-		invalidate_stats_from_fit(fit);
+
+		if (regargs->x2upscale) {
+			fit->pixel_size_x /= 2;
+			fit->pixel_size_y /= 2;
+			regargs->regparam[out_index].fwhm *= 2.0;
+			regargs->regparam[out_index].weighted_fwhm *= 2.0;
+		}
 	} else {
 		set_shifts(args->seq, in_index, regargs->layer, (float) H.h02,
 				(float) -H.h12, fit->top_down);
@@ -357,7 +359,7 @@ static int star_align_image_hook(struct generic_seq_args *args, int out_index, i
 	return 0;
 }
 
-static int star_align_finalize_hook(struct generic_seq_args *args) {
+int star_align_finalize_hook(struct generic_seq_args *args) {
 	struct star_align_data *sadata = args->user;
 	struct registration_args *regargs = sadata->regargs;
 	int i, failed = 0;
@@ -437,12 +439,106 @@ static int star_align_finalize_hook(struct generic_seq_args *args) {
 	// it here because it's still used in the generic processing function.
 }
 
+int star_align_compute_mem_limits(struct generic_seq_args *args, gboolean for_writer) { 
+	unsigned int MB_per_orig_image, MB_per_scaled_image, MB_avail;
+	int limit = compute_nb_images_fit_memory(args->seq, args->upscale_ratio, args->force_float,
+			&MB_per_orig_image, &MB_per_scaled_image, &MB_avail);
+	unsigned int required = MB_per_scaled_image;
+	if (limit > 0) {
+		/* The registration memory consumption, n is image size and m channel size.
+		 * First, a threshold is computed for star pixel value, using statistics:
+		 *	O(m), data is duplicated for median computation if
+		 *	there are nil values, O(1) otherwise
+		 * Then, still in peaker(), image is filtered using unsharp filter, duplicating
+		 * the reference channel to act as input and output of the filter as float O(2m
+		 * as float).
+		 * Then, the image is rotated and upscaled by the generic function if enabled:
+		 * cvTransformImage is O(n) in mem for unscaled, O(nscaled)=O(4m) for
+		 * monochrome scaled and O(2nscaled)=O(21m) for color scaled
+		 * All this is in addition to the image being already loaded, except for the
+		 * color scaled image.
+		 *
+		 * Since these three operations are in sequence, we need room only for the
+		 * largest.
+		 * rotated color scaled float	mem needed
+		 *       0     0      0     0	O(2m as float)
+		 *       1     0      0     0	O(2m as float)
+		 *       1     0      0     1	O(2m as float, same as 2n)
+		 *       1     0      1     0	O(4m, same as 2m as float)
+		 *       1     0      1     1	O(4m)
+		 *       1     1      0     0	O(2m as float)
+		 *       1     1      0     1	O(n)
+		 *       1     1      1     0	O(8n or 2nscaled)
+		 *       1     1      1     1	O(8n or 2nscaled)
+		 */
+		int is_color = args->seq->nb_layers == 3;
+		int is_float = get_data_type(args->seq->bitpix) == DATA_FLOAT;
+		int is_scaled = args->upscale_ratio == 2.0;
+		unsigned int float_multiplier = is_float ? 1 : 2;
+		unsigned int MB_per_float_image = MB_per_orig_image * float_multiplier;
+		unsigned int MB_per_float_channel = is_color ? MB_per_float_image / 3 : MB_per_float_image;
+		unsigned int MB_per_orig_channel = is_color ? MB_per_orig_image / 3 : MB_per_float_image;
+		MB_per_float_channel = min(1, MB_per_float_channel);
+		MB_per_orig_channel = min(1, MB_per_orig_channel);
+		if (!args->has_output || (!is_scaled && (!is_color || !is_float))) {
+			required = MB_per_orig_image + MB_per_float_channel * 2;
+		}
+		else if (args->has_output && !is_color && is_scaled) {
+			required = MB_per_orig_image + 4 * MB_per_orig_channel;
+		}
+		else if (args->has_output && is_color && !is_scaled && is_float) {
+			required = 2 * MB_per_orig_image;
+		}
+		else {
+			required = 2 * MB_per_scaled_image;
+		}
+		int thread_limit = MB_avail / required;
+		if (thread_limit > com.max_thread)
+			thread_limit = com.max_thread;
+
+		if (for_writer) {
+			/* we allow the already allocated thread_limit images,
+			 * plus how many images can be stored in what remains
+			 * unused by the main processing */
+			limit = thread_limit + (MB_avail - required * thread_limit) / MB_per_scaled_image;
+		} else limit = thread_limit;
+	}
+
+	if (limit == 0) {
+		gchar *mem_per_thread = g_format_size_full(required * BYTES_IN_A_MB, G_FORMAT_SIZE_IEC_UNITS);
+		gchar *mem_available = g_format_size_full(MB_avail * BYTES_IN_A_MB, G_FORMAT_SIZE_IEC_UNITS);
+
+		siril_log_color_message(_("%s: not enough memory to do this operation (%s required per thread, %s considered available)\n"),
+				"red", args->description, mem_per_thread, mem_available);
+
+		g_free(mem_per_thread);
+		g_free(mem_available);
+	} else {
+#ifdef _OPENMP
+		if (for_writer) {
+			int max_queue_size = com.max_thread * 3;
+			if (limit > max_queue_size)
+				limit = max_queue_size;
+		}
+		siril_debug_print("Memory required per thread: %u MB, per image: %u MB, limiting to %d %s\n",
+				required, MB_per_scaled_image, limit, for_writer ? "images" : "threads");
+#else
+		if (!for_writer)
+			limit = 1;
+		else if (limit > 3)
+			limit = 3;
+#endif
+	}
+	return limit;
+}
+
 int register_star_alignment(struct registration_args *regargs) {
 	struct generic_seq_args *args = create_default_seqargs(regargs->seq);
 	if (!regargs->process_all_frames) {
 		args->filtering_criterion = seq_filter_included;
 		args->nb_filtered_images = regargs->seq->selnum;
 	}
+	args->compute_mem_limits_hook = star_align_compute_mem_limits;
 	args->prepare_hook = star_align_prepare_hook;
 	args->image_hook = star_align_image_hook;
 	args->finalize_hook = star_align_finalize_hook;
@@ -454,55 +550,6 @@ int register_star_alignment(struct registration_args *regargs) {
 	args->new_seq_prefix = regargs->prefix;
 	args->load_new_sequence = TRUE;
 	args->already_in_a_thread = TRUE;
-	unsigned int MB_per_image; int MB_avail;
-	int nb_images = compute_nb_images_fit_memory(regargs->seq, args->upscale_ratio, FALSE, &MB_per_image, &MB_avail);
-	if (nb_images > 0) {
-		/* The registration memory consumption, n is image size and m channel size.
-		 * First, a threshold is computed for star pixel value, using statistics:
-		 *	ushort data: O(m), data is duplicated for median
-		 *		computation if there are nil values, O(1) otherwise
-		 *	float data: O(1)
-		 * Then, still in peaker(), image is filtered using wavelets, duplicating the
-		 * image channel to act as input and output of the filter (O(m)) and
-		 * wavelet_transform then allocates 3 times the size of the channel in float,
-		 * because we request 3 planes of wavelets, and pave_2d allocates it once more
-		 * for its working copy, so that makes O(5m as float).
-		 * Then, in the image is written by the generic function if rotation is enabled:
-		 * cvTransformImage is O(n) in mem for monochrome and O(2n) for color.
-		 * Since these three operations are in sequence, we need room only for the
-		 * biggest. In case of float color image, it's the rotation that takes more
-		 * memory, with O(2n) = O(6m). In other cases it's the wavelets with O(5m) or
-		 * O(10m) when it's ushort.
-		 * Don't forget that this is in addition to the image being already read.
-		 */
-		unsigned int required;
-		if (args->has_output && regargs->seq->nb_layers == 3 &&
-				get_data_type(regargs->seq->bitpix) == DATA_FLOAT)
-			required = MB_per_image * 3;
-		else {
-			unsigned int MB_per_channel = regargs->seq->nb_layers == 1 ? MB_per_image : MB_per_image / 3;
-			unsigned int float_multiplier = get_data_type(regargs->seq->bitpix) == DATA_FLOAT ? 1 : 2;
-			required = MB_per_image + 5 * MB_per_channel * float_multiplier;
-		}
-		args->max_thread = MB_avail / required;
-		siril_debug_print("Memory required per thread: %u MB, limiting to %d threads\n", required, args->max_thread);
-	}
-
-	if (args->max_thread > com.max_thread || args->max_thread < 0)
-		args->max_thread = com.max_thread;
-	if (args->max_thread == 0) {
-		gchar *mem_per_image = g_format_size_full(MB_per_image * BYTES_IN_A_MB, G_FORMAT_SIZE_IEC_UNITS);
-		gchar *mem_available = g_format_size_full(MB_avail * BYTES_IN_A_MB, G_FORMAT_SIZE_IEC_UNITS);
-
-		siril_log_color_message(_("Not enough memory to do this operation (%s required per image, %s considered available)\n"),
-				"red", mem_per_image, mem_available);
-
-		g_free(mem_per_image);
-		g_free(mem_available);
-		free(args);
-		return -1;
-	}
-	siril_log_message(_("With the current memory and thread limits, up to %d thread(s) can be used for registration\n"), args->max_thread);
 
 	struct star_align_data *sadata = calloc(1, sizeof(struct star_align_data));
 	if (!sadata) {
@@ -513,6 +560,7 @@ int register_star_alignment(struct registration_args *regargs) {
 	args->user = sadata;
 
 	generic_sequence_worker(args);
+
 	regargs->retval = args->retval;
 	free(args);
 	return regargs->retval;
