@@ -20,6 +20,8 @@
 
 #include <string.h>
 #include <math.h>
+#include <gsl/gsl_statistics_ushort.h>
+#include <gsl/gsl_cdf.h>
 
 #include "core/siril.h"
 #include "core/proto.h"
@@ -286,7 +288,7 @@ int stack_compute_parallel_blocks(struct _image_block **blocksptr, long max_numb
 
 		blocks[j].channel = channel;
 		blocks[j].start_row = row;
-		end = row + height_of_blocks - 1; 
+		end = row + height_of_blocks - 1;
 		if (remainder > 0) {
 			// just add one pixel from the remainder to the first blocks to
 			// avoid having all of them in the last block
@@ -322,8 +324,10 @@ static void stack_read_block_data(struct stacking_args *args, int use_regdata,
 		long *naxes, data_type itype, int thread_id) {
 
 	int ielem_size = itype == DATA_FLOAT ? sizeof(float) : sizeof(WORD);
+	/* store the layer info to retrieve normalization coeffs*/
+	data->layer = (int)my_block->channel;
 	/* Read the block from all images, store them in pix[image] */
-	for (int frame = 0; frame < args->nb_images_to_stack; ++frame){
+	for (int frame = 0; frame < args->nb_images_to_stack; ++frame) {
 		gboolean clear = FALSE, readdata = TRUE;
 		long offset = 0;
 		/* area in C coordinates, starting with 0, not cfitsio coordinates. */
@@ -388,7 +392,7 @@ static void stack_read_block_data(struct stacking_args *args, int use_regdata,
 				int tid = omp_get_thread_num();
 				if (tid == 0)
 #endif
-					siril_log_message(_("Error reading one of the image areas\n"));
+					siril_log_color_message(_("Error reading one of the image areas\n"), "red");
 				break;
 			}
 		}
@@ -490,20 +494,102 @@ static int line_clipping(WORD pixel, float sig[], float sigma, int i, float a, f
 	return 0;
 }
 
+static void remove_element(WORD *array, int index, int array_length) {
+	for (int i = index; i < array_length - 1; i++)
+		array[i] = array[i + 1];
+}
+
+static float siril_stats_ushort_sd(const WORD data[], const int N, float *m) {
+	double accumulator = 0.0; // accumulating in double precision is important for accuracy
+	for (int i = 0; i < N; ++i) {
+		accumulator += data[i];
+	}
+	float mean = (float)(accumulator / N);
+	accumulator = 0.0;
+	for (int i = 0; i < N; ++i)
+		accumulator += (data[i] - mean) * (data[i] - mean);
+
+	if (m) *m = mean;
+
+	return sqrtf((float)(accumulator / (N - 1)));
+}
+
+static void grubbs_stat(WORD *stack, int N, float *GCal, int *max_ind) {
+	float avg_y;
+	float sd = siril_stats_ushort_sd(stack, N, &avg_y);
+
+	/* data are sorted */
+	float max_of_deviations = avg_y - stack[0];
+	float md2 = stack[N - 1] - avg_y;
+
+	if (md2 > max_of_deviations) {
+		max_of_deviations = md2;
+		*max_ind = N - 1;
+	} else {
+		*max_ind = 0;
+	}
+	*GCal = max_of_deviations / sd;
+}
+
+int check_G_values(float Gs, float Gc) {
+	return (Gs > Gc);
+}
+
+void confirm_outliers(struct outliers *out, int N, double median, int *rejected,
+		guint64 rej[2]) {
+	int i = N - 1;
+
+	while (i > 1 && !out[i].out) {
+		i--;
+	}
+	for (int j = i; j >= 0; j--) {
+		out[j].out = 1;
+		if (out[j].x >= median) {
+			rejected[out[j].i] = 1;
+			rej[1]++;
+		} else {
+			rejected[out[j].i] = -1;
+			rej[0]++;
+		}
+	}
+}
+
 static int apply_rejection_ushort(struct _data_block *data, int nb_frames, struct stacking_args *args, guint64 crej[2]) {
 	int N = nb_frames;	// N is the number of pixels kept from the current stack
 	float median = 0.f;
 	int pixel, output, changed, n, r = 0;
 	int firstloop = 1;
-
+	int kept = 0, removed = 0;
 	WORD *stack = (WORD *)data->stack;
 	WORD *w_stack = (WORD *)data->w_stack;
 	int *rejected = (int *)data->rejected;
+	WORD *o_stack = (WORD *)data->o_stack;
+
+	memcpy(o_stack, stack, N * sizeof(WORD)); /* making a copy of unsorted stack to apply weights (before the median sorts in place)*/
+
+	/* remove null pixels */
+	for (int frame = 0; frame < N; frame++) {
+		if (stack[frame] > 0) {
+			if (frame != kept) {
+				stack[kept] = stack[frame];
+			}
+			kept++;
+		}
+	}
+	/* Preventing problems
+	   0: should not happen but just in case.
+	   1 or 2: no need to reject */
+	if (kept <= 2) {
+		return kept;
+	}
+	removed = N - kept;
+	N = kept;
 
 	/* prepare median and check that the stack is not mostly zero */
 	switch (args->type_of_rejection) {
 		case PERCENTILE:
 		case SIGMA:
+		case MAD:
 		case SIGMEDIAN:
 		case WINSORIZED:
 			median = quickmedian(stack, N);
@@ -531,8 +617,14 @@ static int apply_rejection_ushort(struct _data_block *data, int nb_frames, struc
 			N = output;
 			break;
 		case SIGMA:
+		case MAD:
 			do {
-				const float sigma = args->sd_calculator(stack, N);
+				float var;
+				if (args->type_of_rejection == SIGMA)
+					var = args->sd_calculator(stack, N);
+				else
+					var = args->mad_calculator(stack, N, median, FALSE);
+
 				if (!firstloop) {
 					median = quickmedian(stack, N);
 				} else {
@@ -543,7 +635,7 @@ static int apply_rejection_ushort(struct _data_block *data, int nb_frames, struc
 					// no more rejections
 						rejected[frame] = 0;
 					} else {
-						rejected[frame] = sigma_clipping(stack[frame], args->sig, sigma, median, crej);
+						rejected[frame] = sigma_clipping(stack[frame], args->sig, var, median, crej);
 						if (rejected[frame]) {
 							r++;
 						}
@@ -648,6 +740,52 @@ static int apply_rejection_ushort(struct _data_block *data, int nb_frames, struc
 				N = output;
 			} while (changed && N > 3);
 			break;
+		case GESDT:
+			/* Normaly The algorithm does not need to play with sorted data.
+			 * But our implementation (after the rejection) needs to be sorted.
+			 * So we do it, and by the way we get the median value. Indeed, by design
+			 * this algorithm does not have low and high representation of rejection.
+			 * We define:
+			 * - cold pixel: rejected < median
+			 * - hot pixel: rejected > median
+			 */
+
+			quicksort_s(stack, N);
+			median = gsl_stats_ushort_median_from_sorted_data(stack, 1, N);
+
+			int max_outliers = (int) nb_frames * args->sig[0];
+			if (removed >= max_outliers) { /* more than max allowable have been already been removed, should not reject anymore*/
+				return kept;
+			}
+			max_outliers -= removed;
+			struct outliers *out = malloc(max_outliers * sizeof(struct outliers));
+
+			memcpy(w_stack, stack, N * sizeof(WORD));
+			memset(rejected, 0, N * sizeof(int));
+
+			for (int iter = 0, size = N; iter < max_outliers; iter++, size--) {
+				float Gstat;
+				int max_index = 0;
+
+				grubbs_stat(w_stack, size, &Gstat, &max_index);
+				out[iter].out = check_G_values(Gstat, args->critical_value[iter + removed]);
+				out[iter].x = w_stack[max_index];
+				out[iter].i = max_index;
+				remove_element(w_stack, max_index, size);
+			}
+			confirm_outliers(out, max_outliers, median, rejected, crej);
+			free(out);
+
+			for (pixel = 0, output = 0; pixel < N; pixel++) {
+				if (!rejected[pixel]) {
+					// copy only if there was a rejection
+					if (pixel != output)
+						stack[output] = stack[pixel];
+					output++;
+				}
+			}
+			N = output;
+		break;
 		default:
 		case NO_REJEC:
 			;		// Nothing to do, no rejection
@@ -658,27 +796,70 @@ static int apply_rejection_ushort(struct _data_block *data, int nb_frames, struc
 static double mean_and_reject(struct stacking_args *args, struct _data_block *data,
 		int stack_size, data_type itype, guint64 crej[2]) {
 	double mean;
+
+	int layer = data->layer;
 	if (itype == DATA_USHORT) {
 		int kept_pixels = apply_rejection_ushort(data, stack_size, args, crej);
 		if (kept_pixels == 0)
 			mean = quickmedian(data->stack, stack_size);
 		else {
-			gint64 sum = 0L;
-			for (int frame = 0; frame < kept_pixels; ++frame) {
-				sum += ((WORD *)data->stack)[frame];
+			if (args->apply_weight) {
+				double *pweights = args->weights + layer * stack_size;
+				WORD pmin = 65535, pmax = 0; /* min and max computed here instead of rejection step to avoid dealing with too many particular cases */
+				for (int frame = 0; frame < kept_pixels; ++frame) {
+					if (pmin > ((WORD*)data->stack)[frame]) pmin = ((WORD*)data->stack)[frame];
+					if (pmax < ((WORD*)data->stack)[frame]) pmax = ((WORD*)data->stack)[frame];
+				}
+				double sum = 0.0;
+				double norm = 0.0;
+				WORD val;
+
+				for (int frame = 0; frame < stack_size; ++frame) {
+					val = ((WORD*)data->o_stack)[frame];
+					if (val >= pmin && val <= pmax && val > 0) {
+						sum += (float)val * pweights[frame];
+						norm += pweights[frame];
+					}
+				}
+				mean = sum / norm;
+			} else {
+				gint64 sum = 0L;
+				for (int frame = 0; frame < kept_pixels; ++frame) {
+					sum += ((WORD *)data->stack)[frame];
+				}
+				mean = sum / (double)kept_pixels;
 			}
-			mean = sum / (double)kept_pixels;
 		}
 	} else {
 		int kept_pixels = apply_rejection_float(data, stack_size, args, crej);
 		if (kept_pixels == 0)
 			mean = quickmedian_float(data->stack, stack_size);
 		else {
-			double sum = 0.0;
-			for (int frame = 0; frame < kept_pixels; ++frame) {
-				sum += ((float*)data->stack)[frame];
+			if (args->apply_weight) {
+				double *pweights = args->weights + layer * stack_size;
+				float pmin = 10000.0, pmax = -10000.0; /* min and max computed here instead of rejection step to avoid dealing with too many particular cases */
+				for (int frame = 0; frame < kept_pixels; ++frame) {
+					if (pmin > ((float*)data->stack)[frame]) pmin = ((float*)data->stack)[frame];
+					if (pmax < ((float*)data->stack)[frame]) pmax = ((float*)data->stack)[frame];
+				}
+				double sum = 0.0;
+				double norm = 0.0;
+				float val;
+				for (int frame = 0; frame < stack_size; ++frame) {
+					val = ((float*)data->o_stack)[frame];
+					if (val >= pmin && val <= pmax && val != 0.f) {
+						sum += val * pweights[frame];
+						norm += pweights[frame];
+					}
+				}
+			mean = sum / norm;
+			} else {
+				double sum = 0.0;
+				for (int frame = 0; frame < kept_pixels; ++frame) {
+					sum += ((float*)data->stack)[frame];
+				}
+				mean = sum / (double)kept_pixels;
 			}
-			mean = sum / (double)kept_pixels;
 		}
 	}
 	return mean;
@@ -692,6 +873,33 @@ int stack_median(struct stacking_args *args) {
 	return stack_mean_or_median(args, FALSE);
 }
 
+static int compute_weights(struct stacking_args *args) {
+	int nb_frames = args->nb_images_to_stack;
+	int nb_layers = args->seq->nb_layers;
+	int idx = 0;
+
+	args->weights = malloc(nb_layers * nb_frames * sizeof(double));
+	double *pweights[3];
+
+	for (int layer = 0; layer < nb_layers; ++layer) {
+		double norm = 0.0;
+		pweights[layer] = args->weights + layer * nb_frames;
+		for (int i = 0; i < args->nb_images_to_stack; ++i) {
+			idx = args->image_indices[i];
+			pweights[layer][i] = 1.f /
+				(args->coeff.pscale[layer][i] * args->coeff.pscale[layer][i] *
+				 args->seq->stats[layer][idx]->bgnoise * args->seq->stats[layer][idx]->bgnoise);
+			norm += pweights[layer][i];
+		}
+		norm /= (double) nb_frames;
+
+		for (int i = 0; i < args->nb_images_to_stack; i++) {
+			pweights[layer][i] /= norm;
+		}
+	}
+	return ST_OK;
+}
+
 static void compute_date_time_keywords(GList *list_date, fits *fit) {
 	if (list_date) {
 		gdouble exposure = 0.0;
@@ -736,20 +944,16 @@ static void compute_date_time_keywords(GList *list_date, fits *fit) {
 static long stack_get_max_number_of_rows(long naxes[3], data_type type, int nb_images_to_stack) {
 	int max_memory = get_max_memory_in_MB();
 	long total_nb_rows = naxes[1] * naxes[2];
-	if (max_memory > 0) {
-		siril_log_message(_("Using %d MB memory maximum for stacking\n"), max_memory);
-		int elem_size = type == DATA_FLOAT ? sizeof(float) : sizeof(WORD);
-		guint64 number_of_rows = (guint64)max_memory * BYTES_IN_A_MB /
-			((guint64)naxes[0] * nb_images_to_stack * elem_size);
-		// this is how many rows we can load in parallel from all images of the
-		// sequence and be under the limit defined in config in megabytes.
-		if (total_nb_rows < number_of_rows)
-			return total_nb_rows;
-		return (long)number_of_rows;
-	} else {
-		siril_log_message(_("Not using limits on maximum memory for stacking\n"));
-		return naxes[1] * naxes[2];
-	}
+
+	siril_log_message(_("Using %d MB memory maximum for stacking\n"), max_memory);
+	int elem_size = type == DATA_FLOAT ? sizeof(float) : sizeof(WORD);
+	guint64 number_of_rows = (guint64)max_memory * BYTES_IN_A_MB /
+		((guint64)naxes[0] * nb_images_to_stack * elem_size);
+	// this is how many rows we can load in parallel from all images of the
+	// sequence and be under the limit defined in config in megabytes.
+	if (total_nb_rows < number_of_rows)
+		return total_nb_rows;
+	return (long)number_of_rows;
 }
 
 static int stack_mean_or_median(struct stacking_args *args, gboolean is_mean) {
@@ -764,12 +968,16 @@ static int stack_mean_or_median(struct stacking_args *args, gboolean is_mean) {
 	regdata *layerparam = NULL;
 	gboolean use_regdata = is_mean;
 
+
 	int nb_frames = args->nb_images_to_stack; // number of frames actually used
 	naxes[0] = naxes[1] = 0; naxes[2] = 1;
 
 	if (nb_frames < 2) {
 		siril_log_message(_("Select at least two frames for stacking. Aborting.\n"));
 		return ST_GENERIC_ERROR;
+	} else if (nb_frames < 3 && is_mean && args->type_of_rejection == GESDT) {
+		siril_log_message(_("The Generalized Extreme Studentized Deviate Test needs at least three frames for stacking. Aborting.\n"));
+		return ST_GENERIC_ERROR;
 	}
 	g_assert(nb_frames <= args->seq->number);
 
@@ -874,8 +1082,12 @@ static int stack_mean_or_median(struct stacking_args *args, gboolean is_mean) {
 	size_t bufferSize = ielem_size * nb_frames * (npixels_in_block + 1ul) + 4ul; // buffer for tmp and stack, added 4 byte for alignment
 	if (is_mean) {
 		bufferSize += nb_frames * sizeof(int); // for rejected
+		bufferSize += ielem_size * nb_frames; // for o_stack
 		if (args->type_of_rejection == WINSORIZED) {
 			bufferSize += ielem_size * nb_frames; // for w_frame
+		} else if (args->type_of_rejection == GESDT) {
+			bufferSize += ielem_size * nb_frames; // for w_frame
+			bufferSize += sizeof(float) * (int) floor(nb_frames * args->sig[0]); //and GCritical
 		} else if (args->type_of_rejection == LINEARFIT) {
 			bufferSize += 2 * sizeof(float) * nb_frames; // for xc and yc
 		}
@@ -902,10 +1114,22 @@ static int stack_mean_or_median(struct stacking_args *args, gboolean is_mean) {
 				offset += sizeof(int) - temp;
 			}
 			data_pool[i].rejected = (int*)((char*)data_pool[i].tmp + offset);
+			data_pool[i].o_stack = (void*)((char*)data_pool[i].rejected + sizeof(int) * nb_frames);
+
 			if (args->type_of_rejection == WINSORIZED) {
-				data_pool[i].w_stack = (void*)((char*)data_pool[i].rejected + sizeof(int) * nb_frames);
+				data_pool[i].w_stack = (void*)((char*)data_pool[i].o_stack + ielem_size * nb_frames);
+			} else if (args->type_of_rejection == GESDT) {
+				data_pool[i].w_stack = (void*)((char*)data_pool[i].o_stack + ielem_size * nb_frames);
+				int max_outliers = (int) floor(nb_frames * args->sig[0]);
+				args->critical_value = malloc(max_outliers * sizeof(float));
+				for (int j = 0, size = nb_frames; j < max_outliers; j++, size--) {
+					float t_dist = gsl_cdf_tdist_Pinv(1 - args->sig[1] / (2 * size), size - 2);
+					float numerator = (size - 1) * t_dist;
+					float denominator = sqrtf(size) * sqrtf(size - 2 + (t_dist * t_dist));
+					args->critical_value[j] = numerator / denominator;
+				}
 			} else if (args->type_of_rejection == LINEARFIT) {
-				data_pool[i].xf = (float (*)) ((char*) data_pool[i].rejected + sizeof(int) * nb_frames);
+				data_pool[i].xf = (float (*)) ((char*)data_pool[i].o_stack + ielem_size * nb_frames);
 				data_pool[i].yf = data_pool[i].xf + nb_frames;
 				// precalculate some stuff
 				data_pool[i].m_x = (nb_frames - 1) * 0.5f;
@@ -927,8 +1151,19 @@ static int stack_mean_or_median(struct stacking_args *args, gboolean is_mean) {
 		}
 	}
 
-	if (itype == DATA_USHORT)
+	if (itype == DATA_USHORT) {
 		args->sd_calculator = nb_frames < 65536 ? siril_stats_ushort_sd_32 : siril_stats_ushort_sd_64;
+		args->mad_calculator = siril_stats_ushort_mad;
+	}
+
+	if (args->apply_weight) {
+		siril_log_message(_("Computing weights...\n"));
+		retval = compute_weights(args);
+		if(retval) {
+			retval = ST_GENERIC_ERROR;
+			goto free_and_close;
+		}
+	}
 
 	siril_log_message(_("Starting stacking...\n"));
 	if (is_mean)
@@ -974,6 +1209,7 @@ static int stack_mean_or_median(struct stacking_args *args, gboolean is_mean) {
 #endif
 
 		/**** Step 3: iterate over the y and x of the image block and stack ****/
+		int layer = my_block->channel;
 		for (y = 0; y < my_block->height; y++)
 		{
 			/* index of the pixel in the result image
@@ -1044,11 +1280,19 @@ static int stack_mean_or_median(struct stacking_args *args, gboolean is_mean) {
 						case ADDITIVE_SCALING:
 							// additive + scale (mul[frame] = 1)
 							if (itype == DATA_FLOAT) {
-								tmp = fpixel * args->coeff.scale[frame];
-								((float*)data->stack)[frame] = (float)(tmp - args->coeff.offset[frame]);
+								if (fpixel != 0.f) { // do not normalize null pixels to detect them later
+									tmp = fpixel * args->coeff.pscale[layer][frame];
+									((float*)data->stack)[frame] = (float)(tmp - args->coeff.poffset[layer][frame]);
+								} else {
+									((float*)data->stack)[frame] = 0.f;
+								}
 							} else {
-								tmp = (double)pixel * args->coeff.scale[frame];
-								((WORD *)data->stack)[frame] = round_to_WORD(tmp - args->coeff.offset[frame]);
+								if (pixel > 0) { // do not normalize null pixels to detect them later
+									tmp = (double)pixel * args->coeff.pscale[layer][frame];
+									((WORD *)data->stack)[frame] = round_to_WORD(tmp - args->coeff.poffset[layer][frame]);
+								} else {
+									((WORD *)data->stack)[frame] = 0;
+								}
 							}
 							break;
 						case MULTIPLICATIVE:
@@ -1056,11 +1300,11 @@ static int stack_mean_or_median(struct stacking_args *args, gboolean is_mean) {
 						case MULTIPLICATIVE_SCALING:
 							// multiplicative + scale (offset[frame] = 0)
 							if (itype == DATA_FLOAT) {
-								tmp = fpixel * args->coeff.scale[frame];
-								((float*)data->stack)[frame] = (float)(tmp * args->coeff.mul[frame]);
+								tmp = fpixel * args->coeff.pscale[layer][frame];
+								((float*)data->stack)[frame] = (float)(tmp * args->coeff.pmul[layer][frame]);
 							} else {
-								tmp = (double)pixel * args->coeff.scale[frame];
-								((WORD *)data->stack)[frame] = round_to_WORD(tmp * args->coeff.mul[frame]);
+								tmp = (double)pixel * args->coeff.pscale[layer][frame];
+								((WORD *)data->stack)[frame] = round_to_WORD(tmp * args->coeff.pmul[layer][frame]);
 							}
 							break;
 					}
@@ -1129,6 +1373,7 @@ static int stack_mean_or_median(struct stacking_args *args, gboolean is_mean) {
 	/* copy result to gfit if success */
 	clearfits(&gfit);
 	copyfits(&fit, &gfit, CP_FORMAT, -1);
+
 	if (args->use_32bit_output) {
 		gfit.fdata = fit.fdata;
 		for (i = 0; i < fit.naxes[2]; i++)
@@ -1160,9 +1405,13 @@ free_and_close:
 	}
 	g_list_free_full(list_date, (GDestroyNotify) free_list_date);
 	if (blocks) free(blocks);
-	if (args->coeff.offset) free(args->coeff.offset);
-	if (args->coeff.mul) free(args->coeff.mul);
-	if (args->coeff.scale) free(args->coeff.scale);
+	if (args->normalize) {
+		free(args->coeff.offset);
+		free(args->coeff.scale);
+		free(args->coeff.mul);
+	}
+
+	if (args->weights) free(args->weights);
 	if (retval) {
 		/* if retval is set, gfit has not been modified */
 		if (fit.data) free(fit.data);
