@@ -47,7 +47,7 @@
 
 static struct stacking_args stackparam = {	// parameters passed to stacking
 	NULL, NULL, -1, NULL, -1.0, 0, NULL, NULL, NULL, FALSE, { 0, 0 }, -1,
-	{ 0, 0 }, NO_REJEC, NO_NORM, { NULL, NULL, NULL}, FALSE, -1
+	{ 0, 0 }, NULL, NO_REJEC, NO_NORM, { NULL, NULL, NULL}, FALSE, -1
 };
 
 #define MAX_FILTERS 5
@@ -87,11 +87,16 @@ void initialize_stacking_methods() {
 		gtk_spin_button_set_value(high, com.pref.stack.linear_high);
 		break;
 	case SIGMA:
+	case MAD:
 	case SIGMEDIAN:
 	case WINSORIZED:
 		gtk_spin_button_set_value(low, com.pref.stack.sigma_low);
 		gtk_spin_button_set_value(high, com.pref.stack.sigma_high);
 		break;
+	case GESDT:
+		gtk_spin_button_set_value(low, 0.3);
+		gtk_spin_button_set_value(high, 0.05);
+		break;
 	default:
 		return;
 	}
@@ -176,7 +181,7 @@ static void start_stacking() {
 	gchar *error = NULL;
 	static GtkComboBox *method_combo = NULL, *rejec_combo = NULL, *norm_combo = NULL;
 	static GtkEntry *output_file = NULL;
-	static GtkToggleButton *overwrite = NULL, *force_norm = NULL;
+	static GtkToggleButton *overwrite = NULL, *force_norm = NULL, *weight_button = NULL;
 	static GtkSpinButton *sigSpin[2] = {NULL, NULL};
 	static GtkWidget *norm_to_max = NULL;
 
@@ -190,6 +195,7 @@ static void start_stacking() {
 		norm_combo = GTK_COMBO_BOX(lookup_widget("combonormalize"));
 		force_norm = GTK_TOGGLE_BUTTON(lookup_widget("checkforcenorm"));
 		norm_to_max = lookup_widget("check_normalise_to_max");
+		weight_button = GTK_TOGGLE_BUTTON(lookup_widget("stack_weight_button"));
 	}
 
 	if (get_thread_run()) {
@@ -202,12 +208,12 @@ static void start_stacking() {
 	stackparam.type_of_rejection = gtk_combo_box_get_active(rejec_combo);
 	stackparam.normalize = gtk_combo_box_get_active(norm_combo);
 	stackparam.force_norm = gtk_toggle_button_get_active(force_norm);
-	stackparam.output_norm= gtk_toggle_button_get_active(
-			GTK_TOGGLE_BUTTON(norm_to_max)) && gtk_widget_is_visible(norm_to_max);
+	stackparam.output_norm = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(norm_to_max)) && gtk_widget_is_visible(norm_to_max);
 	stackparam.coeff.offset = NULL;
 	stackparam.coeff.mul = NULL;
 	stackparam.coeff.scale = NULL;
 	stackparam.method =	stacking_methods[gtk_combo_box_get_active(method_combo)];
+	stackparam.apply_weight = gtk_toggle_button_get_active(weight_button) && (gtk_combo_box_get_active(norm_combo) != NO_NORM);
 
 	stackparam.use_32bit_output = evaluate_stacking_should_output_32bits(stackparam.method,
 			&com.seq, stackparam.nb_images_to_stack, &error);
@@ -220,7 +226,7 @@ static void start_stacking() {
 	if (stackparam.method != stack_median && stackparam.method != stack_mean_with_rejection)
 		stackparam.normalize = NO_NORM;
 	stackparam.seq = &com.seq;
-	stackparam.reglayer = get_registration_layer(&com.seq);
+	stackparam.reglayer = get_registration_layer(stackparam.seq);
 	siril_log_color_message(_("Stacking will use registration data of layer %d if some exist.\n"), "salmon", stackparam.reglayer);
 
 	/* Do not display that cause it uses the generic function that already
@@ -297,27 +303,35 @@ static void _show_summary(struct stacking_args *args) {
 		switch (args->type_of_rejection) {
 		default:
 		case NO_REJEC:
-			rej_str = _("none");
+			rej_str = _("None");
 			break;
 		case PERCENTILE:
-			rej_str = _("percentile clipping");
+			rej_str = _("Percentile Clipping");
 			break;
 		case SIGMA:
-			rej_str = _("sigma clipping");
+			rej_str = _("Sigma Clipping");
+			break;
+		case MAD:
+			rej_str = _("MAD Clipping");
 			break;
 		case SIGMEDIAN:
-			rej_str = _("median sigma clipping");
+			rej_str = _("Median sigma Clipping");
 			break;
 		case WINSORIZED:
-			rej_str = _("Winsorized sigma clipping");
+			rej_str = _("Winsorized Sigma Clipping");
 			break;
 		case LINEARFIT:
-			rej_str = _("linear fit clipping");
+			rej_str = _("Linear Fit Clipping");
+			break;
+		case GESDT:
+			rej_str = _("Generalized Extreme Studentized Deviate Test");
 			break;
 		}
 		siril_log_message(_("Pixel rejection ........... %s\n"), rej_str);
-		siril_log_message(_("Rejection parameters ...... low=%.3f high=%.3f\n"),
+		if (args->type_of_rejection != GESDT) {
+			siril_log_message(_("Rejection parameters ...... low=%.3f high=%.3f\n"),
 				args->sig[0], args->sig[1]);
+		}
 	}
 }
 
@@ -462,8 +476,9 @@ void on_comboboxstack_methods_changed (GtkComboBox *box, gpointer user_data) {
 void on_combonormalize_changed (GtkComboBox *box, gpointer user_data) {
 	GtkWidget *widgetnormalize = lookup_widget("combonormalize");
 	GtkWidget *force_norm = lookup_widget("checkforcenorm");
-	gtk_widget_set_sensitive(force_norm,
-			gtk_combo_box_get_active(GTK_COMBO_BOX(widgetnormalize)) != 0);
+	GtkWidget *use_weight = lookup_widget("stack_weight_button");
+	gtk_widget_set_sensitive(force_norm, gtk_combo_box_get_active(GTK_COMBO_BOX(widgetnormalize)) != 0);
+	gtk_widget_set_sensitive(use_weight, gtk_combo_box_get_active(GTK_COMBO_BOX(widgetnormalize)) != 0);
 }
 
 void on_stack_siglow_button_value_changed(GtkSpinButton *button, gpointer user_data) {
@@ -477,10 +492,14 @@ void on_stack_siglow_button_value_changed(GtkSpinButton *button, gpointer user_d
 		com.pref.stack.linear_low = gtk_spin_button_get_value(button);
 		break;
 	case SIGMA:
+	case MAD:
 	case SIGMEDIAN:
 	case WINSORIZED:
 		com.pref.stack.sigma_low = gtk_spin_button_get_value(button);
 		break;
+	case GESDT:
+		com.pref.stack.esdt_outliers = gtk_spin_button_get_value(button);
+		break;
 	default:
 		return;
 	}
@@ -498,17 +517,21 @@ void on_stack_sighigh_button_value_changed(GtkSpinButton *button, gpointer user_
 		com.pref.stack.linear_high = gtk_spin_button_get_value(button);
 		break;
 	case SIGMA:
+	case MAD:
 	case SIGMEDIAN:
 	case WINSORIZED:
 		com.pref.stack.sigma_high = gtk_spin_button_get_value(button);
 		break;
+	case GESDT:
+		com.pref.stack.esdt_significance = gtk_spin_button_get_value(button);
+		break;
 	default:
 		return;
 	}
 	writeinitfile();
 }
 
-void on_comborejection_changed (GtkComboBox *box, gpointer user_data) {
+void on_comborejection_changed(GtkComboBox *box, gpointer user_data) {
 	rejection type_of_rejection = gtk_combo_box_get_active(box);
 	static GtkWidget *labellow = NULL, *labelhigh = NULL;
 	static GtkWidget *siglow = NULL, *sighigh = NULL;
@@ -535,6 +558,8 @@ void on_comborejection_changed (GtkComboBox *box, gpointer user_data) {
 			gtk_widget_set_visible(sighigh, TRUE);
 			gtk_widget_set_visible(labellow, TRUE);
 			gtk_widget_set_visible(labelhigh, TRUE);
+			gtk_widget_set_tooltip_text(siglow, _("Low clipping factor for the percentile clipping rejection algorithm."));
+			gtk_widget_set_tooltip_text(sighigh, _("High clipping factor for the percentile clipping rejection algorithm."));
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(siglow), com.pref.stack.percentile_low);
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(sighigh), com.pref.stack.percentile_high);
 			gtk_spin_button_set_range(GTK_SPIN_BUTTON(siglow), 0.0, 1.0);
@@ -547,6 +572,8 @@ void on_comborejection_changed (GtkComboBox *box, gpointer user_data) {
 			gtk_widget_set_visible(sighigh, TRUE);
 			gtk_widget_set_visible(labellow, TRUE);
 			gtk_widget_set_visible(labelhigh, TRUE);
+			gtk_widget_set_tooltip_text(siglow, _("Tolerance for low pixel values of the linear fit clipping algorithm, in sigma units."));
+			gtk_widget_set_tooltip_text(sighigh, _("Tolerance for high pixel values of the linear fit clipping algorithm, in sigma units."));
 			gtk_spin_button_set_range(GTK_SPIN_BUTTON(siglow), 0.0, 10.0);
 			gtk_spin_button_set_range(GTK_SPIN_BUTTON(sighigh), 0.0, 10.0);
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(siglow), com.pref.stack.linear_low);
@@ -556,17 +583,36 @@ void on_comborejection_changed (GtkComboBox *box, gpointer user_data) {
 			break;
 		default:
 		case SIGMA:
+		case MAD:
+		case SIGMEDIAN:
 		case WINSORIZED:
 			gtk_widget_set_visible(siglow, TRUE);
 			gtk_widget_set_visible(sighigh, TRUE);
 			gtk_widget_set_visible(labellow, TRUE);
 			gtk_widget_set_visible(labelhigh, TRUE);
+			gtk_widget_set_tooltip_text(siglow, _("Low clipping factor for the sigma clipping rejection algorithm."));
+			gtk_widget_set_tooltip_text(sighigh, _("High clipping factor for the sigma clipping rejection algorithm."));
 			gtk_spin_button_set_range(GTK_SPIN_BUTTON(siglow), 0.0, 10.0);
 			gtk_spin_button_set_range(GTK_SPIN_BUTTON(sighigh), 0.0, 10.0);
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(siglow), com.pref.stack.sigma_low);
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(sighigh), com.pref.stack.sigma_high);
 			gtk_label_set_text(GTK_LABEL(labellow), _("Sigma low: "));
 			gtk_label_set_text(GTK_LABEL(labelhigh), _("Sigma high: "));
+			break;
+		case GESDT:
+			gtk_widget_set_visible(siglow, TRUE);
+			gtk_widget_set_visible(sighigh, TRUE);
+			gtk_widget_set_visible(labellow, TRUE);
+			gtk_widget_set_visible(labelhigh, TRUE);
+			gtk_widget_set_tooltip_text(siglow, _("Expected fraction of maximum outliers for the Generalized Extreme Studentized Deviate Test algorithm."));
+			gtk_widget_set_tooltip_text(sighigh, _("Probability of making a false positive for the Generalized Extreme Studentized Deviate Test algorithm. "
+					"Increasing this value will reject more pixels."));
+			gtk_spin_button_set_range(GTK_SPIN_BUTTON(siglow), 0.0, 1.0);
+			gtk_spin_button_set_range(GTK_SPIN_BUTTON(sighigh), 0.0, 1.0);
+			gtk_spin_button_set_value(GTK_SPIN_BUTTON(siglow), 0.3);
+			gtk_spin_button_set_value(GTK_SPIN_BUTTON(sighigh), 0.05);
+			gtk_label_set_text(GTK_LABEL(labellow), _("ESD Outliers: "));
+			gtk_label_set_text(GTK_LABEL(labelhigh), _("ESD Significance: "));
 	}
 
 	g_signal_handlers_unblock_by_func(GTK_SPIN_BUTTON(siglow), on_stack_siglow_button_value_changed, NULL);
@@ -847,5 +893,6 @@ static void stacking_args_deep_copy(struct stacking_args *from, struct stacking_
 static void stacking_args_deep_free(struct stacking_args *args) {
 	free(args->image_indices);
 	free(args->description);
+	free(args->critical_value);
 	free(args);
 }
