@@ -31,9 +31,11 @@ typedef enum {
 	NO_REJEC,
 	PERCENTILE,
 	SIGMA,
+	MAD,
 	SIGMEDIAN,
 	WINSORIZED,
 	LINEARFIT,
+	GESDT
 } rejection;
 
 /* TYPE OF NORMALIZATION */
@@ -59,8 +61,12 @@ struct normalization_coeff {
 	double *offset;
 	double *mul;
 	double *scale;
+	double *poffset[3];
+	double *pmul[3];
+	double *pscale[3];
 };
 
+
 struct stacking_args {
 	stack_method method;
 	sequence *seq;
@@ -74,7 +80,8 @@ struct stacking_args {
 	gboolean output_overwrite;	// used in the idle function only
 	struct timeval t_start;
 	int retval;
-	float sig[2];		/* low and high sigma rejection */
+	float sig[2];		/* low and high sigma rejection or GESTD parameters */
+	float *critical_value; /* index of critical_values for GESTD */
 	rejection type_of_rejection;	/* type of rejection */
 	normalization normalize;	/* type of normalization */
 	norm_coeff coeff;		/* normalization data */
@@ -83,7 +90,11 @@ struct stacking_args {
 	gboolean use_32bit_output;	/* output to 32 bit float */
 	int reglayer;		/* layer used for registration data */
 
+	gboolean apply_weight;			/* enable weights */
+	double *weights; 				/* computed weights for each (layer,image)*/
+
 	float (*sd_calculator)(const WORD *, const int); // internal, for ushort
+	float (*mad_calculator)(const WORD *, const size_t, const double, gboolean) ; // internal, for ushort
 };
 
 /* configuration from the command line */
@@ -100,8 +111,20 @@ struct stacking_configuration {
 	int number_of_loaded_sequences;
 	float f_fwhm, f_fwhm_p, f_wfwhm, f_wfwhm_p, f_round, f_round_p, f_quality, f_quality_p; // on if >0
 	gboolean filter_included;
+	gboolean apply_weight;
 };
 
+
+/*
+ * ESD test statistic data.
+ */
+struct outliers {
+	float x;
+	int i;
+	int out;
+};
+
+
 void initialize_stacking_default();
 void initialize_stacking_methods();
 gboolean evaluate_stacking_should_output_32bits(stack_method method,
@@ -127,6 +150,9 @@ int do_normalization(struct stacking_args *args);
 
 	/* median and mean functions */
 
+int check_G_values(float Gs, float Gc);
+void confirm_outliers(struct outliers *out, int N, double median, int *rejected, guint64 rej[2]);
+
 struct _image_block {
 	long channel, start_row, end_row, height; // long matches naxes type
 };
@@ -141,7 +167,9 @@ struct _data_block {
 	void *stack;	// the reordered stack for one pixel in all images
 	int *rejected;  // 0 if pixel ok, 1 or -1 if rejected
 	void *w_stack;	// stack for the winsorized rejection
+	void *o_stack;  // original unordered stack
 	float *xf, *yf, m_x, m_dx2;// data for the linear fit rejection
+	int layer;	// to identify layer for normalization
 };
 
 int stack_open_all_files(struct stacking_args *args, int *bitpix, int *naxis, long *naxes, GList **date_time, fits *fit);
